@@ -21,6 +21,10 @@ from .models import (
     BlueprintChart,
     BlueprintTaskDocument,
     CalendarFile,
+    Cluster,
+    ClusteringModel,
+    ClusterInsight,
+    CombinedModel,
     ComplianceDocTemplate,
     ComplianceDocumentation,
     Connector,
@@ -33,6 +37,7 @@ from .models import (
     CustomTask,
     CustomTaskVersion,
     DataDriver,
+    DataEngineQueryGenerator,
     Dataset,
     DatasetDetails,
     DatasetFeature,
@@ -86,6 +91,8 @@ from .models import (
     RelationshipsConfiguration,
     Ruleset,
     SecondaryDatasetConfigurations,
+    SegmentationTask,
+    SegmentInfo,
     ShapImpact,
     ShapMatrix,
     ShapMatrixJob,
