@@ -1,3 +1,16 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
+
+
 def enum(*vals, **enums):
     """
     Enum without third party libs and compatible with py2 and py3 versions.
@@ -7,7 +20,11 @@ def enum(*vals, **enums):
 
 
 CV_METHOD = enum(
-    DATETIME="datetime", GROUP="group", RANDOM="random", STRATIFIED="stratified", USER="user",
+    DATETIME="datetime",
+    GROUP="group",
+    RANDOM="random",
+    STRATIFIED="stratified",
+    USER="user",
 )
 
 
@@ -40,7 +57,10 @@ QUEUE_STATUS = enum(
 
 
 AUTOPILOT_MODE = enum(
-    FULL_AUTO="auto", MANUAL="manual", QUICK="quick", COMPREHENSIVE="comprehensive",
+    FULL_AUTO="auto",
+    MANUAL="manual",
+    QUICK="quick",
+    COMPREHENSIVE="comprehensive",
 )
 
 
@@ -101,7 +121,10 @@ PRIME_LANGUAGE = enum(JAVA="Java", PYTHON="Python")
 
 # CATEGORICAL is deprecated, to be removed in 2.22
 VARIABLE_TYPE_TRANSFORM = enum(
-    CATEGORICAL="categorical", CATEGORICAL_INT="categoricalInt", NUMERIC="numeric", TEXT="text",
+    CATEGORICAL="categorical",
+    CATEGORICAL_INT="categoricalInt",
+    NUMERIC="numeric",
+    TEXT="text",
 )
 
 
@@ -140,12 +163,16 @@ TS_BLENDER_METHOD = enum(
 )
 
 CHART_DATA_SOURCE = enum(
-    CROSSVALIDATION="crossValidation", HOLDOUT="holdout", VALIDATION="validation",
+    CROSSVALIDATION="crossValidation",
+    HOLDOUT="holdout",
+    VALIDATION="validation",
 )
 
 
 SCALEOUT_MODELING_MODE = enum(
-    AUTOPILOT="autopilot", DISABLED="disabled", REPOSITORY_ONLY="repositoryOnly",
+    AUTOPILOT="autopilot",
+    DISABLED="disabled",
+    REPOSITORY_ONLY="repositoryOnly",
 )
 
 
@@ -156,7 +183,7 @@ DATA_SUBSET = enum(
     ALL_BACKTESTS="allBacktests",
 )
 
-FEATURE_TYPE = enum(NUMERIC="numeric", CATEGORICAL="categorical")
+FEATURE_TYPE = enum(NUMERIC="numeric", CATEGORICAL="categorical", DATETIME="datetime")
 
 DEFAULT_MAX_WAIT = 600
 
@@ -203,7 +230,10 @@ RECOMMENDED_MODEL_TYPE = enum(
 )
 
 AVAILABLE_STATEMENT_TYPES = enum(
-    INSERT="insert", UPDATE="update", INSERT_UPDATE="insert_update", CREATE_TABLE="create_table",
+    INSERT="insert",
+    UPDATE="update",
+    INSERT_UPDATE="insert_update",
+    CREATE_TABLE="create_table",
 )
 
 
@@ -541,3 +571,70 @@ class AnomalyAssessmentStatus(object):
     NOT_SUPPORTED = "notSupported"  # when full training subset can not be fit into memory.
 
     ALL = (COMPLETED, NO_DATA, NOT_SUPPORTED)
+
+
+class UnsupervisedTypeEnum(object):
+    ANOMALY = "anomaly"
+    CLUSTERING = "clustering"
+
+
+class FairnessMetricsSet(object):
+    PROPORTIONAL_PARITY = "proportionalParity"
+    EQUAL_PARITY = "equalParity"
+    PREDICTION_BALANCE = "predictionBalance"
+    TRUE_FAVORABLE_AND_UNFAVORABLE_RATE_PARITY = "trueFavorableAndUnfavorableRateParity"
+    FAVORABLE_AND_UNFAVORABLE_PREDICTIVE_VALUE_PARITY = (
+        "favorableAndUnfavorablePredictiveValueParity"
+    )
+
+    ALL = (
+        PROPORTIONAL_PARITY,
+        EQUAL_PARITY,
+        PREDICTION_BALANCE,
+        TRUE_FAVORABLE_AND_UNFAVORABLE_RATE_PARITY,
+        FAVORABLE_AND_UNFAVORABLE_PREDICTIVE_VALUE_PARITY,
+    )
+
+
+class FileLocationType(object):
+    PATH = "path"
+    URL = "url"
+    ALL = [PATH, URL]
+
+
+class ImageFormat(object):
+    JPEG = "JPEG"
+    PNG = "PNG"
+    BMP = "BMP"
+    PPM = "PPM"
+    GIF = "GIF"
+    MPO = "MPO"
+    TIFF = "TIFF"
+    ALL = [JPEG, PNG, BMP, PPM, GIF, MPO, TIFF]
+
+
+# enum representing resample methods in alignment with PIL.Image resampling methods.
+# Enum is created explicitly both for user convenience and because PIL library
+# installation is optional dependency for datarobot library.
+class ImageResampleMethod(object):
+    NEAREST = NONE = 0
+    LANCZOS = ANTIALIAS = 1
+    BILINEAR = LINEAR = 2
+    BICUBIC = CUBIC = 3
+    BOX = 4
+    HAMMING = 5
+
+
+# Defaults used for image transformations preprocessing
+# Image resize defaults
+DEFAULT_VISUAL_AI_SHOULD_RESIZE = True
+DEFAULT_VISUAL_AI_IMAGE_SIZE = (224, 224)
+# Image format defaults
+DEFAULT_VISUAL_AI_IMAGE_FORMAT = ImageFormat.JPEG
+DEFAULT_VISUAL_AI_IMAGE_SUBSAMPLING = 0
+DEFAULT_VISUAL_AI_IMAGE_QUALITY = 95
+DEFAULT_VISUAL_AI_IMAGE_RESAMPLE_METHOD = ImageResampleMethod.LANCZOS
+
+
+# Image formats supported by DataRobot application
+SUPPORTED_IMAGE_FORMATS = set(ImageFormat.ALL)
