@@ -110,6 +110,31 @@ class AdvancedOptions(object):
         ``Project.validate_external_time_series_baseline`` and
         :ref:`external baseline predictions documentation <external_baseline_predictions>`
         for further explanation.
+    use_supervised_feature_reduction: bool, default ``True` optional
+        Time Series only. When true, during feature generation DataRobot runs a supervised
+        algorithm to retain only qualifying features. Setting to false can
+        severely impact autopilot duration, especially for datasets with many features.
+    primary_location_column: str, optional.
+        The name of primary location column.
+    protected_features: str, optional.
+        (New in version v2.24) A list of project features to mark as protected for
+        Bias and Fairness testing calculations. Max number of protected features allowed is 10.
+    preferable_target_value: str, optional.
+        (New in version v2.24) A target value that should be treated as a favorable outcome
+        for the prediction. For example, if we want to check gender discrimination for
+        giving a loan and our target is named ``is_bad``, then the positive outcome for
+        the prediction would be ``No``, which means that the loan is good and that's
+        what we treat as a favorable result for the loaner.
+    fairness_metrics_set: str, optional.
+        (New in version v2.24) Metric to use for calculating fairness.
+        Can be one of ``proportionalParity``, ``equalParity``, ``predictionBalance``,
+        ``trueFavorableAndUnfavorableRateParity`` or
+        ``favorableAndUnfavorablePredictiveValueParity``.
+        Used and required only if *Bias & Fairness in AutoML* feature is enabled.
+    fairness_threshold: str, optional.
+        (New in version v2.24) Threshold value for the fairness metric.
+        Can be in a range of ``[0.0, 1.0]``. If the relative (i.e. normalized) fairness
+        score is below the threshold, then the user will see a visual indication on the
 
     Examples
     --------
@@ -155,6 +180,12 @@ class AdvancedOptions(object):
         feature_discovery_supervised_feature_reduction=True,
         exponentially_weighted_moving_alpha=None,
         external_time_series_baseline_dataset_id=None,
+        use_supervised_feature_reduction=True,
+        primary_location_column=None,
+        protected_features=None,
+        preferable_target_value=None,
+        fairness_metrics_set=None,
+        fairness_threshold=None,
     ):
         self.weights = weights
         self.response_cap = response_cap
@@ -185,6 +216,12 @@ class AdvancedOptions(object):
         )
         self.exponentially_weighted_moving_alpha = exponentially_weighted_moving_alpha
         self.external_time_series_baseline_dataset_id = external_time_series_baseline_dataset_id
+        self.use_supervised_feature_reduction = use_supervised_feature_reduction
+        self.primary_location_column = primary_location_column
+        self.protected_features = protected_features
+        self.preferable_target_value = preferable_target_value
+        self.fairness_metrics_set = fairness_metrics_set
+        self.fairness_threshold = fairness_threshold
 
     def collect_payload(self):
 
@@ -204,6 +241,7 @@ class AdvancedOptions(object):
             monotonic_decreasing_featurelist_id=self.monotonic_decreasing_featurelist_id,
             only_include_monotonic_blueprints=self.only_include_monotonic_blueprints,
             allowed_pairwise_interaction_groups=self.allowed_pairwise_interaction_groups,
+            use_supervised_feature_reduction=self.use_supervised_feature_reduction,
         )
 
         # Some of the optional parameters are incompatible with the others.
@@ -223,8 +261,52 @@ class AdvancedOptions(object):
             feature_discovery_supervised_feature_reduction=sfd,
             exponentially_weighted_moving_alpha=self.exponentially_weighted_moving_alpha,
             external_time_series_baseline_dataset_id=self.external_time_series_baseline_dataset_id,
+            primary_location_column=self.primary_location_column,
+            protected_features=self.protected_features,
+            preferable_target_value=self.preferable_target_value,
+            fairness_metrics_set=self.fairness_metrics_set,
+            fairness_threshold=self.fairness_threshold,
         )
 
         payload.update({k: v for k, v in optional.items() if v is not None})
 
         return payload
+
+
+class ClassMappingAggregationSettings(object):
+    """Class mapping aggregation settings.
+    For multiclass projects allows fine control over which target values will be
+    preserved as classes. Classes which aren't preserved will be
+    - aggregated into a single "catch everything else" class in case of multiclass
+    - or will be ignored in case of multilabel.
+    All attributes are optional, if not specified - server side defaults will be used.
+
+    Attributes
+    ----------
+    max_unaggregated_class_values : int, optional
+        Maximum amount of unique values allowed before aggregation kicks in.
+    min_class_support : int, optional
+        Minimum number of instances necessary for each target value in the dataset.
+        All values with less instances will be aggregated.
+    excluded_from_aggregation : list, optional
+        List of target values that should be guaranteed to kept as is,
+        regardless of other settings.
+    aggregation_class_name : str, optional
+        If some of the values will be aggregated - this is the name of the aggregation class
+        that will replace them.
+    """
+
+    def __init__(
+        self,
+        max_unaggregated_class_values=None,
+        min_class_support=None,
+        excluded_from_aggregation=None,
+        aggregation_class_name=None,
+    ):
+        self.max_unaggregated_class_values = max_unaggregated_class_values
+        self.min_class_support = min_class_support
+        self.excluded_from_aggregation = excluded_from_aggregation
+        self.aggregation_class_name = aggregation_class_name
+
+    def collect_payload(self):
+        return {key: self.__dict__[key] for key in self.__dict__ if self.__dict__[key] is not None}
