@@ -1,8 +1,19 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from ..enums import SNAPSHOT_POLICY
 
 
 class DatasetDefinition(object):
-    """ Dataset definition for the Feature Discovery
+    """Dataset definition for the Feature Discovery
 
     .. versionadded:: v2.25
 
@@ -87,7 +98,7 @@ class DatasetDefinition(object):
 
 
 class Relationship(object):
-    """ Relationship between dataset defined in DatasetDefinition
+    """Relationship between dataset defined in DatasetDefinition
 
     .. versionadded:: v2.25
 
@@ -119,6 +130,10 @@ class Relationship(object):
         One of ``datarobot.enums.AllowedTimeUnitsSAFER``
         If present, time-aware joins will be used.
         Only applicable when dataset1_identifier is not provided.
+    feature_derivation_windows: list of dict, or None
+        List of feature derivation windows settings. If present, time-aware joins will be used.
+        Only allowed when feature_derivation_window_start,
+        feature_derivation_window_end and feature_derivation_window_time_unit are not provided.
     prediction_point_rounding: int, optional
         Closest value of prediction_point_rounding_time_unit to round the prediction point
         into the past when applying the feature derivation window. Will be a positive integer,
@@ -128,6 +143,18 @@ class Relationship(object):
         One of ``datarobot.enums.AllowedTimeUnitsSAFER``
         Only applicable when dataset1_identifier is not provided.
 
+    The `feature_derivation_windows` is a list of dictionary with schema:
+        start: int
+            How many time_units of each dataset's primary temporal key into the past relative
+            to the datetimePartitionColumn the feature derivation window should begin.
+        end: int
+            How many timeUnits of each dataset's record
+            primary temporal key into the past relative to the datetimePartitionColumn the
+            feature derivation window should end.
+        unit: string
+            Time unit of the feature derivation window.
+            One of ``datarobot.enums.AllowedTimeUnitsSAFER``.
+
     Examples
     --------
     .. code-block:: python
@@ -161,6 +188,7 @@ class Relationship(object):
         feature_derivation_window_start=None,
         feature_derivation_window_end=None,
         feature_derivation_window_time_unit=None,
+        feature_derivation_windows=None,
         prediction_point_rounding=None,
         prediction_point_rounding_time_unit=None,
     ):
@@ -171,6 +199,7 @@ class Relationship(object):
         self.feature_derivation_window_start = feature_derivation_window_start
         self.feature_derivation_window_end = feature_derivation_window_end
         self.feature_derivation_window_time_unit = feature_derivation_window_time_unit
+        self.feature_derivation_windows = feature_derivation_windows
         self.prediction_point_rounding = prediction_point_rounding
         self.prediction_point_rounding_time_unit = prediction_point_rounding_time_unit
 
@@ -183,6 +212,7 @@ class Relationship(object):
             "feature_derivation_window_start": self.feature_derivation_window_start,
             "feature_derivation_window_end": self.feature_derivation_window_end,
             "feature_derivation_window_time_unit": self.feature_derivation_window_time_unit,
+            "feature_derivation_windows": self.feature_derivation_windows,
             "prediction_point_rounding": self.prediction_point_rounding,
             "prediction_point_rounding_time_unit": self.prediction_point_rounding_time_unit,
         }
@@ -201,6 +231,8 @@ class Relationship(object):
             payload["featureDerivationWindowEnd"] = self.feature_derivation_window_end
         if self.feature_derivation_window_time_unit:
             payload["featureDerivationWindowTimeUnit"] = self.feature_derivation_window_time_unit
+        if self.feature_derivation_windows is not None:
+            payload["featureDerivationWindows"] = self.feature_derivation_windows
         if self.prediction_point_rounding is not None:
             payload["predictionPointRounding"] = self.prediction_point_rounding
         if self.prediction_point_rounding_time_unit:
@@ -209,7 +241,7 @@ class Relationship(object):
 
 
 class SecondaryDataset(object):
-    """ A secondary dataset to be used for feature discovery
+    """A secondary dataset to be used for feature discovery
 
     .. versionadded:: v2.25
 
@@ -265,7 +297,7 @@ class SecondaryDataset(object):
 
 
 class FeatureDiscoverySetting(object):
-    """ A feature discovery settings used to customize the feature discovery process
+    """A feature discovery settings used to customize the feature discovery process
 
     To see the list of possible settings, create a RelationshipConfiguration without specifying
     settings and check its `feature_discovery_settings` attribute, which is a list of possible
