@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import abc
 from datetime import datetime
 
@@ -65,7 +76,7 @@ class PartitioningMethod(object):
 
     @abc.abstractmethod
     def collect_payload(self):
-        """ Set up the dict that should be sent to the server when setting the target
+        """Set up the dict that should be sent to the server when setting the target
         Returns
         -------
         partitioning_spec : dict
@@ -74,7 +85,7 @@ class PartitioningMethod(object):
 
     @abc.abstractmethod
     def prep_payload(self, project_id, max_wait=DEFAULT_MAX_WAIT):
-        """ Run any necessary validation and prep of the payload, including async operations
+        """Run any necessary validation and prep of the payload, including async operations
 
         Mainly used for the datetime partitioning spec but implemented in general for consistency
         """
@@ -210,7 +221,7 @@ class StratifiedCV(BaseCrossValidation):
 
 
 class GroupCV(BaseCrossValidation):
-    """ A partition in which one column is specified, and rows sharing a common value
+    """A partition in which one column is specified, and rows sharing a common value
     for that column are guaranteed to stay together in the partitioning into cross-validation
     groups and the holdout set.
 
@@ -237,7 +248,7 @@ class GroupCV(BaseCrossValidation):
 
 
 class UserCV(BaseCrossValidation):
-    """ A partition where the cross-validation folds and the holdout set are specified by
+    """A partition where the cross-validation folds and the holdout set are specified by
     the user.
 
     Parameters
@@ -360,7 +371,7 @@ class GroupTVH(BaseTVH):
 
 
 def construct_duration_string(years=0, months=0, days=0, hours=0, minutes=0, seconds=0):
-    """ Construct a valid string representing a duration in accordance with ISO8601
+    """Construct a valid string representing a duration in accordance with ISO8601
 
     A duration of six months, 3 days, and 12 hours could be represented as P6M3DT12H.
 
@@ -454,7 +465,7 @@ _feature_settings_converter = t.Dict(
 
 
 class FeatureSettings(object):
-    """ Per feature settings
+    """Per feature settings
 
     Attributes
     ----------
@@ -542,7 +553,7 @@ _start_end_backtest_fields = {
 
 
 class BacktestSpecification(object):
-    """ Uniquely defines a Backtest used in a DatetimePartitioning
+    """Uniquely defines a Backtest used in a DatetimePartitioning
 
     Includes only the attributes of a backtest directly controllable by users.  The other attributes
     are assigned by the DataRobot application based on the project dataset and the user-controlled
@@ -551,7 +562,7 @@ class BacktestSpecification(object):
     There are two ways to specify an individual backtest:
 
     Option 1: Use ``index``, ``gap_duration``, ``validation_start_date``, and
-    ``valiidation_duration``. All durations should be specified with a duration string such as those
+    ``validation_duration``. All durations should be specified with a duration string such as those
     returned by the :meth:`partitioning_methods.construct_duration_string
     <datarobot.helpers.partitioning_methods.construct_duration_string>` helper method.
 
@@ -666,7 +677,7 @@ class BacktestSpecification(object):
 
 
 class Backtest(object):
-    """ A backtest used to evaluate models trained in a datetime partitioned project
+    """A backtest used to evaluate models trained in a datetime partitioned project
 
     When setting up a datetime partitioning project, backtests are specified by a
     :class:`BacktestSpecification <datarobot.BacktestSpecification>`.
@@ -768,7 +779,7 @@ class Backtest(object):
         self.total_row_count = total_row_count
 
     def to_specification(self, use_start_end_format=False):
-        """ Render this backtest as a
+        """Render this backtest as a
         :class:`BacktestSpecification <datarobot.BacktestSpecification>`.
 
         The resulting specification includes only the attributes users can directly control, not
@@ -802,7 +813,7 @@ class Backtest(object):
             )
 
     def to_dataframe(self):
-        """ Render this backtest as a dataframe for convenience of display
+        """Render this backtest as a dataframe for convenience of display
 
         Returns
         -------
@@ -844,7 +855,7 @@ class Backtest(object):
 
 
 class DatetimePartitioningSpecification(PartitioningMethod):
-    """ Uniquely defines a DatetimePartitioning for some project
+    """Uniquely defines a DatetimePartitioning for some project
 
     Includes only the attributes of DatetimePartitioning that are directly controllable by users,
     not those determined by the DataRobot application based on the project dataset and the
@@ -1136,7 +1147,7 @@ class DatetimePartitioningSpecification(PartitioningMethod):
 
 
 class DatetimePartitioning(object):
-    """ Full partitioning of a project for datetime partitioning.
+    """Full partitioning of a project for datetime partitioning.
 
     To instantiate, use
     :meth:`DatetimePartitioning.get(project_id) <datarobot.DatetimePartitioning.get>`.
@@ -1506,7 +1517,7 @@ class DatetimePartitioning(object):
 
     @classmethod
     def generate(cls, project_id, spec, max_wait=DEFAULT_MAX_WAIT, target=None):
-        """ Preview the full partitioning determined by a DatetimePartitioningSpecification
+        """Preview the full partitioning determined by a DatetimePartitioningSpecification
 
         Based on the project dataset and the partitioning specification, inspect the full
         partitioning that would be used if the same specification were passed into
@@ -1546,7 +1557,7 @@ class DatetimePartitioning(object):
 
     @classmethod
     def get(cls, project_id):
-        """ Retrieve the DatetimePartitioning from a project
+        """Retrieve the DatetimePartitioning from a project
 
         Only available if the project has already set the target as a datetime project.
 
@@ -1565,7 +1576,7 @@ class DatetimePartitioning(object):
 
     @classmethod
     def generate_optimized(cls, project_id, spec, target, max_wait=DEFAULT_MAX_WAIT):
-        """ Preview the full partitioning determined by a DatetimePartitioningSpecification
+        """Preview the full partitioning determined by a DatetimePartitioningSpecification
 
         Based on the project dataset and the partitioning specification, inspect the full
         partitioning that would be used if the same specification were passed into
@@ -1602,7 +1613,7 @@ class DatetimePartitioning(object):
 
     @classmethod
     def get_optimized(cls, project_id, datetime_partitioning_id):
-        """ Retrieve an Optimized DatetimePartitioning from a project for the specified
+        """Retrieve an Optimized DatetimePartitioning from a project for the specified
         datetime_partitioning_id. A datetime_partitioning_id is created by using the
         :meth:`generate_optimized<datarobot.DatetimePartitioning.generate_optimized>` function.
 
@@ -1625,7 +1636,7 @@ class DatetimePartitioning(object):
 
     @classmethod
     def feature_log_list(cls, project_id, offset=None, limit=None):
-        """ Retrieve the feature derivation log content and log length for a time series project.
+        """Retrieve the feature derivation log content and log length for a time series project.
 
         The Time Series Feature Log provides details about the feature generation process for a
         time series project. It includes information about which features are generated and their
@@ -1671,7 +1682,7 @@ class DatetimePartitioning(object):
 
     @classmethod
     def feature_log_retrieve(cls, project_id):
-        """ Retrieve the feature derivation log content and log length for a time series project.
+        """Retrieve the feature derivation log content and log length for a time series project.
 
         The Time Series Feature Log provides details about the feature generation process for a
         time series project. It includes information about which features are generated and their
@@ -1713,7 +1724,7 @@ class DatetimePartitioning(object):
     def to_specification(
         self, use_holdout_start_end_format=False, use_backtest_start_end_format=False
     ):
-        """ Render the DatetimePartitioning as a :class:`DatetimePartitioningSpecification
+        """Render the DatetimePartitioning as a :class:`DatetimePartitioningSpecification
         <datarobot.DatetimePartitioningSpecification>`
 
         The resulting specification can be used when setting the target, and contains only the
@@ -1777,7 +1788,7 @@ class DatetimePartitioning(object):
         return DatetimePartitioningSpecification(**init_data)
 
     def to_dataframe(self):
-        """ Render the partitioning settings as a dataframe for convenience of display
+        """Render the partitioning settings as a dataframe for convenience of display
 
         Excludes project_id, datetime_partition_column, date_format,
         autopilot_data_selection_method, validation_duration,
