@@ -6,6 +6,9 @@ from .automated_documentation import AutomatedDocument
 from .batch_prediction_job import BatchPredictionJob, BatchPredictionJobDefinition
 from .blueprint import Blueprint, BlueprintChart, BlueprintTaskDocument, ModelBlueprintChart
 from .calendar_file import CalendarFile
+from .change_request import ChangeRequest, ChangeRequestReview
+from .cluster import Cluster
+from .cluster_insight import ClusterInsight
 from .compliance_doc_template import ComplianceDocTemplate
 from .compliance_documentation import ComplianceDocumentation
 from .connector import Connector
@@ -17,6 +20,7 @@ from .custom_model_version import CustomModelVersion, CustomModelVersionDependen
 from .custom_task import CustomTask
 from .custom_task_version import CustomTaskVersion
 from .data_drift import FeatureDrift, TargetDrift
+from .data_engine_query_generator import DataEngineQueryGenerator
 from .data_source import DataSource, DataSourceParameters
 from .data_store import DataStore
 from .dataset import Dataset, DatasetDetails
@@ -53,6 +57,7 @@ from .feature_effect import (
     FeatureEffectMetadataDatetime,
     FeatureEffectMetadataDatetimePerBacktest,
     FeatureEffects,
+    FeatureEffectsMulticlass,
 )
 from .feature_fit import (
     FeatureFit,
@@ -65,6 +70,8 @@ from .imported_model import ImportedModel
 from .job import FeatureImpactJob, Job, TrainingPredictionsJob
 from .model import (
     BlenderModel,
+    ClusteringModel,
+    CombinedModel,
     DatetimeModel,
     FrozenModel,
     Model,
@@ -92,6 +99,7 @@ from .recommended_model import ModelRecommendation
 from .relationships_configuration import RelationshipsConfiguration
 from .ruleset import Ruleset
 from .secondary_dataset import SecondaryDatasetConfigurations
+from .segmentation import SegmentationTask, SegmentInfo
 from .service_stats import ServiceStats, ServiceStatsOverTime
 from .shap_impact import ShapImpact
 from .shap_matrix import ShapMatrix
