@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import csv
 import datetime
 import io
@@ -115,6 +126,7 @@ class BatchPredictionJob(AbstractSpecificJob):
             t.Key("update_columns", optional=True): t.List(String),
             t.Key("where_columns", optional=True): t.List(String),
             t.Key("credential_id", optional=True): String(),
+            t.Key("create_table_if_not_exists", optional=True): t.Bool(),
         }
     )
 
@@ -213,7 +225,8 @@ class BatchPredictionJob(AbstractSpecificJob):
         intake_settings : dict (optional)
             A dict configuring how data is coming from. Supported options:
 
-                - type : string, either `localFile`, `s3`, `azure`, `gcp`, `dataset` or `jdbc`
+                - type : string, either `localFile`, `s3`, `azure`, `gcp`, `dataset`, `jdbc`
+                  `snowflake`, `synapse` or `bigquery`
 
             To score from a local file, add the this parameter to the
             settings:
@@ -252,7 +265,8 @@ class BatchPredictionJob(AbstractSpecificJob):
             A dict configuring how scored data is to be saved. Supported
             options:
 
-                - type : string, either `localFile`, `s3` or `jdbc`
+                - type : string, either `localFile`, `s3`, `azure`, `gcp`, `jdbc`,
+                  `snowflake`, `synapse` or `bigquery`
 
             To save scored data to a local file, add this parameters to the
             settings:
@@ -295,6 +309,9 @@ class BatchPredictionJob(AbstractSpecificJob):
                 - `credential_id` : string, the ID of the credentials holding information about
                   a user with write-access to the JDBC data source (see
                   :ref:`Credentials <credentials_api_doc>`).
+                - `create_table_if_not_exists` : bool (optional), If no existing table is detected,
+                  attempt to create it before writing data with the strategy defined in the
+                  statementType parameter.
 
         csv_settings : dict (optional)
             CSV intake and output settings. Supported options:
@@ -525,6 +542,9 @@ class BatchPredictionJob(AbstractSpecificJob):
 
         if intake_settings is None:
             intake_settings = {"type": "localFile"}
+        else:
+            # avoid mutating the input argument
+            intake_settings = dict(intake_settings)
 
         intake_file = None
 
@@ -539,6 +559,7 @@ class BatchPredictionJob(AbstractSpecificJob):
             "dataset",
             "snowflake",
             "synapse",
+            "bigquery",
         ):
             raise ValueError(
                 "Unsupported type parameter for intake_settings: {}".format(
@@ -589,6 +610,8 @@ class BatchPredictionJob(AbstractSpecificJob):
 
         if output_settings is None:
             output_settings = {"type": "localFile"}
+        else:
+            output_settings = dict(output_settings)
 
         output_file = None
 
@@ -602,6 +625,7 @@ class BatchPredictionJob(AbstractSpecificJob):
             "jdbc",
             "snowflake",
             "synapse",
+            "bigquery",
         ):
             raise ValueError(
                 "Unsupported type parameter for output_settings: {}".format(
@@ -706,7 +730,7 @@ class BatchPredictionJob(AbstractSpecificJob):
 
         Will block until the entire file is scored.
 
-        Refer to the `create` method for details on the other `kwargs`
+        Refer to the `score` method for details on the other `kwargs`
         parameters.
 
         Attributes
@@ -745,9 +769,9 @@ class BatchPredictionJob(AbstractSpecificJob):
 
         This returns immediately after the job has been created. You
         must poll for job completion using `get_status()` or
-        `wait_for_completion()`.
+        `wait_for_completion()` (see `datarobot.models.Job`)
 
-        Refer to the `create` method for details on the other `kwargs`
+        Refer to the `score` method for details on the other `kwargs`
         parameters.
 
         Attributes
@@ -796,9 +820,9 @@ class BatchPredictionJob(AbstractSpecificJob):
 
         This returns immediately after the job has been created. You
         must poll for job completion using `get_status()` or
-        `wait_for_completion()`.
+        `wait_for_completion()` (see `datarobot.models.Job`).
 
-        Refer to the `create` method for details on the other `kwargs`
+        Refer to the `score` method for details on the other `kwargs`
         parameters.
 
         Attributes
@@ -849,9 +873,9 @@ class BatchPredictionJob(AbstractSpecificJob):
 
         This returns immediately after the job has been created. You
         must poll for job completion using `get_status()` or
-        `wait_for_completion()`.
+        `wait_for_completion()` (see `datarobot.models.Job`).
 
-        Refer to the `create` method for details on the other `kwargs`
+        Refer to the `score` method for details on the other `kwargs`
         parameters.
 
         Attributes
@@ -931,7 +955,7 @@ class BatchPredictionJob(AbstractSpecificJob):
         This method blocks until the job has completed or raises an
         exception on errors.
 
-        Refer to the `create` method for details on the other `kwargs`
+        Refer to the `score` method for details on the other `kwargs`
         parameters.
 
         Attributes
@@ -1096,7 +1120,9 @@ class BatchPredictionJob(AbstractSpecificJob):
         """
         status = self._wait_for_download(timeout=timeout)
         download_iter = self._client.get(
-            status["links"]["download"], stream=True, timeout=read_timeout,
+            status["links"]["download"],
+            stream=True,
+            timeout=read_timeout,
         ).iter_content(chunk_size=8192)
 
         for chunk in download_iter:
@@ -1109,12 +1135,21 @@ class BatchPredictionJob(AbstractSpecificJob):
             raise RuntimeError("Job {0} was aborted: {1}".format(self.id, status["status_details"]))
 
     def _wait_for_download(self, timeout=120):
-        """ Waits for download to become available """
+        """Waits for download to become available"""
         start = time.time()
         status = None
         while True:
             status = self.get_status()
 
+            output_adapter_type = status["job_spec"].get("output_settings", {}).get("type")
+            if output_adapter_type and not output_adapter_type == "localFile":
+                raise RuntimeError(
+                    (
+                        "You cannot download predictions from jobs that did not use local_file as "
+                        "the output adapter. Job with ID {} had the output adapter defined as {}."
+                    ).format(self.id, output_adapter_type)
+                )
+
             if status["status"] in ("ABORTED", "FAILED"):
                 raise RuntimeError(
                     "Job {0} was aborted: {1}".format(self.id, status["status_details"])
@@ -1346,9 +1381,7 @@ class BatchPredictionJobDefinition(APIObject):
         )
 
     @classmethod
-    def create(
-        cls, enabled, batch_prediction_job, name=None, schedule=None,
-    ):
+    def create(cls, enabled, batch_prediction_job, name=None, schedule=None):
         """
         Creates a new batch prediction job definition to be run either at scheduled interval or as
         a manual run.
@@ -1472,15 +1505,16 @@ class BatchPredictionJobDefinition(APIObject):
         payload = {
             "name": name,
             "enabled": enabled,
-            "schedule": to_api(schedule),
         }
+
+        if schedule:
+            payload["schedule"] = (to_api(schedule),)
+
         payload.update(**job_spec)
 
         return cls.from_server_data(cls._client.post(cls._path, data=payload).json())
 
-    def update(
-        self, enabled, batch_prediction_job=None, name=None, schedule=None,
-    ):
+    def update(self, enabled, batch_prediction_job=None, name=None, schedule=None):
         """
         Updates a job definition with the changed specs.
 
