@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from functools import partial
 import json
 
@@ -74,7 +85,7 @@ def load_sections_from_path(path):
 
 
 class ComplianceDocTemplate(APIObject):
-    """ A :ref:`compliance documentation template <compliance_doc_template_overview>`. Templates
+    """A :ref:`compliance documentation template <compliance_doc_template_overview>`. Templates
     are used to customize contents of :class:`ComplianceDocumentation
     <datarobot.models.compliance_documentation.ComplianceDocumentation>`.
 
@@ -153,7 +164,7 @@ class ComplianceDocTemplate(APIObject):
 
     @classmethod
     def get_default(cls, template_type=None):
-        """ Get a default DataRobot template. This template is used for generating
+        """Get a default DataRobot template. This template is used for generating
         compliance documentation when no template is specified.
 
 
@@ -232,7 +243,7 @@ class ComplianceDocTemplate(APIObject):
 
     @classmethod
     def get(cls, template_id):
-        """ Retrieve a specific template.
+        """Retrieve a specific template.
 
         Parameters
         ----------
@@ -248,7 +259,7 @@ class ComplianceDocTemplate(APIObject):
 
     @classmethod
     def list(cls, name_part=None, limit=None, offset=None):
-        """ Get a paginated list of compliance documentation template objects.
+        """Get a paginated list of compliance documentation template objects.
 
         Parameters
         ----------
@@ -272,7 +283,7 @@ class ComplianceDocTemplate(APIObject):
         return [cls.from_server_data(item) for item in r_data["data"]]
 
     def sections_to_json_file(self, path, indent=2):
-        """ Save sections of the template to a json file at the specified path
+        """Save sections of the template to a json file at the specified path
 
         Parameters
         ----------
@@ -285,7 +296,7 @@ class ComplianceDocTemplate(APIObject):
             f.write(json.dumps(self.sections, indent=indent))
 
     def update(self, name=None, sections=None):
-        """ Update the name or sections of an existing doc template.
+        """Update the name or sections of an existing doc template.
 
         Note that default or non-existent templates can not be updated.
 
@@ -310,6 +321,5 @@ class ComplianceDocTemplate(APIObject):
             self.sections = sections
 
     def delete(self):
-        """ Delete the compliance documentation template.
-        """
+        """Delete the compliance documentation template."""
         self._client.delete(make_url(self._root_path, self.id))
