@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import six
@@ -257,7 +268,10 @@ class Credential(APIObject):
 
     @classmethod
     def create_azure(
-        cls, name, azure_connection_string, description=None,
+        cls,
+        name,
+        azure_connection_string,
+        description=None,
     ):
         """
         Creates the Azure storage credentials.
@@ -299,13 +313,19 @@ class Credential(APIObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             u"{}('{}', '{}', '{}')".format(
-                self.__class__.__name__, self.credential_id, self.name, self.credential_type,
+                self.__class__.__name__,
+                self.credential_id,
+                self.name,
+                self.credential_type,
             )
         )
 
     @classmethod
     def create_gcp(
-        cls, name, gcp_key=None, description=None,
+        cls,
+        name,
+        gcp_key=None,
+        description=None,
     ):
         """
         Creates the GCP credentials.
