@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import String
@@ -100,7 +111,11 @@ class CustomInferenceImage(APIObject):
         "Please use CustomModelVersions with base_environment_id",
     )
     def create(
-        cls, custom_model_id, custom_model_version_id, environment_id, environment_version_id=None,
+        cls,
+        custom_model_id,
+        custom_model_version_id,
+        environment_id,
+        environment_version_id=None,
     ):
         """Create a custom model image.
 
