@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -139,7 +150,8 @@ class _CustomModelBase(APIObject):
 
     @classmethod
     def copy_custom_model(
-        cls, custom_model_id,
+        cls,
+        custom_model_id,
     ):
         path = "{}fromCustomModel/".format(cls._path)
         response = cls._client.post(path, data={"custom_model_id": custom_model_id})
@@ -294,7 +306,10 @@ class CustomInferenceModel(_CustomModelBase):
 
     @classmethod
     def list(
-        cls, is_deployed=None, search_for=None, order_by=None,
+        cls,
+        is_deployed=None,
+        search_for=None,
+        order_by=None,
     ):
         """List custom inference models available to the user.
 
@@ -473,7 +488,8 @@ class CustomInferenceModel(_CustomModelBase):
 
     @classmethod
     def copy_custom_model(
-        cls, custom_model_id,
+        cls,
+        custom_model_id,
     ):
         """Create a custom inference model by copying existing one.
 
