@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import time
 
 import trafaret as t
@@ -20,10 +31,6 @@ class CustomModelTest(APIObject):
     ----------
     id: str
         test id
-    dataset_id: str
-        id of a dataset used for testing
-    dataset_version_id: str
-        id of a dataset version used for testing
     custom_model_image_id: str
         id of a custom model image
     image_type: str
@@ -46,6 +53,10 @@ class CustomModelTest(APIObject):
         The values are dict with 'message' and 'status' keys.
     created_by: str
         a user who created a test
+    dataset_id: str, optional
+        id of a dataset used for testing
+    dataset_version_id: str, optional
+        id of a dataset version used for testing
     completed_at: str, optional
         ISO-8601 formatted timestamp of when the test has completed
     created_at: str, optional
@@ -64,8 +75,6 @@ class CustomModelTest(APIObject):
     _converter = t.Dict(
         {
             t.Key("id"): String(),
-            t.Key("dataset_id"): String(),
-            t.Key("dataset_version_id"): String(),
             t.Key("custom_model_image_id"): String(),
             t.Key("image_type"): t.Enum(*CUSTOM_MODEL_IMAGE_TYPE.ALL),
             t.Key("overall_status"): String(),
@@ -84,6 +93,8 @@ class CustomModelTest(APIObject):
                 }
             ).allow_extra("*"),
             t.Key("created_by"): String(),
+            t.Key("dataset_id", optional=True): String(),
+            t.Key("dataset_version_id", optional=True): String(),
             t.Key("completed_at", optional=True): String(allow_blank=True),
             t.Key("created", optional=True) >> "created_at": String(),
             t.Key("network_egress_policy", optional=True): t.Enum(*NETWORK_EGRESS_POLICY.ALL),
@@ -101,13 +112,13 @@ class CustomModelTest(APIObject):
     def _set_values(
         self,
         id,
-        dataset_id,
-        dataset_version_id,
         custom_model_image_id,
         image_type,
         overall_status,
         detailed_status,
         created_by,
+        dataset_id=None,
+        dataset_version_id=None,
         completed_at=None,
         created_at=None,
         network_egress_policy=None,
@@ -133,7 +144,7 @@ class CustomModelTest(APIObject):
         cls,
         custom_model_id,
         custom_model_version_id,
-        dataset_id,
+        dataset_id=None,
         environment_id=None,
         environment_version_id=None,
         max_wait=DEFAULT_MAX_WAIT,
@@ -151,8 +162,9 @@ class CustomModelTest(APIObject):
             the id of the custom model
         custom_model_version_id: str
             the id of the custom model version
-        dataset_id: str
-            the id of the testing dataset
+        dataset_id: str, optional
+            The id of the testing dataset for non-unstructured custom models.
+            Ignored and not required for unstructured models.
         environment_id: str, optional
             the id of the execution environment.
             If specified, the environment will be used as is; if the custom model version
@@ -188,8 +200,8 @@ class CustomModelTest(APIObject):
         payload = {
             "custom_model_id": custom_model_id,
             "custom_model_version_id": custom_model_version_id,
-            "dataset_id": dataset_id,
         }
+
         if environment_id or environment_version_id:
             deprecation_warning(
                 "Specifying an environment to use for testing has been deprecated",
@@ -197,6 +209,8 @@ class CustomModelTest(APIObject):
                 will_remove_version="v2.24",
             )
 
+        if dataset_id:
+            payload["dataset_id"] = dataset_id
         if environment_id:
             payload["environment_id"] = environment_id
         if environment_version_id:
