@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import copy
 import json
 import os
@@ -42,7 +53,9 @@ class RequiredMetadataValue(APIObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             u"{}(field_name={!r}, value={!r})".format(
-                self.__class__.__name__, self.field_name, self.value,
+                self.__class__.__name__,
+                self.field_name,
+                self.value,
             )
         )
 
@@ -86,7 +99,12 @@ class CustomModelFileItem(APIObject):
     schema = _converter
 
     def __init__(
-        self, id, file_name, file_path, file_source, created_at=None,
+        self,
+        id,
+        file_name,
+        file_path,
+        file_source,
+        created_at=None,
     ):
         self.id = id
         self.file_name = file_name
@@ -143,7 +161,12 @@ class CustomModelVersionDependencyBuild(APIObject):
         )
 
     def _set_values(
-        self, custom_model_id, custom_model_version_id, build_status, started_at, completed_at=None,
+        self,
+        custom_model_id,
+        custom_model_version_id,
+        build_status,
+        started_at,
+        completed_at=None,
     ):
         self.custom_model_id = custom_model_id
         self.custom_model_version_id = custom_model_version_id
@@ -301,7 +324,9 @@ class CustomDependencyConstraint(APIObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             u"{}(constraint_type={!r}, version={!r})".format(
-                self.__class__.__name__, self.constraint_type, self.version,
+                self.__class__.__name__,
+                self.constraint_type,
+                self.version,
             )
         )
 
@@ -344,7 +369,9 @@ class CustomDependency(APIObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             u"{}(package_name={!r}, constraints={!r})".format(
-                self.__class__.__name__, self.package_name, self.constraints,
+                self.__class__.__name__,
+                self.package_name,
+                self.constraints,
             )
         )
 
