@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 import os
 
@@ -12,8 +23,12 @@ from datarobot.models.custom_model_version import (
     CustomModelFileItem,
     RequiredMetadataValue,
 )
+from datarobot.models.custom_task_version_dependency_build import CustomTaskVersionDependencyBuild
+from datarobot.models.trafarets import UserBlueprintTaskArgument_
+from datarobot.models.user_blueprints.models import UserBlueprintTaskArgument
 from datarobot.utils import camelize, deprecation_warning, encode_utf8_if_py2
 from datarobot.utils.pagination import unpaginate
+from datarobot.utils.waiters import wait_for_custom_resolution
 
 
 class CustomTaskFileItem(CustomModelFileItem):
@@ -89,9 +104,13 @@ class CustomTaskVersion(APIObject):
     required_metadata_values: List[RequiredMetadataValue]
         Additional parameters required by the execution environment. The required keys are
         defined by the fieldNames in the base environment's requiredMetadataKeys.
+    arguments: List[UserBlueprintTaskArgument]
+        A list of custom task version arguments.
     """
 
     _path = "customTasks/{}/versions/"
+    _dependency_build_path = "customTasks/{}/versions/{}/dependencyBuild/"
+    _dependency_build_log_path = "customTasks/{}/versions/{}/dependencyBuildLog/"
 
     _converter = t.Dict(
         {
@@ -106,11 +125,13 @@ class CustomTaskVersion(APIObject):
             # because `from_server_data` scrubs Nones, this must be optional here.
             t.Key("description", optional=True): String(max_length=10000, allow_blank=True)
             | t.Null(),
+            t.Key("maximum_memory", optional=True): Int(),
             t.Key("required_metadata", optional=True): t.Mapping(String(), String()),
             t.Key("base_environment_id", optional=True): String() | t.Null(),
             t.Key("base_environment_version_id", optional=True): String() | t.Null(),
             t.Key("dependencies", optional=True): t.List(CustomDependency.schema),
             t.Key("required_metadata_values", optional=True): t.List(RequiredMetadataValue.schema),
+            t.Key("arguments", optional=True): t.List(UserBlueprintTaskArgument_),
         }
     ).ignore_extra("*")
 
@@ -129,12 +150,15 @@ class CustomTaskVersion(APIObject):
         description=None,
         required_metadata=None,
         base_environment_id=None,
+        maximum_memory=None,
         base_environment_version_id=None,
         dependencies=None,
         required_metadata_values=None,
+        arguments=None,
     ):
         if dependencies is None:
             dependencies = []
+        arguments = arguments or []
 
         self.id = id
         self.custom_task_id = custom_task_id
@@ -147,6 +171,7 @@ class CustomTaskVersion(APIObject):
         self.items = [CustomTaskFileItem(**data) for data in items]
 
         self.required_metadata = required_metadata
+        self.maximum_memory = maximum_memory
         self.required_metadata_values = (
             [RequiredMetadataValue(**val) for val in required_metadata_values]
             if required_metadata_values
@@ -155,6 +180,7 @@ class CustomTaskVersion(APIObject):
         self.base_environment_id = base_environment_id
         self.base_environment_version_id = base_environment_version_id
         self.dependencies = [CustomDependency(**data) for data in dependencies]
+        self.arguments = [UserBlueprintTaskArgument(**argument) for argument in arguments]
 
     def __repr__(self):
         return encode_utf8_if_py2(
@@ -190,6 +216,7 @@ class CustomTaskVersion(APIObject):
         cls,
         custom_task_id,
         base_environment_id,
+        maximum_memory=None,
         is_major_update=True,
         folder_path=None,
         required_metadata=None,
@@ -222,6 +249,8 @@ class CustomTaskVersion(APIObject):
         required_metadata_values: List[RequiredMetadataValue]
             Additional parameters required by the execution environment. The required keys are
             defined by the fieldNames in the base environment's requiredMetadataKeys.
+        maximum_memory: int
+            A number in bytes about how much memory custom tasks' inference containers can run with.
 
         Returns
         -------
@@ -241,6 +270,7 @@ class CustomTaskVersion(APIObject):
             is_major_update,
             base_environment_id,
             folder_path,
+            maximum_memory=maximum_memory,
             required_metadata=required_metadata,
             required_metadata_values=required_metadata_values,
         )
@@ -255,6 +285,7 @@ class CustomTaskVersion(APIObject):
         files_to_delete=None,
         required_metadata=None,
         required_metadata_values=None,
+        maximum_memory=None,
     ):
         """Create a custom task version containing files from a previous version.
 
@@ -286,6 +317,8 @@ class CustomTaskVersion(APIObject):
         required_metadata_values: List[RequiredMetadataValue]
             Additional parameters required by the execution environment. The required keys are
             defined by the fieldNames in the base environment's requiredMetadataKeys.
+        maximum_memory: int
+            A number in bytes about how much memory custom tasks' inference containers can run with.
 
         Returns
         -------
@@ -305,6 +338,7 @@ class CustomTaskVersion(APIObject):
             is_major_update,
             base_environment_id,
             folder_path,
+            maximum_memory,
             files_to_delete=files_to_delete,
             required_metadata=required_metadata,
             required_metadata_values=required_metadata_values,
@@ -318,6 +352,7 @@ class CustomTaskVersion(APIObject):
         is_major_update,
         base_environment_id,
         folder_path=None,
+        maximum_memory=None,
         files_to_delete=None,
         required_metadata=None,
         required_metadata_values=None,
@@ -357,6 +392,9 @@ class CustomTaskVersion(APIObject):
                 )
             )
 
+        if maximum_memory:
+            upload_data.append(("maximumMemory", str(maximum_memory)))
+
         cls._verify_folder_path(folder_path)
 
         with contextlib2.ExitStack() as stack:
@@ -530,3 +568,108 @@ class CustomTaskVersion(APIObject):
 
         new_object = self.get(self.custom_task_id, self.id)
         self._update_values(new_object)
+
+    def start_dependency_build(self):
+        """Start the dependency build for a custom task version and return build status.
+        .. versionadded:: v2.27
+
+        Returns
+        -------
+        CustomTaskVersionDependencyBuild
+            DTO of custom task version dependency build.
+        """
+        url = self._dependency_build_path.format(self.custom_task_id, self.id)
+        response = self._client.post(url)
+        server_data = response.json()
+        return CustomTaskVersionDependencyBuild.from_server_data(server_data)
+
+    def start_dependency_build_and_wait(self, max_wait):
+        """Start the dependency build for a custom task version and wait while pulling status.
+        .. versionadded:: v2.27
+
+        Parameters
+        ----------
+        max_wait: int
+            max time to wait for a build completion
+
+        Returns
+        -------
+        CustomTaskVersionDependencyBuild
+            DTO of custom task version dependency build.
+
+        Raises
+        ------
+        datarobot.errors.ClientError
+            if the server responded with 4xx status
+        datarobot.errors.ServerError
+            if the server responded with 5xx status
+        datarobot.errors.AsyncTimeoutError
+            Raised if the dependency build is not finished after max_wait.
+        """
+        custom_task_id = self.custom_task_id
+        custom_task_version_id = self.id
+
+        def build_complete(response):
+            server_data = response.json()
+            if server_data["buildStatus"] in ["success", "failed"]:
+                return CustomTaskVersionDependencyBuild.from_server_data(server_data)
+            return None
+
+        url = self._dependency_build_path.format(custom_task_id, custom_task_version_id)
+        self._client.post(url)
+        return wait_for_custom_resolution(self._client, url, build_complete, max_wait)
+
+    def cancel_dependency_build(self):
+        """Cancel custom task version dependency build that is in progress.
+        .. versionadded:: v2.27
+
+        Raises
+        ------
+        datarobot.errors.ClientError
+            if the server responded with 4xx status
+        datarobot.errors.ServerError
+            if the server responded with 5xx status
+        """
+
+        url = self._dependency_build_path.format(self.custom_task_id, self.id)
+        self._client.delete(url)
+
+    def get_dependency_build(self):
+        """Retrieve information about a custom task version's dependency build.
+        .. versionadded:: v2.27
+
+        Returns
+        -------
+        CustomTaskVersionDependencyBuild
+            DTO of custom task version dependency build.
+        """
+
+        url = self._dependency_build_path.format(self.custom_task_id, self.id)
+        response = self._client.get(url)
+        server_data = response.json()
+        return CustomTaskVersionDependencyBuild.from_server_data(server_data)
+
+    def download_dependency_build_log(self, file_directory="."):
+        """Get log of a custom task version dependency build.
+        .. versionadded:: v2.27
+
+        Parameters
+        ----------
+        file_directory: str (optional, default is ".")
+            Directory path where downloaded file is to save.
+
+        Raises
+        ------
+        datarobot.errors.ClientError
+            if the server responded with 4xx status
+        datarobot.errors.ServerError
+            if the server responded with 5xx status
+        """
+
+        url = self._dependency_build_log_path.format(self.custom_task_id, self.id)
+        response = self._client.get(url)
+        content_disposition = response.headers["Content-Disposition"]
+        fiie_name = content_disposition[len("attachment; filename=") :]
+        with open(os.path.join(file_directory, fiie_name), "wb") as f:
+            for chunk in response.iter_content(chunk_size=1024 * 1024):
+                f.write(chunk)
