@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from collections import namedtuple
 import os
 
@@ -43,7 +54,7 @@ _base_dataset_schema = t.Dict(
 
 
 class Dataset(APIObject):
-    """ Represents a Dataset returned from the api/v2/datasets/ endpoints.
+    """Represents a Dataset returned from the api/v2/datasets/ endpoints.
 
     Attributes
     ----------
@@ -234,7 +245,10 @@ class Dataset(APIObject):
         else:
             buff = list_of_records_to_buffer(records)
         return cls.create_from_file(
-            filelike=buff, categories=categories, read_timeout=read_timeout, max_wait=max_wait,
+            filelike=buff,
+            categories=categories,
+            read_timeout=read_timeout,
+            max_wait=max_wait,
         )
 
     @classmethod
@@ -381,6 +395,52 @@ class Dataset(APIObject):
         )
         return cls.from_location(new_dataset_location)
 
+    @classmethod
+    def create_from_query_generator(
+        cls, generator_id, dataset_id=None, dataset_version_id=None, max_wait=DEFAULT_MAX_WAIT
+    ):
+        """
+        A blocking call that creates a new Dataset from the query generator.
+        Returns when the dataset has been successfully processed. If optional
+        parameters are not specified the query is applied to the dataset_id
+        and dataset_version_id stored in the query generator. If specified they
+        will override the stored dataset_id/dataset_version_id, e.g. to prep a
+        prediction dataset.
+
+        Parameters
+        ----------
+        generator_id: str
+            The id of the query generator to use.
+        dataset_id: str, optional
+            The id of the dataset to apply the query to.
+        dataset_version_id: str, optional
+            The id of the dataset version to apply the query to. If not specified the
+            latest version associated with dataset_id (if specified) is used.
+        max_wait : int
+            optional, the maximum number of seconds to wait before giving up.
+
+        Returns
+        -------
+        response: Dataset
+            The Dataset created from the query generator
+        """
+        url = "dataEngineWorkspaceStates/fromDataEngineQueryGenerator/"
+        base_data = {
+            "query_generator_id": generator_id,
+            "dataset_id": dataset_id,
+            "dataset_version_id": dataset_version_id,
+        }
+        data = _remove_empty_params(base_data)
+        response = cls._client.post(url, data=data)
+        workspace_id = response.json()["workspaceStateId"]
+
+        url = "{}fromDataEngineWorkspaceState/".format(cls._path)
+        response = cls._client.post(url, data={"workspace_state_id": workspace_id})
+        new_dataset_location = wait_for_async_resolution(
+            cls._client, response.headers["Location"], max_wait
+        )
+        return cls.from_location(new_dataset_location)
+
     @classmethod
     def get(cls, dataset_id):
         """Get information about a dataset.
@@ -647,7 +707,7 @@ class Dataset(APIObject):
         return [DatasetFeaturelist.from_server_data(el) for el in result]
 
     def create_featurelist(self, name, features):
-        """ Create a new dataset featurelist
+        """Create a new dataset featurelist
 
         Parameters
         ----------
@@ -1038,7 +1098,7 @@ def _safe_merge(first, second):
 
 
 class DatasetDetails(APIObject):
-    """ Represents a detailed view of a Dataset. The `to_dataset` method creates a Dataset
+    """Represents a detailed view of a Dataset. The `to_dataset` method creates a Dataset
     from this details view.
 
     Attributes
@@ -1120,7 +1180,7 @@ class DatasetDetails(APIObject):
             t.Key("data_engine_query_id", optional=True): String,
             t.Key("data_source_id", optional=True): String,
             t.Key("data_source_type"): String(allow_blank=True),
-            t.Key("description", optional=True): String,
+            t.Key("description", optional=True): String(allow_blank=True),
             t.Key("eda1_modification_date", optional=True): t.Call(
                 lambda s: dateutil.parser.parse(s)
             ),
