@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -216,7 +227,10 @@ class AccuracyOverTimePlotsMetadata(DatetimeTrendPlotsMetadataObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             "{}(project_id={}, model_id={}, forecast_distance={})".format(
-                self.__class__.__name__, self.project_id, self.model_id, self.forecast_distance,
+                self.__class__.__name__,
+                self.project_id,
+                self.model_id,
+                self.forecast_distance,
             )
         )
 
@@ -477,7 +491,9 @@ class ForecastVsActualPlotsMetadata(DatetimeTrendPlotsMetadataObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             "{}(project_id={}, model_id={})".format(
-                self.__class__.__name__, self.project_id, self.model_id,
+                self.__class__.__name__,
+                self.project_id,
+                self.model_id,
             )
         )
 
@@ -800,7 +816,14 @@ class AnomalyOverTimePlot(DatetimeTrendPlotsAPIObject):
     ).ignore_extra("*")
 
     def __init__(
-        self, project_id, model_id, start_date, end_date, resolution, bins, calendar_events,
+        self,
+        project_id,
+        model_id,
+        start_date,
+        end_date,
+        resolution,
+        bins,
+        calendar_events,
     ):
         self.project_id = project_id
         self.model_id = model_id
