@@ -1,7 +1,17 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from collections import defaultdict
 from datetime import datetime
 
-import attr
 import dateutil
 import pandas as pd
 import pytz
@@ -35,6 +45,8 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         the description of the deployment
     default_prediction_server : dict
         information on the default prediction server of the deployment
+    importance : str, optional
+        deployment importance
     model : dict
         information on the model of the deployment
     capabilities : dict
@@ -49,6 +61,14 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         information on the model health of the deployment
     accuracy_health : dict
         information on the accuracy health of the deployment
+    fairness_health : dict
+        information on the fairness health of a deployment
+    governance : dict
+        information on approval and change requests of a deployment
+    owners : dict
+        information on the owners of a deployment
+    prediction_environment : dict
+        information on the prediction environment of a deployment
     """
 
     _path = "deployments/"
@@ -93,6 +113,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             t.Key("label", optional=True): String(allow_blank=True),
             t.Key("description", optional=True): String(allow_blank=True) | t.Null(),
             t.Key("default_prediction_server", optional=True): _default_prediction_server_converter,
+            t.Key("importance", optional=True): String() | t.Null(),
             t.Key("model", optional=True): _model_converter,
             t.Key("capabilities", optional=True): _capabilities,
             t.Key("prediction_usage", optional=True): _prediction_usage,
@@ -100,6 +121,10 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             t.Key("service_health", optional=True): _health,
             t.Key("model_health", optional=True): _health,
             t.Key("accuracy_health", optional=True): _health,
+            t.Key("fairness_health", optional=True): _health,
+            t.Key("governance", optional=True): t.Dict().allow_extra("*"),
+            t.Key("owners", optional=True): t.Dict().allow_extra("*"),
+            t.Key("prediction_environment", optional=True): t.Dict().allow_extra("*"),
         }
     ).allow_extra("*")
 
@@ -116,6 +141,11 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         service_health=None,
         model_health=None,
         accuracy_health=None,
+        importance=None,
+        fairness_health=None,
+        governance=None,
+        owners=None,
+        prediction_environment=None,
     ):
         self.id = id
         self.label = label
@@ -128,13 +158,24 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         self.service_health = service_health
         self.model_health = model_health
         self.accuracy_health = accuracy_health
+        self.importance = importance
+        self.fairness_health = fairness_health
+        self.governance = governance
+        self.owners = owners
+        self.prediction_environment = prediction_environment
 
     def __repr__(self):
         return encode_utf8_if_py2(u"{}({})".format(self.__class__.__name__, self.label or self.id))
 
     @classmethod
     def create_from_learning_model(
-        cls, model_id, label, description=None, default_prediction_server_id=None
+        cls,
+        model_id,
+        label,
+        description=None,
+        default_prediction_server_id=None,
+        importance=None,
+        prediction_threshold=None,
     ):
         """Create a deployment from a DataRobot model.
 
@@ -150,6 +191,10 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             a human readable description of the deployment
         default_prediction_server_id : str, optional
             an identifier of a prediction server to be used as the default prediction server
+        importance : str, optional
+            deployment importance
+        prediction_threshold : float, optional
+            threshold used for binary classification in predictions
 
         Returns
         -------
@@ -171,6 +216,10 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         payload = {"model_id": model_id, "label": label, "description": description}
         if default_prediction_server_id:
             payload["default_prediction_server_id"] = default_prediction_server_id
+        if importance:
+            payload["importance"] = importance
+        if prediction_threshold is not None:
+            payload["prediction_threshold"] = prediction_threshold
 
         url = "{}fromLearningModel/".format(cls._path)
         deployment_id = cls._client.post(url, data=payload).json()["id"]
@@ -185,6 +234,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         description=None,
         default_prediction_server_id=None,
         max_wait=DEFAULT_MAX_WAIT,
+        importance=None,
     ):
         # check if model package of the custom model image is already created
         existing_model_packages = unpaginate(
@@ -216,6 +266,8 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         }
         if default_prediction_server_id:
             deployment_payload["default_prediction_server_id"] = default_prediction_server_id
+        if importance:
+            deployment_payload["importance"] = importance
         response = cls._client.post(
             "{}fromModelPackage/".format(cls._path), data=deployment_payload
         )
@@ -281,6 +333,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         description=None,
         default_prediction_server_id=None,
         max_wait=DEFAULT_MAX_WAIT,
+        importance=None,
     ):
         """Create a deployment from a DataRobot custom model image.
 
@@ -299,6 +352,8 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             seconds to wait for successful resolution of a deployment creation job.
             Deployment supports making predictions only after a deployment creating job
             has successfully finished
+        importance : str, optional
+            deployment importance
 
         Returns
         -------
@@ -313,6 +368,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             description=description,
             default_prediction_server_id=default_prediction_server_id,
             max_wait=max_wait,
+            importance=importance,
         )
 
     @classmethod
@@ -364,7 +420,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         .. code-block:: python
 
             from datarobot import Deployment
-            from datarobot.enums import DEPLOYMENT_SERVICE_HEALTH
+            from datarobot.enums import DEPLOYMENT_SERVICE_HEALTH_STATUS
             filters = DeploymentListFilters(
                 role='OWNER',
                 service_health=[DEPLOYMENT_SERVICE_HEALTH.FAILING]
@@ -416,7 +472,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         path = "{}{}/".format(cls._path, deployment_id)
         return cls.from_location(path)
 
-    def update(self, label=None, description=None):
+    def update(self, label=None, description=None, importance=None):
         """
         Update the label and description of this deployment.
 
@@ -428,6 +484,8 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             payload["label"] = label
         if description:
             payload["description"] = description
+        if importance:
+            payload["importance"] = importance
         if not payload:
             raise ValueError("")
 
@@ -451,7 +509,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
 
     def replace_model(self, new_model_id, reason, max_wait=600):
         """Replace the model used in this deployment. To confirm model replacement eligibility, use
-         :meth:`~datarobot.Deployment.validate_replacement_model` beforehand.
+         :meth:`~datarobot.models.Deployment.validate_replacement_model` beforehand.
 
         .. versionadded:: v2.17
 
@@ -481,6 +539,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         .. code-block:: python
 
             from datarobot import Deployment
+            from datarobot.enums import MODEL_REPLACEMENT_REASON
             deployment = Deployment.get(deployment_id='5c939e08962d741e34f609f0')
             deployment.model['id'], deployment.model['type']
             >>>('5c0a979859b00004ba52e431', 'Decision Tree Classifier (Gini)')
@@ -528,9 +587,10 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         -------
         status : str
             status of the validation, will be one of 'passing', 'warning' or 'failing'.
-            If the status is passing or warning, use :meth:`~datarobot.Deployment.replace_model` to
-            perform a model replacement. If the status is failing, refer to ``checks`` for more
-            detail on why the new model cannot be used as a replacement.
+            If the status is passing or warning, use
+            :meth:`~datarobot.models.Deployment.replace_model` to perform a model replacement. If
+            the status is failing, refer to ``checks`` for more detail on why the new model cannot
+            be used as a replacement.
         message : str
             message for the validation result
         checks : dict
@@ -668,6 +728,202 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             response = self._client.post(url, data={"data": payload})
             wait_for_async_resolution(self._client, response.headers["Location"])
 
+    def get_predictions_by_forecast_date_settings(self):
+        """Retrieve predictions by forecast date settings of this deployment.
+
+        .. versionadded:: v2.27
+
+        Returns
+        -------
+        settings : dict
+            Predictions by forecast date settings of the deployment is a dict with the following
+            format:
+
+            enabled : bool
+                Is ''True'' if predictions by forecast date is enabled for this deployment.
+                To update this setting, see
+                :meth:`~datarobot.models.Deployment.update_predictions_by_forecast_date_settings`
+
+            column_name : string
+                The column name in prediction datasets to be used as forecast date.
+
+            datetime_format : string
+                The datetime format of the forecast date column in prediction datasets.
+        """
+
+        url = "{}{}/settings/".format(self._path, self.id)
+        response_json = from_api(self._client.get(url).json())
+        return response_json.get("predictions_by_forecast_date")
+
+    def update_predictions_by_forecast_date_settings(
+        self,
+        enable_predictions_by_forecast_date,
+        forecast_date_column_name=None,
+        forecast_date_format=None,
+        max_wait=DEFAULT_MAX_WAIT,
+    ):
+        """Update predictions by forecast date settings of this deployment.
+
+        .. versionadded:: v2.27
+
+        Updating predictions by forecast date setting is an asynchronous process,
+        which means some preparatory work may be performed after the initial request is completed.
+        This function will not return until all preparatory work is fully finished.
+
+        Example
+        -------
+        To set predictions by forecast date settings to the same default settings you see when using
+        the DataRobot web application, you use your ''Deployment'' object like this:
+
+            >>> deployment.update_predictions_by_forecast_date_settings(
+            >>>    enable_predictions_by_forecast_date=True,
+            >>>    forecast_date_column_name="date (actual)",
+            >>>    forecast_date_format="%Y-%m-%d")
+
+        Parameters
+        ----------
+        enable_predictions_by_forecast_date : bool
+            set to ''True'' if predictions by forecast date is to be turned on or set to ''False''
+            if predictions by forecast date is to be turned off.
+
+        forecast_date_column_name: string, optional
+            The column name in prediction datasets to be used as forecast date.
+            If ''enable_predictions_by_forecast_date'' is set to ''False'',
+            then the parameter will be ignored.
+
+        forecast_date_format: string, optional
+            The datetime format of the forecast date column in prediction datasets.
+            If ''enable_predictions_by_forecast_date'' is set to ''False'',
+            then the parameter will be ignored.
+
+        max_wait : int, optional
+            seconds to wait for successful
+        """
+
+        payload = defaultdict(dict)
+        payload["predictions_by_forecast_date"]["enabled"] = enable_predictions_by_forecast_date
+        if enable_predictions_by_forecast_date:
+            assert forecast_date_column_name, (
+                "Please specify 'forecast_date_column_name' or set "
+                "'enable_predictions_by_forecast_date' to False"
+            )
+            assert forecast_date_format, (
+                "Please specify 'forecast_date_format' or set "
+                "'enable_predictions_by_forecast_date' to False"
+            )
+            payload["predictions_by_forecast_date"]["column_name"] = forecast_date_column_name
+            payload["predictions_by_forecast_date"]["datetime_format"] = forecast_date_format
+
+        url = "{}{}/settings/".format(self._path, self.id)
+        response = self._client.patch(url, data=payload)
+        wait_for_async_resolution(self._client, response.headers["Location"], max_wait)
+
+    def get_challenger_models_settings(self):
+        """Retrieve challenger models settings of this deployment.
+
+        .. versionadded:: v2.27
+
+        Returns
+        -------
+        settings : dict
+            Challenger models settings of the deployment is a dict with the following format:
+
+            enabled : bool
+                Is ''True'' if challenger models is enabled for this deployment. To update
+                existing ''challenger_models'' settings, see
+                :meth:`~datarobot.models.Deployment.update_challenger_models_settings`
+        """
+
+        url = "{}{}/settings/".format(self._path, self.id)
+        response_json = from_api(self._client.get(url).json())
+        return response_json.get("challenger_models")
+
+    def update_challenger_models_settings(
+        self, challenger_models_enabled, max_wait=DEFAULT_MAX_WAIT
+    ):
+        """Update challenger models settings of this deployment.
+
+        .. versionadded:: v2.27
+
+        Updating challenger models setting is an asynchronous process, which means some preparatory
+        work may be performed after the initial request is completed. This function will not return
+        until all preparatory work is fully finished.
+
+        Parameters
+        ----------
+        challenger_models_enabled : bool
+            set to ''True'' if challenger models is to be turned on or set to ''False'' if
+            challenger models is to be turned off
+        max_wait : int, optional
+            seconds to wait for successful resolution
+        """
+
+        payload = defaultdict(dict)
+        payload["challenger_models"]["enabled"] = challenger_models_enabled
+        url = "{}{}/settings/".format(self._path, self.id)
+        response = self._client.patch(url, data=payload)
+        wait_for_async_resolution(self._client, response.headers["Location"], max_wait)
+
+    def get_segment_analysis_settings(self):
+        """Retrieve segment analysis settings of this deployment.
+
+        .. versionadded:: v2.27
+
+        Returns
+        -------
+        settings : dict
+            Segment analysis settings of the deployment containing two items with keys
+            ``enabled`` and ``attributes``, which are further described below.
+
+            enabled : bool
+                Set to ''True'' if segment analysis is enabled for this deployment. To update
+                existing setting, see
+                :meth:`~datarobot.models.Deployment.update_segment_analysis_settings`
+
+            attributes : list
+                To create or update existing segment analysis attributes, see
+                :meth:`~datarobot.models.Deployment.update_segment_analysis_settings`
+        """
+
+        url = "{}{}/settings/".format(self._path, self.id)
+        response_json = from_api(self._client.get(url).json())
+        return response_json.get("segment_analysis")
+
+    def update_segment_analysis_settings(
+        self,
+        segment_analysis_enabled,
+        segment_analysis_attributes=None,
+        max_wait=DEFAULT_MAX_WAIT,
+    ):
+        """Update segment analysis settings of this deployment.
+
+        .. versionadded:: v2.27
+
+        Updating segment analysis setting is an asynchronous process, which means some preparatory
+        work may be performed after the initial request is completed. This function will not return
+        until all preparatory work is fully finished.
+
+        Parameters
+        ----------
+        segment_analysis_enabled : bool
+            set to ''True'' if segment analysis is to be turned on or set to ''False'' if
+            segment analysis is to be turned off
+
+        segment_analysis_attributes: list, optional
+            A list of strings that gives the segment attributes selected for tracking.
+
+        max_wait : int, optional
+            seconds to wait for successful resolution
+        """
+
+        payload = defaultdict(dict)
+        payload["segment_analysis"]["enabled"] = segment_analysis_enabled
+        if segment_analysis_attributes:
+            payload["segment_analysis"]["attributes"] = segment_analysis_attributes
+        url = "{}{}/settings/".format(self._path, self.id)
+        response = self._client.patch(url, data=payload)
+        wait_for_async_resolution(self._client, response.headers["Location"], max_wait)
+
     def get_drift_tracking_settings(self):
         """Retrieve drift tracking settings of this deployment.
 
@@ -684,14 +940,14 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             enabled : bool
                 If target drift tracking is enabled for this deployment. To create or update
                 existing ''target_drift'' settings, see
-                :meth:`~datarobot.Deployment.update_drift_tracking_settings`
+                :meth:`~datarobot.models.Deployment.update_drift_tracking_settings`
 
             ``Feature drift`` setting contains:
 
             enabled : bool
                 If feature drift tracking is enabled for this deployment. To create or update
                 existing ''feature_drift'' settings, see
-                :meth:`~datarobot.Deployment.update_drift_tracking_settings`
+                :meth:`~datarobot.models.Deployment.update_drift_tracking_settings`
         """
 
         url = "{}{}/settings/".format(self._path, self.id)
@@ -797,7 +1053,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             enabled : bool
                 If predictions data collection is enabled for this deployment. To update
                 existing ''predictions_data_collection'' settings, see
-                :meth:`~datarobot.Deployment.update_predictions_data_collection_settings`
+                :meth:`~datarobot.models.Deployment.update_predictions_data_collection_settings`
         """
 
         url = "{}{}/settings/".format(self._path, self.id)
@@ -816,7 +1072,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         Parameters
         ----------
         enabled: bool
-            if predictions data collecion is to be turned on
+            if predictions data collection is to be turned on
         max_wait : int, optional
             seconds to wait for successful resolution
         """
@@ -837,7 +1093,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             enabled : bool
                 If target prediction_warning is enabled for this deployment. To create or update
                 existing ''prediction_warning'' settings, see
-                :meth:`~datarobot.Deployment.update_prediction_warning_settings`
+                :meth:`~datarobot.models.Deployment.update_prediction_warning_settings`
 
             custom_boundaries : dict or None
                 If None default boundaries for a model are used. Otherwise has following keys:
@@ -893,7 +1149,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         wait_for_async_resolution(self._client, response.headers["Location"], max_wait)
 
     def get_prediction_intervals_settings(self):
-        """ Retrieve prediction intervals settings for this deployment.
+        """Retrieve prediction intervals settings for this deployment.
 
         .. versionadded:: v2.19
 
@@ -907,7 +1163,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             enabled : bool
                 Whether prediction intervals are enabled for this deployment
             percentiles : list[int]
-                List of enabled prediction intervals sizes for this deployment. Currently we only
+                List of enabled prediction intervals' sizes for this deployment. Currently we only
                 support one percentile at a time.
         """
         url = "{}{}/settings/".format(self._path, self.id)
@@ -1100,7 +1356,9 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         end_time : datetime
             end of the time period
         metric : str
-            (New in version v2.22) metric used to calculate the drift score
+            (New in version v2.22) The metric used to calculate the drift score. Allowed
+            values include `psi`, `kl_divergence`, `dissimilarity`, `hellinger`, and
+            `js_divergence`.
 
         Returns
         -------
@@ -1174,7 +1432,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         )
 
     def update_secondary_dataset_config(self, secondary_dataset_config_id, credential_ids=None):
-        """ Update the secondary dataset config used by Feature discovery model for a
+        """Update the secondary dataset config used by Feature discovery model for a
         given deployment.
 
         .. versionadded:: v2.23
@@ -1204,7 +1462,7 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         return self.get_secondary_dataset_config()
 
     def get_secondary_dataset_config(self):
-        """ Get the secondary dataset config used by Feature discovery model for a
+        """Get the secondary dataset config used by Feature discovery model for a
         given deployment.
 
         .. versionadded:: v2.23
@@ -1339,15 +1597,23 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         with open(filepath, mode="wb") as file:
             file.write(response.content)
 
-    def download_scoring_code(self, filepath, source_code=False, include_agent=False):
+    def download_scoring_code(
+        self,
+        filepath,
+        source_code=False,
+        include_agent=False,
+        include_prediction_explanations=False,
+        include_prediction_intervals=False,
+    ):
         """Retrieve scoring code of the current deployed model.
 
         .. versionadded:: v2.24
 
         Notes
         -----
-        When setting `include_agent` to `True`, it can take
-        a considerably longer time to download the scoring code.
+        When setting `include_agent` or `include_predictions_explanations` or
+        `include_prediction_intervals` to `True`,
+        it can take a considerably longer time to download the scoring code.
 
         Parameters
         ----------
@@ -1357,6 +1623,10 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
             whether source code or binary of the scoring code will be retrieved
         include_agent : bool
             whether the scoring code retrieved will include tracking agent
+        include_prediction_explanations : bool
+            whether the scoring code retrieved will include prediction explanations
+        include_prediction_intervals : bool
+            whether the scoring code retrieved will support prediction intervals
 
         Examples
         --------
@@ -1368,132 +1638,147 @@ class Deployment(APIObject, DeploymentQueryBuilderMixin):
         """
 
         # retrieve the scoring code
-        if include_agent:
+        if include_agent or include_prediction_explanations or include_prediction_intervals:
             build_url = "{}{}/scoringCodeBuilds/".format(self._path, self.id)
-            response = self._client.post(build_url, data={"includeAgent": include_agent})
+            response = self._client.post(
+                build_url,
+                data={
+                    "includeAgent": include_agent,
+                    "includePredictionExplanations": include_prediction_explanations,
+                    "includePredictionIntervals": include_prediction_intervals,
+                },
+            )
             retrieve_url = wait_for_async_resolution(self._client, response.headers["Location"])
             response = self._client.get(retrieve_url)
         else:
             retrieve_url = "{}{}/scoringCode/".format(self._path, self.id)
-            params = {"sourceCode": source_code, "includeAgent": include_agent}
+            params = {
+                "sourceCode": source_code,
+                "includeAgent": include_agent,
+                "includePredictionExplanations": include_prediction_explanations,
+                "includePredictionIntervals": include_prediction_intervals,
+            }
             response = self._client.get(retrieve_url, params=params)
-
         # write to file
         with open(filepath, mode="wb") as file:
             file.write(response.content)
 
 
-def _check(trafaret, default_to_null=True):
-    def _trafaret_check(*args):
-        value = args[0]
+def _check(trafaret, value, default_to_null=True):
+    if default_to_null and value is None:
+        return None
 
-        if default_to_null and value is None:
-            return None
+    # Allow users to pass a single value even if a list of values is expected.
+    if isinstance(trafaret, t.List) and not isinstance(value, list):
+        value = [value]
 
-        # Allow users to pass a single value even if a list of values is expected.
-        if isinstance(trafaret, t.List) and not isinstance(value, list):
-            value = [value]
-
-        return trafaret.check(value)
-
-    return _trafaret_check
+    return trafaret.check(value)
 
 
-@attr.s(slots=True, frozen=True)
 class DeploymentListFilters(object):
-    """Construct a set of filters to pass to ``Deployment.list()``
+    def __init__(
+        self,
+        role=None,
+        service_health=None,
+        model_health=None,
+        accuracy_health=None,
+        execution_environment_type=None,
+        importance=None,
+    ):
+        """Construct a set of filters to pass to ``Deployment.list()``
 
-    .. versionadded:: v2.20
+        .. versionadded:: v2.20
 
-    Parameters
-    ----------
-    role : str
-        A user role. If specified, then take those deployments that the user can view, then
-        filter them down to those that the user has the specified role for, and return only them.
-        Allowed options are ``OWNER`` and ``USER``.
-    service_health : list of str
-        A list of service health status values. If specified, then only deployments whose
-        service health status is one of these will be returned. See
-        ``datarobot.enums.DEPLOYMENT_SERVICE_HEALTH_STATUS`` for allowed values.
-        Supports comma-separated lists.
-    model_health : list of str
-        A list of model health status values. If specified, then only deployments whose model
-        health status is one of these will be returned. See
-        ``datarobot.enums.DEPLOYMENT_MODEL_HEALTH_STATUS`` for allowed values.
-        Supports comma-separated lists.
-    accuracy_health : list of str
-        A list of accuracy health status values. If specified, then only deployments whose
-        accuracy health status is one of these will be returned. See
-        ``datarobot.enums.DEPLOYMENT_ACCURACY_HEALTH_STATUS`` for allowed values.
-        Supports comma-separated lists.
-    execution_environment_type : list of str
-        A list of strings representing the type of the deployments' execution environment.
-        If provided, then only return those deployments whose execution environment type is
-        one of those provided. See ``datarobot.enums.DEPLOYMENT_EXECUTION_ENVIRONMENT_TYPE``
-        for allowed values. Supports comma-separated lists.
-    importance : list of str
-        A list of strings representing the deployments' "importance".
-        If provided, then only return those deployments whose importance
-        is one of those provided. See ``datarobot.enums.DEPLOYMENT_IMPORTANCE``
-        for allowed values. Supports comma-separated lists. Note that Approval Workflows must be
-        enabled for your account to use this filter, otherwise the API will return a 403.
+        Parameters
+        ----------
+        role : str
+            A user role. If specified, then take those deployments that the user can view, then
+            filter them down to those that the user has the specified role for, and return only
+            them. Allowed options are ``OWNER`` and ``USER``.
+        service_health : list of str
+            A list of service health status values. If specified, then only deployments whose
+            service health status is one of these will be returned. See
+            ``datarobot.enums.DEPLOYMENT_SERVICE_HEALTH_STATUS`` for allowed values.
+            Supports comma-separated lists.
+        model_health : list of str
+            A list of model health status values. If specified, then only deployments whose model
+            health status is one of these will be returned. See
+            ``datarobot.enums.DEPLOYMENT_MODEL_HEALTH_STATUS`` for allowed values.
+            Supports comma-separated lists.
+        accuracy_health : list of str
+            A list of accuracy health status values. If specified, then only deployments whose
+            accuracy health status is one of these will be returned. See
+            ``datarobot.enums.DEPLOYMENT_ACCURACY_HEALTH_STATUS`` for allowed values.
+            Supports comma-separated lists.
+        execution_environment_type : list of str
+            A list of strings representing the type of the deployments' execution environment.
+            If provided, then only return those deployments whose execution environment type is
+            one of those provided. See ``datarobot.enums.DEPLOYMENT_EXECUTION_ENVIRONMENT_TYPE``
+            for allowed values. Supports comma-separated lists.
+        importance : list of str
+            A list of strings representing the deployments' "importance".
+            If provided, then only return those deployments whose importance
+            is one of those provided. See ``datarobot.enums.DEPLOYMENT_IMPORTANCE``
+            for allowed values. Supports comma-separated lists. Note that Approval Workflows must
+            be enabled for your account to use this filter, otherwise the API will return a 403.
 
-    Examples
-    --------
-    Multiple filters can be combined in interesting ways to return very specific subsets of
-    deployments.
+        Examples
+        --------
+        Multiple filters can be combined in interesting ways to return very specific subsets of
+        deployments.
 
-    *Performing AND logic*
+        *Performing AND logic*
 
-        Providing multiple different parameters will result in AND logic between them. For example,
-        the following will return all deployments that I own whose service health status is failing.
+            Providing multiple different parameters will result in AND logic between them.
+            For example, the following will return all deployments that I own whose service health
+            status is failing.
 
-        .. code-block:: python
+            .. code-block:: python
 
-            from datarobot import Deployment
-            from datarobot.models.deployment import DeploymentListFilters
-            from datarobot.enums import DEPLOYMENT_SERVICE_HEALTH
-            filters = DeploymentListFilters(
-                role='OWNER',
-                service_health=[DEPLOYMENT_SERVICE_HEALTH.FAILING]
-            )
-            deployments = Deployment.list(filters=filters)
+                from datarobot import Deployment
+                from datarobot.models.deployment import DeploymentListFilters
+                from datarobot.enums import DEPLOYMENT_SERVICE_HEALTH_STATUS
+                filters = DeploymentListFilters(
+                    role='OWNER',
+                    service_health=[DEPLOYMENT_SERVICE_HEALTH.FAILING]
+                )
+                deployments = Deployment.list(filters=filters)
 
-    **Performing OR logic**
+        **Performing OR logic**
 
-        Some filters support comma-separated lists (and will say so if they do). Providing a
-        comma-separated list of values to a single filter performs OR logic between those values.
-        For example, the following will return all deployments whose service health is either
-        ``warning`` OR ``failing``.
+            Some filters support comma-separated lists (and will say so if they do). Providing a
+            comma-separated list of values to a single filter performs OR logic between those
+            values. For example, the following will return all deployments whose service health
+            is either ``warning`` OR ``failing``.
 
-        .. code-block:: python
+            .. code-block:: python
 
-            from datarobot import Deployment
-            from datarobot.models.deployment import DeploymentListFilters
-            from datarobot.enums import DEPLOYMENT_SERVICE_HEALTH
-            filters = DeploymentListFilters(
-                service_health=[
-                    DEPLOYMENT_SERVICE_HEALTH.WARNING,
-                    DEPLOYMENT_SERVICE_HEALTH.FAILING,
-                ]
-            )
-            deployments = Deployment.list(filters=filters)
+                from datarobot import Deployment
+                from datarobot.models.deployment import DeploymentListFilters
+                from datarobot.enums import DEPLOYMENT_SERVICE_HEALTH_STATUS
+                filters = DeploymentListFilters(
+                    service_health=[
+                        DEPLOYMENT_SERVICE_HEALTH.WARNING,
+                        DEPLOYMENT_SERVICE_HEALTH.FAILING,
+                    ]
+                )
+                deployments = Deployment.list(filters=filters)
 
-    Performing OR logic across different filter types is not supported.
+        Performing OR logic across different filter types is not supported.
 
-    .. note::
+        .. note::
 
-        In all cases, you may only retrieve deployments for which you have at least the USER role
-        for. Deployments for which you are a CONSUMER of will not be returned, regardless of the
-        filters applied.
-    """
+            In all cases, you may only retrieve deployments for which you have at least
+            the USER role for. Deployments for which you are a CONSUMER of will not be returned,
+            regardless of the filters applied.
+        """
 
-    role = attr.ib(default=None, converter=_check(String()))
-    service_health = attr.ib(default=None, converter=_check(t.List[String()]))
-    model_health = attr.ib(default=None, converter=_check(t.List[String()]))
-    accuracy_health = attr.ib(default=None, converter=_check(t.List[String()]))
-    execution_environment_type = attr.ib(default=None, converter=_check(t.List[String()]))
-    importance = attr.ib(default=None, converter=_check(t.List[String()]))
+        self.role = _check(String(), role)
+        self.service_health = _check(t.List[String()], service_health)
+        self.model_health = _check(t.List[String()], model_health)
+        self.accuracy_health = _check(t.List[String()], accuracy_health)
+        self.execution_environment_type = _check(t.List[String()], execution_environment_type)
+        self.importance = _check(t.List[String()], importance)
 
     def construct_query_args(self):
         query_args = {}
