@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import String
@@ -31,7 +42,9 @@ class RequiredMetadataKey(APIObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             u"{}(field_name={!r}, display_name={!r})".format(
-                self.__class__.__name__, self.field_name, self.display_name,
+                self.__class__.__name__,
+                self.field_name,
+                self.display_name,
             )
         )
 
