@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import os
 import shutil
 import tempfile
@@ -322,7 +333,10 @@ class ExecutionEnvironmentVersion(APIObject):
                 raise errors.AsyncTimeoutError(
                     "Timeout while waiting for environment version to be built. Timeout: {}, "
                     "current state: {}, environment id: {}, environment version id: {}".format(
-                        max_wait, version.build_status, version.id, version.environment_id,
+                        max_wait,
+                        version.build_status,
+                        version.id,
+                        version.environment_id,
                     )
                 )
             time.sleep(5)
