@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import pandas as pd
 from six.moves.urllib.parse import quote
 import trafaret as t
@@ -35,7 +46,7 @@ class HasHistogram(object):
 
 
 class Feature(APIObject, HasHistogram):
-    """ A feature from a project's dataset
+    """A feature from a project's dataset
 
     These are features either included in the originally uploaded dataset or added to it via
     feature transformations.  In time series projects, these will be distinct from the
@@ -265,7 +276,7 @@ class Feature(APIObject, HasHistogram):
         )
 
     def get_multiseries_properties(self, multiseries_id_columns, max_wait=DEFAULT_MAX_WAIT):
-        """ Retrieve time series properties for a potential multiseries datetime partition column
+        """Retrieve time series properties for a potential multiseries datetime partition column
 
         Multiseries time series projects use multiseries id columns to model multiple distinct
         series within a single project.  This function returns the time series properties (time step
@@ -351,7 +362,7 @@ class Feature(APIObject, HasHistogram):
     def get_cross_series_properties(
         self, datetime_partition_column, cross_series_group_by_columns, max_wait=DEFAULT_MAX_WAIT
     ):
-        """ Retrieve cross-series properties for multiseries ID column.
+        """Retrieve cross-series properties for multiseries ID column.
 
         This function returns the cross-series properties (eligibility
         as group-by column) of this column if it were used with specified datetime partition column
@@ -540,7 +551,7 @@ class Feature(APIObject, HasHistogram):
 
 
 class ModelingFeature(APIObject, HasHistogram):
-    """ A feature used for modeling
+    """A feature used for modeling
 
     In time series projects, a new set of modeling features is created after setting the
     partitioning options.  These features are automatically derived from those in the project's
@@ -723,7 +734,7 @@ class ModelingFeature(APIObject, HasHistogram):
 
 
 class DatasetFeature(APIObject):
-    """ A feature from a project's dataset
+    """A feature from a project's dataset
 
     These are features either included in the originally uploaded dataset or added to it via
     feature transformations.
@@ -880,7 +891,7 @@ class DatasetFeature(APIObject):
 
 
 class BaseFeatureHistogram(APIObject):
-    """ A histogram plot data for a specific feature
+    """A histogram plot data for a specific feature
 
     .. versionadded:: v2.14
 
@@ -1112,13 +1123,13 @@ class InteractionFeature(APIObject):
         -------
         feature : InteractionFeature
             The queried instance
-          """
+        """
         feature_url = cls._url(project_id, feature_name)
         return cls.from_location(feature_url)
 
 
 class FeatureLineage(APIObject):
-    """ Lineage of an automatically engineered feature.
+    """Lineage of an automatically engineered feature.
 
     Attributes
     ----------
@@ -1255,13 +1266,14 @@ class FeatureLineage(APIObject):
     ).ignore_extra("*")
 
     def __init__(
-        self, steps=None,
+        self,
+        steps=None,
     ):
         self.steps = steps
 
     @classmethod
     def get(cls, project_id, id):
-        """ Retrieve a single FeatureLineage.
+        """Retrieve a single FeatureLineage.
 
         Parameters
         ----------
