@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -30,7 +41,7 @@ class FeatureAssociationMatrix(APIObject):
 
         # retrieve feature association matrix
         feature_association_matrix = dr.FeatureAssociationMatrix.get(project_id)
-        feature_association_matrix.strength
+        feature_association_matrix.strengths
         feature_association_matrix.features
 
         # retrieve feature association matrix for a metric, association type or a feature list
@@ -83,7 +94,10 @@ class FeatureAssociationMatrix(APIObject):
     def __repr__(self):
         return encode_utf8_if_py2(
             u"{}(project_id={}, strengths={}, features={})".format(
-                self.__class__.__name__, self.project_id, self.strengths, self.features,
+                self.__class__.__name__,
+                self.project_id,
+                self.strengths,
+                self.features,
             )
         )
 
@@ -111,8 +125,8 @@ class FeatureAssociationMatrix(APIObject):
         Returns
         -------
         FeatureAssociationMatrix
-            Feature association pairwise metric strength data, clustering data, and ordering data
-            for Feature Association Matrix visualization.
+            Feature association pairwise metric strength data, feature clustering data, and
+            ordering data for Feature Association Matrix visualization.
         """
         String().check(project_id)
         params = dict()
