@@ -1,13 +1,25 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
 from datarobot.enums import FEATURE_TYPE
 from datarobot.models.api_object import APIObject
-from datarobot.utils import encode_utf8_if_py2, from_api
+from datarobot.utils import encode_utf8_if_py2, from_api, get_id_from_response
+from datarobot.utils.pagination import unpaginate
 
 
 class FeatureEffectMetadata(APIObject):
-    """ Feature Effect Metadata for model, contains status and available model sources.
+    """Feature Effect Metadata for model, contains status and available model sources.
 
     Notes
     -----
@@ -30,7 +42,7 @@ class FeatureEffectMetadata(APIObject):
 
 
 class FeatureEffectMetadataDatetime(APIObject):
-    """ Feature Effect Metadata for datetime model, contains list of
+    """Feature Effect Metadata for datetime model, contains list of
     feature effect metadata per backtest.
 
     Notes
@@ -138,7 +150,7 @@ class FeatureEffects(APIObject):
 
         * ``feature_name`` (string) Name of the feature
         * ``feature_type`` (string) `dr.enums.FEATURE_TYPE`, \
-          Feature type either numeric or categorical
+          Feature type either numeric, categorical or datetime
         * ``feature_impact_score`` (float) Feature impact score
         * ``weight_label`` (string) optional, Weight label if configured for the project else null
         * ``partial_dependence`` (List) Partial dependence results
@@ -197,31 +209,54 @@ class FeatureEffects(APIObject):
         }
     ).ignore_extra("*")
 
+    _IndividualConditionalExpectation = t.Dict(
+        {
+            t.Key("is_capped"): t.Bool,
+            t.Key("data"): t.List(
+                t.List(
+                    t.Dict(
+                        {t.Key("label"): String | Int, t.Key("dependence"): t.Float}
+                    ).ignore_extra("*")
+                )
+            ),
+        }
+    ).ignore_extra("*")
+
+    _FeatureEffect = t.Dict(
+        {
+            t.Key("feature_name"): String,
+            t.Key("feature_impact_score"): t.Float,
+            t.Key("feature_type"): t.Enum(
+                FEATURE_TYPE.NUMERIC, FEATURE_TYPE.CATEGORICAL, FEATURE_TYPE.DATETIME
+            ),
+            t.Key("partial_dependence"): _PartialDependence,
+            t.Key("predicted_vs_actual", optional=True): _PredictedVsActual,
+            t.Key("weight_label", optional=True): String | t.Null,
+            t.Key("is_scalable"): t.Bool | t.Null,
+            t.Key("is_binnable"): t.Bool,
+            t.Key(
+                "individual_conditional_expectation", optional=True
+            ): _IndividualConditionalExpectation,
+        }
+    ).ignore_extra("*")
+
     _converter = t.Dict(
         {
             t.Key("project_id"): String,
             t.Key("model_id"): String,
             t.Key("source"): String,
             t.Key("backtest_index", optional=True): String,
-            t.Key("feature_effects"): t.List(
-                t.Dict(
-                    {
-                        t.Key("feature_name"): String,
-                        t.Key("feature_impact_score"): t.Float,
-                        t.Key("feature_type"): t.Enum(
-                            FEATURE_TYPE.NUMERIC, FEATURE_TYPE.CATEGORICAL
-                        ),
-                        t.Key("partial_dependence"): _PartialDependence,
-                        t.Key("predicted_vs_actual", optional=True): _PredictedVsActual,
-                        t.Key("weight_label", optional=True): String | t.Null,
-                    }
-                ).ignore_extra("*")
-            ),
+            t.Key("feature_effects"): t.List(_FeatureEffect),
         }
     ).ignore_extra("*")
 
     def __init__(
-        self, project_id, model_id, source, feature_effects, backtest_index=None,
+        self,
+        project_id,
+        model_id,
+        source,
+        feature_effects,
+        backtest_index=None,
     ):
         self.project_id = project_id
         self.model_id = model_id
@@ -285,3 +320,168 @@ class FeatureEffects(APIObject):
         # keep_null_keys is required for predicted/actual
         case_converted = from_api(data, keep_null_keys=True)
         return cls.from_data(case_converted)
+
+
+class FeatureEffectsMulticlass(APIObject):
+    """
+    Feature Effects for a model in multiclass project.
+
+    Attributes
+    ----------
+    class_ : str
+        Name of the class.
+    feature_name : str
+        Name of the feature.
+    feature_type : dr.enums.FEATURE_TYPE
+        Feature type either numeric, categorical or datetime.
+    feature_impact_score : float
+        Feature impact score.
+    weight_label : str
+        Optional. Weight label if configured for the project else None.
+    partial_dependence : list
+        Partial dependence results.
+    predicted_vs_actual : list
+        Optional. Predicted versus actual results, may be omitted if there are insufficient
+        qualified samples.
+    """
+
+    _path = "projects/{project_id}/{model_type}/{model_id}/multiclassFeatureEffects/"
+    _converter = (
+        t.Dict({t.Key("class", to_name="class_"): String()})
+        .merge(FeatureEffects._FeatureEffect)
+        .ignore_extra("*")
+    )
+
+    def __init__(
+        self,
+        class_,
+        feature_name,
+        feature_type,
+        feature_impact_score,
+        partial_dependence,
+        is_scalable,
+        is_binnable,
+        predicted_vs_actual=None,
+        weight_label=None,
+    ):
+        self.class_ = class_
+        self.feature_name = feature_name
+        self.feature_type = feature_type
+        self.feature_impact_score = feature_impact_score
+        self.partial_dependence = partial_dependence
+        self.predicted_vs_actual = predicted_vs_actual
+        self.weight_label = weight_label
+        self.is_scalable = is_scalable
+        self.is_binnable = is_binnable
+
+    def __repr__(self):
+        return encode_utf8_if_py2(
+            "{}(class={}, feature_name={}, feature_type={}, feature_impact_score={}, "
+            "weight_label={}, partial_dependence={}, predicted_vs_actual={})".format(
+                self.__class__.__name__,
+                self.class_,
+                self.feature_name,
+                self.feature_type,
+                self.feature_impact_score,
+                self.weight_label,
+                self.partial_dependence,
+                self.predicted_vs_actual,
+            )
+        )
+
+    @classmethod
+    def create(
+        cls,
+        project_id,
+        model_id,
+        backtest_index=None,
+        row_count=None,
+        top_n_features=10,
+        features=None,
+    ):
+        """
+        Compute feature effects for a multiclass model.
+
+        Parameters
+        ----------
+        project_id : string
+            The project that contains requested model.
+        model_id : string
+            The model for which to retrieve Feature Effects.
+        row_count : int
+            The number of rows from dataset to use for Feature Impact calculation.
+        backtest_index : str
+            The backtest index for datetime models. e.g. 0, 1, ..., 20, holdout, startstop
+        top_n_features : int or None
+            Number of top features (ranked by Feature Impact) to use to calculate Feature Effects.
+        features : list or None
+            The list of features used to calculate Feature Effects.
+
+        Returns
+        -------
+        job : FeatureEffectsMulticlassJob
+            A Job representing Feature Effect computation. To get the completed Feature Effect data,
+            use `job.get_result` or `job.get_result_when_complete`.
+        """
+        if not ((features is None) ^ (top_n_features is None)):
+            raise ValueError(
+                "Either 'features' or 'top_n_features' must be provided, but not both."
+            )
+        payload = {"rowCount": row_count}
+        if backtest_index is not None:
+            payload["backtestIndex"] = backtest_index
+        if top_n_features:
+            payload["topNFeatures"] = top_n_features
+        if features:
+            payload["features"] = features
+        url = cls._get_url(project_id, model_id, backtest_index)
+        response = cls._client.post(url, json=payload)
+        job_id = get_id_from_response(response)
+        from .job import FeatureEffectsMulticlassJob
+
+        return FeatureEffectsMulticlassJob.get(project_id, job_id)
+
+    @classmethod
+    def get(cls, project_id, model_id, source="training", backtest_index=None, class_=None):
+        """
+        Retrieve multiclass Feature Effects.
+
+        Parameters
+        ----------
+        project_id: str
+            project id
+        model_id: str
+            model id
+        source: str
+            datasource, optional defaults to 'training' (e.g. 'validation', 'training', 'holdout')
+        backtest_index: str
+            backtest index, required for datetime models (e.g. 0, 1, ..., 20, holdout, startstop)
+        class_: str
+            target class name
+
+        Returns
+        -------
+            list of FeatureEffectsMulticlass
+        """
+
+        params = {"source": source}
+        if backtest_index is not None:
+            params["backtestIndex"] = backtest_index
+        if class_:
+            params["class"] = class_
+        url = cls._get_url(project_id, model_id, backtest_index)
+        return cls.from_location(url, params=params)
+
+    @classmethod
+    def from_location(cls, path, keep_attrs=None, params=None):
+        results = unpaginate(initial_url=path, initial_params=params, client=cls._client)
+        return [
+            cls.from_data(from_api(item, keep_attrs=keep_attrs, keep_null_keys=True))
+            for item in results
+        ]
+
+    @classmethod
+    def _get_url(cls, project_id, model_id, backtest_index):
+        model_type = "models" if backtest_index is None else "datetimeModels"
+        url = cls._path.format(project_id=project_id, model_type=model_type, model_id=model_id)
+        return url
