@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -12,7 +23,7 @@ from datarobot.utils import encode_utf8_if_py2, from_api
 
 
 class FeatureFitMetadata(FeatureEffectMetadata):
-    """ Feature Fit Metadata for model, contains status and available model sources.
+    """Feature Fit Metadata for model, contains status and available model sources.
 
     Notes
     -----
@@ -27,7 +38,7 @@ class FeatureFitMetadata(FeatureEffectMetadata):
 
 
 class FeatureFitMetadataDatetime(FeatureEffectMetadataDatetime):
-    """ Feature Fit Metadata for datetime model, contains list of feature fit metadata per backtest.
+    """Feature Fit Metadata for datetime model, contains list of feature fit metadata per backtest.
 
     Notes
     -----
@@ -118,7 +129,7 @@ class FeatureFit(APIObject):
 
         * ``feature_name`` (string) Name of the feature
         * ``feature_type`` (string) `dr.enums.FEATURE_TYPE`, \
-          Feature type either numeric or categorical
+          Feature type either numeric, categorical or datetime
         * ``feature_importance_score`` (float) Feature importance score
         * ``weight_label`` (string) optional, Weight label if configured for the project else null
         * ``partial_dependence`` (List) Partial dependence results
@@ -177,6 +188,19 @@ class FeatureFit(APIObject):
         }
     ).ignore_extra("*")
 
+    _IndividualConditionalExpectation = t.Dict(
+        {
+            t.Key("is_capped"): t.Bool,
+            t.Key("data"): t.List(
+                t.List(
+                    t.Dict(
+                        {t.Key("label"): String | Int, t.Key("dependence"): t.Float}
+                    ).ignore_extra("*")
+                )
+            ),
+        }
+    ).ignore_extra("*")
+
     _converter = t.Dict(
         {
             t.Key("project_id"): String,
@@ -189,11 +213,16 @@ class FeatureFit(APIObject):
                         t.Key("feature_name"): String,
                         t.Key("feature_importance_score"): t.Float,
                         t.Key("feature_type"): t.Enum(
-                            FEATURE_TYPE.NUMERIC, FEATURE_TYPE.CATEGORICAL
+                            FEATURE_TYPE.NUMERIC, FEATURE_TYPE.CATEGORICAL, FEATURE_TYPE.DATETIME
                         ),
                         t.Key("partial_dependence"): _PartialDependence,
                         t.Key("predicted_vs_actual"): _PredictedVsActual,
                         t.Key("weight_label", optional=True): String | t.Null,
+                        t.Key("is_scalable"): t.Bool | t.Null,
+                        t.Key("is_binnable"): t.Bool,
+                        t.Key(
+                            "individual_conditional_expectation", optional=True
+                        ): _IndividualConditionalExpectation,
                     }
                 ).ignore_extra("*")
             ),
@@ -201,7 +230,12 @@ class FeatureFit(APIObject):
     ).ignore_extra("*")
 
     def __init__(
-        self, project_id, model_id, source, feature_fit, backtest_index=None,
+        self,
+        project_id,
+        model_id,
+        source,
+        feature_fit,
+        backtest_index=None,
     ):
         self.project_id = project_id
         self.model_id = model_id
