@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 """
   AbstractJob
   ^        ^
@@ -35,7 +46,7 @@ from .. import errors
 from ..client import get_client, staticproperty
 from ..enums import DEFAULT_MAX_WAIT, JOB_TYPE, PREDICTION_PREFIX, QUEUE_STATUS
 from ..utils import from_api, raw_prediction_response_to_dataframe
-from .feature_effect import FeatureEffects
+from .feature_effect import FeatureEffects, FeatureEffectsMulticlass
 from .model import Model, PrimeModel
 from .prediction_explanations import PredictionExplanations, PredictionExplanationsInitialization
 from .prime_file import PrimeFile
@@ -46,8 +57,7 @@ from .training_predictions import TrainingPredictions
 
 
 class AbstractJob(object):
-    """ Generic representation of a job in the queue
-    """
+    """Generic representation of a job in the queue"""
 
     # Subclasses can override this:
     _converter_extra = t.Dict()
@@ -188,10 +198,6 @@ class AbstractJob(object):
             return PredictionExplanationsInitialization.from_server_data(server_data)
         elif self.job_type == JOB_TYPE.REASON_CODES:
             return ReasonCodes.from_location(server_data["reasonCodesRecordLocation"])
-        elif self.job_type == JOB_TYPE.PREDICTION_EXPLANATIONS:
-            return PredictionExplanations.from_location(
-                server_data["predictionExplanationsRecordLocation"]
-            )
         elif self.job_type == JOB_TYPE.RATING_TABLE_VALIDATION:
             return RatingTable.from_server_data(server_data)
         elif self.job_type == JOB_TYPE.SHAP_IMPACT:
@@ -203,6 +209,13 @@ class AbstractJob(object):
         if self.job_type == JOB_TYPE.TRAINING_PREDICTIONS:
             return TrainingPredictions.from_location(location)
 
+        if self.job_type == JOB_TYPE.PREDICTION_EXPLANATIONS:
+            head, tail = location.split("/predictionExplanations/", 1)
+            project_id, prediction_expl_id = head.split("/")[-1], tail.split("/")[0]
+            return PredictionExplanations.get(
+                project_id=project_id, prediction_explanations_id=prediction_expl_id
+            )
+
         server_data = self._client.get(location, params=params).json()
         return self._make_result_from_json(server_data)
 
@@ -277,7 +290,7 @@ class AbstractJob(object):
 
 class Job(AbstractJob):
 
-    """ Tracks asynchronous work being done within a project
+    """Tracks asynchronous work being done within a project
 
     Attributes
     ----------
@@ -415,12 +428,17 @@ class TrainingPredictionsJob(Job):
         url = cls._job_path(project_id, job_id)
         data, completed_url = cls._data_and_completed_url_for_job(url)
         return cls(
-            data, model_id=model_id, data_subset=data_subset, completed_resource_url=completed_url,
+            data,
+            model_id=model_id,
+            data_subset=data_subset,
+            completed_resource_url=completed_url,
         )
 
     def _make_result_from_location(self, location, params=None):
         return TrainingPredictions.from_location(
-            location, model_id=self._model_id, data_subset=self._data_subset,
+            location,
+            model_id=self._model_id,
+            data_subset=self._data_subset,
         )
 
     def refresh(self):
@@ -496,6 +514,11 @@ class FeatureImpactJob(Job):
         return filter_feature_impact_result(server_data, with_metadata=self._with_metadata)
 
 
+class FeatureEffectsMulticlassJob(Job):
+    def _make_result_from_location(self, location, params=None):
+        return FeatureEffectsMulticlass.from_location(location)
+
+
 def _filter_feature_impact_result(data, validator_config):
     # The trafaret used might allow extra fields, but we want this method to return only known
     # fields. Be conservative in what you do, be liberal in what you accept from others.
