@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import String
@@ -7,7 +18,7 @@ from datarobot.utils.pagination import unpaginate
 
 
 class PayoffMatrix(APIObject):
-    """ Represents a Payoff Matrix, a costs/benefit scenario used for creating a profit curve.
+    """Represents a Payoff Matrix, a costs/benefit scenario used for creating a profit curve.
 
     Attributes
     ----------
@@ -148,7 +159,9 @@ class PayoffMatrix(APIObject):
             if the server responded with 5xx status
         """
         data = unpaginate(
-            initial_url=cls._base_url.format(project_id), initial_params=None, client=cls._client,
+            initial_url=cls._base_url.format(project_id),
+            initial_params=None,
+            client=cls._client,
         )
         result = [cls.from_server_data(item) for item in data]
         return result
@@ -190,7 +203,7 @@ class PayoffMatrix(APIObject):
         false_positive_value,
         false_negative_value,
     ):
-        """ Update (replace) a payoff matrix. Note that all data fields are required.
+        """Update (replace) a payoff matrix. Note that all data fields are required.
 
         Parameters
         ----------
