@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import pandas as pd
 import six
 from six.moves.urllib_parse import urlencode
@@ -307,7 +318,10 @@ class Predictions(APIObject):
         """
         df = self.get_all_as_dataframe(serializer=serializer)
         df.to_csv(
-            path_or_buf=filename, header=True, index=False, encoding=encoding,
+            path_or_buf=filename,
+            header=True,
+            index=False,
+            encoding=encoding,
         )
 
     def __repr__(self):
