@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -9,7 +20,7 @@ from ..helpers.feature_discovery import DatasetDefinition, FeatureDiscoverySetti
 
 
 class RelationshipsConfiguration(APIObject):
-    """ A Relationships configuration specifies a set of secondary datasets as well as
+    """A Relationships configuration specifies a set of secondary datasets as well as
     the relationships among them. It is used to configure Feature Discovery for a project
     to generate features automatically from these datasets.
 
@@ -126,6 +137,10 @@ class RelationshipsConfiguration(APIObject):
         MILLISECOND, SECOND, MINUTE, HOUR, DAY, WEEK, MONTH, QUARTER, YEAR
         If present, time-aware joins will be used.
         Only applicable when dataset1Identifier is not provided.
+    feature_derivation_windows: list of dict, or None
+        List of feature derivation windows settings. If present, time-aware joins will be used.
+        Only allowed when feature_derivation_window_start,
+        feature_derivation_window_end and feature_derivation_window_time_unit are not provided.
     prediction_point_rounding: int, or None
         Closest value of prediction_point_rounding_time_unit to round the prediction point
         into the past when applying the feature derivation window. Will be a positive integer,
@@ -135,6 +150,18 @@ class RelationshipsConfiguration(APIObject):
         MILLISECOND, SECOND, MINUTE, HOUR, DAY, WEEK, MONTH, QUARTER, YEAR
         Only applicable when dataset1_identifier is not provided.
 
+    The `feature_derivation_windows` is a list of dictionary with schema:
+        start: int
+            How many time_units of each dataset's primary temporal key into the past relative
+            to the datetimePartitionColumn the feature derivation window should begin.
+        end: int
+            How many timeUnits of each dataset's record
+            primary temporal key into the past relative to the datetimePartitionColumn the
+            feature derivation window should end.
+        unit: string
+            Time unit of the feature derivation window.
+            One of ``datarobot.enums.AllowedTimeUnitsSAFER``.
+
     The `feature_discovery_settings` structure is:
 
     name: str
@@ -154,10 +181,11 @@ class RelationshipsConfiguration(APIObject):
             t.Key("data_store_id"): String,
             t.Key("url"): String,
             t.Key("dbtable"): String | t.Null,
-            t.Key("schema", optional=True): String | t.Null,
-            t.Key("catalog", optional=True): String | t.Null,
+            t.Key("schema", optional=True): String(allow_blank=True) | t.Null,
+            t.Key("catalog", optional=True): String(allow_blank=True) | t.Null,
+            t.Key("data_source_id", optional=True): String | t.Null,
         }
-    )
+    ).ignore_extra("*")
     feature_list_info = t.Dict(
         {
             t.Key("id"): String,
@@ -170,7 +198,7 @@ class RelationshipsConfiguration(APIObject):
             t.Key("created_by"): String,
             t.Key("dataset_version_id", optional=True): String,
         }
-    )
+    ).ignore_extra("*")
     dataset_definitions_trafaret = t.Dict(
         {
             t.Key("identifier"): String(min_length=3, max_length=20),
@@ -186,6 +214,13 @@ class RelationshipsConfiguration(APIObject):
             t.Key("data_sources", optional=True): t.List(data_source_trafaret) | t.Null,
             t.Key("is_deleted", optional=True): t.Bool | t.Null,
         }
+    ).ignore_extra("*")
+    feature_derivation_window_trafaret = t.Dict(
+        {
+            t.Key("start"): Int(lt=0),
+            t.Key("end"): Int(lte=0),
+            t.Key("unit"): t.Enum(*AllowedTimeUnitsSAFER.ALL),
+        }
     )
 
     relationships_trafaret = t.Dict(
@@ -199,12 +234,15 @@ class RelationshipsConfiguration(APIObject):
             t.Key("feature_derivation_window_time_unit", optional=True): t.Enum(
                 *AllowedTimeUnitsSAFER.ALL
             ),
+            t.Key("feature_derivation_windows", optional=True): t.List(
+                feature_derivation_window_trafaret
+            ),
             t.Key("prediction_point_rounding", optional=True): Int(gt=0, lte=30),
             t.Key("prediction_point_rounding_time_unit", optional=True): t.Enum(
                 *AllowedTimeUnitsSAFER.ALL
             ),
         }
-    )
+    ).ignore_extra("*")
 
     feature_discovery_setting_trafaret = t.Dict(
         {t.Key("name"): String, t.Key("value"): t.Bool}
@@ -241,7 +279,7 @@ class RelationshipsConfiguration(APIObject):
 
     @classmethod
     def create(cls, dataset_definitions, relationships, feature_discovery_settings=None):
-        """ Create a Relationships Configuration
+        """Create a Relationships Configuration
 
         Parameters
         ----------
@@ -319,7 +357,7 @@ class RelationshipsConfiguration(APIObject):
         return RelationshipsConfiguration.from_server_data(response)
 
     def get(self):
-        """ Retrieve the Relationships configuration for a given id
+        """Retrieve the Relationships configuration for a given id
 
         Returns
         -------
@@ -343,7 +381,7 @@ class RelationshipsConfiguration(APIObject):
         return self.from_location("{}{}/".format(self._path, self.id))
 
     def replace(self, dataset_definitions, relationships, feature_discovery_settings=None):
-        """ Update the Relationships Configuration which is not used in
+        """Update the Relationships Configuration which is not used in
         the feature discovery Project
 
         Parameters
