@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import six
 import trafaret as t
 
@@ -62,7 +73,7 @@ class DatasetsCredentials(object):
 
 
 class SecondaryDatasetConfigurations(APIObject):
-    """ Create secondary dataset configurations for a given project
+    """Create secondary dataset configurations for a given project
 
     .. versionadded:: v2.20
 
@@ -237,7 +248,7 @@ class SecondaryDatasetConfigurations(APIObject):
 
     @classmethod
     def create(cls, project_id, secondary_datasets, name, featurelist_id=None):
-        """ create secondary dataset configurations
+        """create secondary dataset configurations
 
         .. versionadded:: v2.20
 
@@ -295,7 +306,8 @@ class SecondaryDatasetConfigurations(APIObject):
             raise errors.ClientError(six.text_type("project_id cannot be None or empty"), 422)
         if not secondary_datasets:
             raise errors.ClientError(
-                six.text_type("secondary_datasets cannot be None or empty"), 422,
+                six.text_type("secondary_datasets cannot be None or empty"),
+                422,
             )
 
         url = cls._base_url.format(project_id)
@@ -321,11 +333,12 @@ class SecondaryDatasetConfigurations(APIObject):
                 "message", six.text_type("error in processing secondary dataset configuration")
             )
             raise errors.ClientError(
-                error_msg + six.text_type(" with server returned status {}").format(status), status,
+                error_msg + six.text_type(" with server returned status {}").format(status),
+                status,
             )
 
     def delete(self):
-        """ Removes the Secondary datasets configuration
+        """Removes the Secondary datasets configuration
 
         .. versionadded:: v2.21
 
@@ -347,7 +360,7 @@ class SecondaryDatasetConfigurations(APIObject):
         self._client.delete("{}{}/".format(url, self.id))
 
     def get(self):
-        """ Retrieve a single secondary dataset configuration for a given id
+        """Retrieve a single secondary dataset configuration for a given id
 
         .. versionadded:: v2.21
 
@@ -396,7 +409,7 @@ class SecondaryDatasetConfigurations(APIObject):
 
     @classmethod
     def list(cls, project_id, featurelist_id=None, limit=None, offset=None):
-        """ Returns list of secondary dataset configurations.
+        """Returns list of secondary dataset configurations.
 
         .. versionadded:: v2.23
 
