@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from collections import OrderedDict
 
 import dateutil
@@ -27,15 +38,29 @@ class ServiceStats(APIObject, DeploymentQueryBuilderMixin):
     _path = "deployments/{}/serviceStats/"
     _period = t.Dict(
         {
-            t.Key("start"): String >> (lambda s: dateutil.parser.parse(s)),
-            t.Key("end"): String >> (lambda s: dateutil.parser.parse(s)),
+            t.Key("start"): t.String >> (lambda s: dateutil.parser.parse(s)),
+            t.Key("end"): t.String >> (lambda s: dateutil.parser.parse(s)),
         }
     )
     _converter = t.Dict(
         {
             t.Key("period"): _period,
-            t.Key("metrics"): t.Mapping(t.Enum(*SERVICE_STAT_METRIC.ALL), Int | t.Float | t.Null),
-            t.Key("model_id"): String() | t.Null,
+            t.Key("metrics"): t.Dict(
+                {
+                    t.Key(SERVICE_STAT_METRIC.TOTAL_PREDICTIONS): t.Int(),
+                    t.Key(SERVICE_STAT_METRIC.TOTAL_REQUESTS, optional=True): t.Int(),
+                    t.Key(SERVICE_STAT_METRIC.SLOW_REQUESTS, optional=True): t.Int(),
+                    t.Key(SERVICE_STAT_METRIC.EXECUTION_TIME, optional=True): t.Float() | t.Null(),
+                    t.Key(SERVICE_STAT_METRIC.RESPONSE_TIME, optional=True): t.Float() | t.Null(),
+                    t.Key(SERVICE_STAT_METRIC.USER_ERROR_RATE, optional=True): t.Float(),
+                    t.Key(SERVICE_STAT_METRIC.SERVER_ERROR_RATE, optional=True): t.Float(),
+                    t.Key(SERVICE_STAT_METRIC.NUM_CONSUMERS, optional=True): t.Int(),
+                    t.Key(SERVICE_STAT_METRIC.CACHE_HIT_RATIO, optional=True): t.Float(),
+                    t.Key(SERVICE_STAT_METRIC.MEDIAN_LOAD, optional=True): t.Float(),
+                    t.Key(SERVICE_STAT_METRIC.PEAK_LOAD, optional=True): t.Float(),
+                }
+            ).allow_extra("*", trafaret=t.Or(t.Int(), t.Float(), t.Null())),
+            t.Key("model_id"): t.String() | t.Null,
         }
     ).allow_extra("*")
 
@@ -118,17 +143,17 @@ class ServiceStats(APIObject, DeploymentQueryBuilderMixin):
 class ServiceStatsOverTime(APIObject, DeploymentQueryBuilderMixin):
     """Deployment service stats over time information.
 
-        Attributes
-        ----------
-        model_id : str
-            the model used to retrieve accuracy metric
-        metric : str
-            the service stat metric being retrieved
-        buckets : dict
-            how the service stat metric changes over time
-        summary : dict
-            summary for the service stat metric
-        """
+    Attributes
+    ----------
+    model_id : str
+        the model used to retrieve accuracy metric
+    metric : str
+        the service stat metric being retrieved
+    buckets : dict
+        how the service stat metric changes over time
+    summary : dict
+        summary for the service stat metric
+    """
 
     _path = "deployments/{}/serviceStatsOverTime/"
     _period = t.Dict(
