@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -23,6 +34,8 @@ class ShapImpact(APIObject):
     ----------
     count : int
         the number of SHAP Impact object returned
+    row_count: int or None
+        the sample size (specified in rows) to use for Shap Impact computation
     shap_impacts : list
         a list which contains SHAP impact scores for top 1000 features used by a model
     """
@@ -31,6 +44,7 @@ class ShapImpact(APIObject):
     _converter = t.Dict(
         {
             t.Key("count"): Int(),
+            t.Key("row_count", optional=True): t.Or(t.Int, t.Null),
             t.Key("shap_impacts"): t.List(
                 t.Dict(
                     {
@@ -43,16 +57,17 @@ class ShapImpact(APIObject):
         }
     )
 
-    def __init__(self, count, shap_impacts):
+    def __init__(self, count, shap_impacts, row_count=None):
         self.count = count
         self.shap_impacts = shap_impacts
+        self.row_count = row_count
 
     def __repr__(self):
         template = u"{}(count={!r})"
         return encode_utf8_if_py2(template.format(type(self).__name__, self.count))
 
     @classmethod
-    def create(cls, project_id, model_id):
+    def create(cls, project_id, model_id, row_count=None):
         """Create SHAP impact for the specified model.
 
         Parameters
@@ -61,6 +76,8 @@ class ShapImpact(APIObject):
             id of the project the model belongs to
         model_id : str
             id of the model to calculate shap impact for
+        row_count : int
+            the sample size (specified in rows) to use for Feature Impact computation
 
         Returns
         -------
@@ -68,7 +85,8 @@ class ShapImpact(APIObject):
             an instance of created async job
         """
         url = cls._path.format(project_id, model_id)
-        response = cls._client.post(url)
+        payload = {"row_count": row_count} if row_count is not None else {}
+        response = cls._client.post(url, data=payload)
         job_id = get_id_from_response(response)
         from .job import Job
 
