@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import pandas as pd
 import six
 import trafaret as t
@@ -62,13 +73,17 @@ class ShapMatrix(APIObject):
         template = u"{}(id={!r}, project_id={!r}, model_id={!r}, dataset_id={!r})"
         return encode_utf8_if_py2(
             template.format(
-                type(self).__name__, self.id, self.project_id, self.model_id, self.dataset_id,
+                type(self).__name__,
+                self.id,
+                self.project_id,
+                self.model_id,
+                self.dataset_id,
             )
         )
 
     @classmethod
     def create(cls, project_id, model_id, dataset_id):
-        """ Calculate SHAP based prediction explanations against previously uploaded dataset.
+        """Calculate SHAP based prediction explanations against previously uploaded dataset.
 
         Parameters
         ----------
