@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from collections import namedtuple
 import itertools
 
@@ -74,7 +85,8 @@ class RowsIterator(object):
         if response.status_code != 200:
             e_msg = "Server returned unexpected status code"
             raise errors.ServerError(
-                e_msg.format(response.status_code), response.status_code,
+                e_msg.format(response.status_code),
+                response.status_code,
             )
 
         body = self._trafaret.check(response.json())
@@ -108,7 +120,8 @@ class TrainingPredictionsIterator(RowsIterator):
     row_id : int
         id of the record in original dataset for which training prediction is calculated
     partition_id : str or float
-        id of the data partition that the row belongs to
+        id of the data partition that the row belongs to. "0.0" corresponds to the validation
+        partition or backtest 1.
     prediction : float
         the model's prediction for this data row
     prediction_values : list of dictionaries
@@ -703,7 +716,8 @@ class TrainingPredictions(APIObject):
             return pd.read_csv(resp.raw)
 
         raise errors.ServerError(
-            "Server returned unknown status code: {}".format(resp.status_code), resp.status_code,
+            "Server returned unknown status code: {}".format(resp.status_code),
+            resp.status_code,
         )
 
     def download_to_csv(self, filename, encoding="utf-8", serializer="json"):
@@ -722,5 +736,8 @@ class TrainingPredictions(APIObject):
         """
         df = self.get_all_as_dataframe(serializer=serializer)
         df.to_csv(
-            path_or_buf=filename, header=True, index=False, encoding=encoding,
+            path_or_buf=filename,
+            header=True,
+            index=False,
+            encoding=encoding,
         )
