@@ -1,7 +1,20 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
 
+from ...utils import deprecated, deprecation_warning
+from ...utils.waiters import wait_for_async_resolution
 from ..api_object import APIObject
 from .images import Image
 
@@ -131,9 +144,13 @@ class ImageAugmentationList(APIObject):
          Number of new rows to add for each existing row
     transformations: array
         List of transformations to possibly apply to each image
+    samples_id: str
+        Id of last image augmentation sample generated for image augmentation list.
     """
 
+    _list_path = "imageAugmentationLists/"
     _create_path = "imageAugmentationLists/"
+    _samples_path = "imageAugmentationLists/{id}/samples/"
     _converter = t.Dict(
         {
             t.Key("project_id"): String(),
@@ -145,6 +162,7 @@ class ImageAugmentationList(APIObject):
             t.Key("transformation_probability", optional=True): t.Float(),
             t.Key("number_of_new_images", optional=True, default=1): Int(),
             t.Key("transformations", optional=True): t.List(t.Dict().allow_extra("*")),
+            t.Key("samples_id", optional=True): String(),
         }
     ).ignore_extra("*")
 
@@ -159,6 +177,7 @@ class ImageAugmentationList(APIObject):
         transformation_probability=0.0,
         number_of_new_images=1,
         transformations=None,
+        samples_id=None,
     ):
         self.id = id
         self.name = name
@@ -169,18 +188,20 @@ class ImageAugmentationList(APIObject):
         self.transformation_probability = transformation_probability
         self.number_of_new_images = number_of_new_images
         self.transformations = transformations
+        self.samples_id = samples_id
 
     def __repr__(self):
         return (
             "datarobot.models.visualai.ImageAugmentationList("
-            "aug_id={0.id}, "
-            "name={0.name}, "
+            "id={0.id}, "
+            "name='{0.name}', "
             "project_id={0.project_id}, "
-            "feature_name={0.feature_name}, "
+            "feature_name='{0.feature_name}', "
             "in_use={0.in_use}, "
             "initial_list={0.initial_list}, "
             "transformation_probability={0.transformation_probability}, "
-            "number_of_new_images={0.number_of_new_images})"
+            "number_of_new_images={0.number_of_new_images}, "
+            "samples_id={0.samples_id})"
         ).format(self)
 
     @classmethod
@@ -194,6 +215,7 @@ class ImageAugmentationList(APIObject):
         transformation_probability=0.0,
         number_of_new_images=1,
         transformations=None,
+        samples_id=None,
     ):
         """
         create a new image augmentation list
@@ -204,6 +226,7 @@ class ImageAugmentationList(APIObject):
             "feature_name": feature_name,
             "in_use": in_use,
             "initial_list": initial_list,
+            "samples_id": samples_id,
             "transformation_probability": transformation_probability,
             "number_of_new_images": number_of_new_images,
             "transformations": transformations,
@@ -223,6 +246,32 @@ class ImageAugmentationList(APIObject):
         path = cls._create_path + str(list_id) + "/"
         cls._client.delete(path)
 
+    def retrieve_samples(self):
+        """
+        Lists already computed image augmentation sample for image augmentation list.
+        Returns samples only if they have been already computed. It does not initialize computation.
+
+        Returns
+        -------
+        List of class ImageAugmentationSample
+        """
+        return ImageAugmentationSample.list(auglist_id=self.id)
+
+    def compute_samples(self, max_wait=600):
+        """
+        Initializes computation and retrieves list of image augmentation samples
+        for image augmentation list. If samples exited prior to this call method,
+        this will compute fresh samples and return latest version of samples.
+
+        Returns
+        -------
+        List of class ImageAugmentationSample
+        """
+        url = self._samples_path.format(id=self.id)
+        response = self._client.post(url, data={"numberOfRows": self.number_of_new_images})
+        wait_for_async_resolution(self._client, response.headers["Location"], max_wait=max_wait)
+        return self.retrieve_samples()
+
 
 class ImageAugmentationSample(APIObject):
     """
@@ -246,7 +295,8 @@ class ImageAugmentationSample(APIObject):
     """
 
     _compute_path = "imageAugmentationSamples/"
-    _list_path = "imageAugmentationSamples/{sample_id}/"
+    _list_by_samples_path = "imageAugmentationSamples/{sample_id}/"
+    _list_by_auglist_path = "imageAugmentationLists/{auglist_id}/samples/"
     _converter = t.Dict(
         {
             t.Key("image_id"): String(),
@@ -279,6 +329,7 @@ class ImageAugmentationSample(APIObject):
         ).format(self)
 
     @classmethod
+    @deprecated("2.28", "2.30", "Please use ImageAugmentationList.compute_samples instead.")
     def compute(cls, augmentation_list, number_of_rows=5):
         """Start creation of image augmentation samples.
 
@@ -308,15 +359,32 @@ class ImageAugmentationSample(APIObject):
         return r_data.headers["Location"]
 
     @classmethod
-    def list(cls, sample_id):
-        """Return a list of ImageAugmentationSample objects
+    def list(cls, sample_id=None, auglist_id=None):
+        """Return a list of ImageAugmentationSample objects.
 
-         Parameters
-         ----------
+        If both sample_id and auglist_id are specified, auglist_id will take precedence.
+
+        Parameters
+        ----------
         sample_id: str
-             Unique Id for the set of sample images
+            Unique ID for the set of sample images
+        auglist_id: str
+            ID for augmentation list to retrieve samples for
+
+        Returns
+        -------
+        List of class ImageAugmentationSample
         """
-        path = cls._list_path.format(sample_id=sample_id)
+        if sample_id:
+            deprecation_warning(
+                subject="Parameter `sample_id in` method ImageAugmentationSample.list",
+                deprecated_since_version="2.28",
+                will_remove_version="2.30",
+                message="Please use parameter `auglist_id` instead.",
+            )
+            path = cls._list_by_samples_path.format(sample_id=sample_id)
+        if auglist_id:
+            path = cls._list_by_auglist_path.format(auglist_id=auglist_id)
 
         result = cls._client.get(path)
         r_data = result.json()
