@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import trafaret as t
 
 from datarobot._compat import Int, String
@@ -153,6 +164,8 @@ class SampleImage(APIObject):
             path = cls._list_images_path.format(project_id=project_id)
         else:
             path = cls._list_sample_path.format(project_id=project_id)
+
+        if feature_name:
             list_params["featureName"] = feature_name
         if target_value:
             list_params["targetValue"] = target_value
@@ -160,6 +173,7 @@ class SampleImage(APIObject):
             list_params["offset"] = int(offset)
         if limit:
             list_params["limit"] = int(limit)
+
         r_data = cls._client.get(path, params=list_params).json()
         ret = []
         for si_data in r_data["data"]:
