@@ -1,8 +1,20 @@
+#
+# Copyright 2021-2022 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 """This module is not considered part of the public interface. As of 2.3, anything here
 may change or be removed without warning."""
 
 import os
 import platform
+import warnings
 
 import requests
 from requests.adapters import HTTPAdapter
@@ -12,9 +24,10 @@ from six.moves.urllib_parse import urljoin, urlparse
 import trafaret as t
 from urllib3 import Retry
 
-from . import __version__, errors
 from ._compat import Int, String
+from ._version import __version__
 from .enums import DEFAULT_TIMEOUT
+from .errors import ClientError, JobAlreadyRequested, ProjectDeprecationWarning, ServerError
 from .utils import to_api
 
 
@@ -147,6 +160,7 @@ class RESTClientObject(requests.Session):
         if not url.startswith("http") or join_endpoint:
             url = self._join_endpoint(url)
         response = super(RESTClientObject, self).request(method, url, **kwargs)
+        handle_deprecation_header(response, **kwargs)
         if not response:
             handle_http_error(response, **kwargs)
         return response
@@ -273,13 +287,13 @@ def _http_message(response):
 def handle_http_error(response, **kwargs):
     message = _http_message(response)
     if 400 <= response.status_code < 500:
-        exception_type = errors.ClientError
+        exception_type = ClientError
         # One-off approach to raising special exception for now. We'll do something more
         # systematic when we have more of these:
         try:
             parsed_json = response.json()  # May raise error if response isn't JSON
             if parsed_json.get("errorName") == "JobAlreadyAdded":
-                exception_type = errors.JobAlreadyRequested
+                exception_type = JobAlreadyRequested
         except (ValueError, AttributeError):
             parsed_json = {}
         template = "{} client error: {}"
@@ -288,7 +302,20 @@ def handle_http_error(response, **kwargs):
     else:
         template = "{} server error: {}"
         exc_message = template.format(response.status_code, message)
-        raise errors.ServerError(exc_message, response.status_code)
+        raise ServerError(exc_message, response.status_code)
+
+
+def handle_deprecation_header(response, **kwargs):
+    if "Deprecation" in response.headers:
+        warnings.warn(
+            (
+                "The resource you are trying to access will be or is deprecated. "
+                "For additional guidance, login to the DataRobot app for this project."
+            ),
+            ProjectDeprecationWarning,
+            stacklevel=3,
+        )
+    # TODO Do anything if status_code == 405?
 
 
 class DataRobotClientConfig(object):
