@@ -7,6 +7,7 @@ from datetime import date, datetime
 import re
 
 from dateutil import parser, tz
+import numpy as np
 import pandas as pd
 import pytz
 import six
@@ -106,8 +107,7 @@ def parse_time(time_str):
 
 
 def datetime_to_string(datetime_obj, ensure_rfc_3339=False):
-    """ Converts to isoformat
-    """
+    """Converts to isoformat"""
     if not isinstance(datetime_obj, datetime):
         msg = "expected to be passed a datetime.datetime, was passed {}".format(type(datetime_obj))
         raise ValueError(msg)
@@ -116,6 +116,15 @@ def datetime_to_string(datetime_obj, ensure_rfc_3339=False):
     return datetime_obj.isoformat()
 
 
+def _is_api_object(obj):
+    # local import of APIObject is required due to circular imports between
+    # utils.__init__.py, rest.py, client.py, and api_object.py if APIObject
+    # is imported at the top of the file.
+    from datarobot.models.api_object import APIObject
+
+    return issubclass(type(obj), APIObject)
+
+
 def to_api(data, keep_attrs=None):
     """
     :param data: dictionary {'max_digits': 1}
@@ -123,13 +132,19 @@ def to_api(data, keep_attrs=None):
     """
     if not data:
         return {}
-    assert isinstance(data, dict), "Wrong type"
+    assert isinstance(data, dict) or _is_api_object(data), "Wrong type"
     return _to_api_item(data, keep_attrs)
 
 
+def _to_dict(item):
+    return {k: v for k, v in item.__dict__.items() if not k.startswith("_") and not callable(v)}
+
+
 def _to_api_item(item, keep_attrs=None):
     if isinstance(item, rawdict):
         return item
+    if _is_api_object(item):
+        return _to_api_item(_to_dict(item))
     elif isinstance(item, dict):
         dense_item = remove_empty_keys(item, keep_attrs)
         return {
@@ -187,11 +202,12 @@ def raw_prediction_response_to_dataframe(pred_response, class_prefix):
     # converting larger prediction responses
     predictions = pred_response["predictions"]
     task_type = pred_response["task"]
+
+    frame = pd.DataFrame.from_records(predictions)
+    frame = _underscorize_df_columns(frame)
     if task_type == "Multilabel":
-        frame = _multilabel_predictions_to_dataframe(predictions, class_prefix)
+        frame = _pivot_multilabel_predictions(frame, class_prefix)
     else:
-        frame = pd.DataFrame.from_records(predictions)
-        frame = _underscorize_df_columns(frame)
         has_prediction_values = "prediction_values" in frame.columns
         if has_prediction_values:
             frame = _pivot_prediction_labels(frame, class_prefix)
@@ -212,7 +228,7 @@ def raw_prediction_response_to_dataframe(pred_response, class_prefix):
 
 
 def _underscorize_df_columns(frame):
-    """ Rename the DataFrame columns from the camel case to underscore
+    """Rename the DataFrame columns from the camel case to underscore
 
     Parameters
     ----------
@@ -229,38 +245,58 @@ def _underscorize_df_columns(frame):
     return frame.rename(columns=column_mapping)
 
 
-def _multilabel_predictions_to_dataframe(predictions, class_prefix):
+def _pivot_multilabel_predictions(frame, class_prefix):
     """
-    Converts the predictions from a json prediction API response and converts them into a DataFrame.
+    Explodes the prediction_values column into multiple columns for prediction labels, thresholds,
+    and predictions.
 
     Parameters
     ----------
-    predictions : list(dict)
-        The predictions as returned by the prediction API
+    frame : pandas.DataFrame
+        The initial dataframe obtained from prediction response.
     class_prefix : str
-            The prefix to append to labels in the final dataframe (e.g., apple -> class_apple)
+        The prefix to append to labels in the final dataframe (e.g., apple -> class_apple)
 
     Returns
     -------
     pandas.DataFrame
         The converted predictions
     """
-    rows = []
-    for prediction in predictions:
-        predicted_labels = prediction["prediction"]
-        row = {}
-        row[u"row_id"] = prediction["rowId"]
-        for prediction_value in prediction["predictionValues"]:
-            label = prediction_value["label"]
-            row[u"threshold_{}".format(label)] = prediction_value["threshold"]
-            row[u"{}{}".format(class_prefix, label)] = prediction_value["value"]
-            row[u"prediction_{}".format(label)] = 1 if label in predicted_labels else 0
-        rows.append(row)
-    return pd.DataFrame(rows)
+    if "prediction_values" not in frame:
+        return frame
+    labels = [entry["label"] for entry in frame.prediction_values[0]]
+
+    values = np.empty((frame.shape[0], len(labels)), np.float32)
+    thresholds = np.empty((frame.shape[0], len(labels)), np.float32)
+    predictions = np.empty((frame.shape[0], len(labels)), np.int8)
+    for i, pair in enumerate(zip(frame.prediction_values, frame.prediction)):
+        row, prediction = pair
+        values[i] = np.array([[col["value"] for col in row]])
+        thresholds[i] = np.array([[col["threshold"] for col in row]])
+        predictions[i] = np.array([[1 if col["label"] in prediction else 0 for col in row]])
+
+    values_df = pd.DataFrame(
+        values, columns=[u"{}{}".format(class_prefix, label) for label in labels]
+    )
+    thresholds_df = pd.DataFrame(
+        thresholds, columns=[u"threshold_{}".format(label) for label in labels]
+    )
+    predictions_df = pd.DataFrame(
+        predictions, columns=[u"prediction_{}".format(label) for label in labels]
+    )
+    return pd.concat(
+        [
+            frame.drop(["prediction_values", "prediction"], axis=1),
+            values_df,
+            thresholds_df,
+            predictions_df,
+        ],
+        axis=1,
+    )
 
 
 def _pivot_prediction_explanations(frame, pred_response, has_prediction_values):
-    """ Pivot the prediction_explanations from the dictionary to columns
+    """Pivot the prediction_explanations from the dictionary to columns
 
     frame : DataFrame
         the DataFrame build based on predictions response
@@ -318,7 +354,7 @@ def _pivot_prediction_explanations(frame, pred_response, has_prediction_values):
 
 
 def _pivot_prediction_labels(frame, class_prefix):
-    """ Pivot the prediciton_values from the dictionary to columns
+    """Pivot the prediciton_values from the dictionary to columns
 
     Parameters
     ----------
@@ -336,7 +372,7 @@ def _pivot_prediction_labels(frame, class_prefix):
             wrapper[col_name].append(pred_value["value"])
     pred_frame = pd.DataFrame.from_records(wrapper)
     frame = pd.concat([frame, pred_frame], axis=1)
-    return frame.drop("prediction_values", 1)
+    return frame.drop("prediction_values", axis=1)
 
 
 def encode_utf8_if_py2(string):
