@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import csv
 from datetime import datetime
 import json
@@ -250,7 +261,10 @@ def test_request_frozen_datetime_with_end_date_and_duration(
     # training_start_date is passed in, we should pass the request to API, and it should fail on
     # BE side.
     responses.add(
-        responses.POST, "{}frozenDatetimeModels/".format(project_url), body="", status=422,
+        responses.POST,
+        "{}frozenDatetimeModels/".format(project_url),
+        body="",
+        status=422,
     )
 
     with pytest.raises(ClientError):
@@ -586,13 +600,18 @@ def test_compute_datetime_trend_plots(unittest_endpoint, datetime_model, project
 
 @responses.activate
 def test_retrieved_model_is_of_datetime_model_from_model_instance(
-    datetime_project_server_data, datetime_start_end_model_server_data, project_url,
+    datetime_project_server_data,
+    datetime_start_end_model_server_data,
+    project_url,
 ):
     project_id = datetime_start_end_model_server_data["projectId"]
     model_id = datetime_start_end_model_server_data["id"]
 
     responses.add(
-        responses.GET, project_url, status=200, json=datetime_project_server_data,
+        responses.GET,
+        project_url,
+        status=200,
+        json=datetime_project_server_data,
     )
     responses.add(
         responses.GET,
