@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import datetime
 
 import pytest
@@ -8,6 +19,7 @@ from six.moves.urllib_parse import parse_qs, urlparse
 import trafaret
 
 from datarobot import (
+    AdvancedOptions,
     BacktestSpecification,
     DatetimePartitioning,
     DatetimePartitioningSpecification,
@@ -847,6 +859,37 @@ def test_create_project_with_differencing_method(
     assert request_message["differencingMethod"] == spec_fixture.differencing_method
 
 
+@responses.activate
+def test_supervised_reduction_on_by_default(datetime_partition_spec_extra_time_series_controls):
+    spec_fixture = datetime_partition_spec_extra_time_series_controls
+    prep_successful_aim_responses()
+
+    # by default not important features are reduced during feature generation
+    Project("p-id").set_target(
+        "SalePrice",
+        metric="RMSE",
+        partitioning_method=spec_fixture,
+        advanced_options=AdvancedOptions(),
+    )
+
+    request_message = request_body_to_json(responses.calls[0].request)
+    assert request_message["useSupervisedFeatureReduction"] is True
+
+
+@responses.activate
+def test_turn_off_supervised_reduction(datetime_partition_spec_extra_time_series_controls):
+    spec_fixture = datetime_partition_spec_extra_time_series_controls
+    prep_successful_aim_responses()
+    # now set use_supervised_feature_reduction to False
+    opts = AdvancedOptions(use_supervised_feature_reduction=False)
+    Project("p-id").set_target(
+        "SalePrice", metric="RMSE", partitioning_method=spec_fixture, advanced_options=opts
+    )
+
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body["useSupervisedFeatureReduction"] is False
+
+
 @responses.activate
 def test_retrieve_otp_without_holdout(
     project_id, project_url, datetime_partition_without_holdout_server_data
@@ -1021,7 +1064,10 @@ def test_time_series_feature_log_retrieve(project_id, project_url):
 
 @responses.activate
 def test_time_series_optimized_partitioining(
-    project_id, project_url, datetime_partition_spec, datetime_partition_after_target_server_data,
+    project_id,
+    project_url,
+    datetime_partition_spec,
+    datetime_partition_after_target_server_data,
 ):
     responses.add(
         responses.POST,
