@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import dateutil
@@ -50,9 +61,27 @@ def assert_deployment(deployment, deployment_data):
             prediction_usage_from_api["lastTimestamp"]
         )
 
+    governance_data = deployment_data["governance"]
+    assert deployment.governance["approval_status"] == governance_data["approvalStatus"]
+    assert (
+        deployment.governance["has_opened_change_requests"]
+        == governance_data["hasOpenedChangeRequests"]
+    )
+    assert deployment.owners == deployment_data["owners"]
+
+    prediction_env_from_api = deployment_data["predictionEnvironment"]
+    assert deployment.prediction_environment["id"] == prediction_env_from_api["id"]
+    assert (
+        deployment.prediction_environment["is_managed_by_management_agent"]
+        == prediction_env_from_api["isManagedByManagementAgent"]
+    )
+    assert deployment.prediction_environment["name"] == prediction_env_from_api["name"]
+    assert deployment.prediction_environment["platform"] == prediction_env_from_api["platform"]
+
     assert_health(deployment.service_health, deployment_data["serviceHealth"])
     assert_health(deployment.model_health, deployment_data["modelHealth"])
     assert_health(deployment.accuracy_health, deployment_data["accuracyHealth"])
+    assert_health(deployment.fairness_health, deployment_data["fairnessHealth"])
 
     repr = "Deployment({label})".format(label=deployment_data["label"])
     assert str(deployment) == repr
@@ -127,6 +156,8 @@ class TestDeploymentCreateFromLearningModel(object):
             "loan is bad",
             "predict if a loan is gonna default",
             "5c0fcdb8962d74370dd0c38e",
+            "HIGH",
+            0.7,
         )
 
         create_body = request_body_to_json(responses.calls[0].request)
@@ -134,6 +165,8 @@ class TestDeploymentCreateFromLearningModel(object):
         assert create_body["label"] == "loan is bad"
         assert create_body["description"] == "predict if a loan is gonna default"
         assert create_body["defaultPredictionServerId"] == "5c0fcdb8962d74370dd0c38e"
+        assert create_body["importance"] == "HIGH"
+        assert create_body["predictionThreshold"] == 0.7
 
 
 @pytest.mark.parametrize("from_version", [True, False])
@@ -184,6 +217,10 @@ class TestDeploymentCreateFromCustomModel(object):
     def prediction_server_id(self):
         return "5c0fcdb8962d74370dd0c38e"
 
+    @pytest.fixture
+    def importance(self):
+        return "CRITICAL"
+
     @pytest.fixture
     def model_package_get_response(
         self, get_model_package_url, custom_model_entity_id, model_package_data
@@ -228,27 +265,38 @@ class TestDeploymentCreateFromCustomModel(object):
         model_package_data,
         deployment_data,
         prediction_server_id,
+        importance,
+        from_version,
         create_deployment_url,
         get_deployment_url,
         get_status_url,
     ):
         def _assert(
-            create_deployment_req, get_status_req, get_deployment_req,
+            create_deployment_req,
+            get_status_req,
+            get_deployment_req,
         ):
             assert create_deployment_req.method == "POST"
             assert create_deployment_req.url == create_deployment_url
             create_body = request_body_to_json(create_deployment_req)
-            assert set(create_body) == {
+            expected_body_attrs = {
                 "modelPackageId",
                 "label",
                 "description",
                 "defaultPredictionServerId",
             }
+            if from_version:
+                expected_body_attrs.add("importance")
+
+            assert set(create_body) == expected_body_attrs
             assert create_body["modelPackageId"] == model_package_data["id"]
             assert create_body["label"] == "My deployment"
             assert create_body["description"] == "deployment description"
             assert create_body["defaultPredictionServerId"] == prediction_server_id
 
+            if from_version:
+                assert create_body["importance"] == importance
+
             assert get_status_req.method == "GET"
             assert get_status_req.url == get_status_url
 
@@ -267,6 +315,7 @@ class TestDeploymentCreateFromCustomModel(object):
         self,
         custom_model_entity_id,
         prediction_server_id,
+        importance,
         get_model_package_url,
         _assert_deployment_creation,
         from_version,
@@ -278,7 +327,7 @@ class TestDeploymentCreateFromCustomModel(object):
             prediction_server_id,
         ]
         if from_version:
-            Deployment.create_from_custom_model_version(*args)
+            Deployment.create_from_custom_model_version(*args, importance=importance)
         else:
             Deployment.create_from_custom_model_image(*args)
 
@@ -306,6 +355,7 @@ class TestDeploymentCreateFromCustomModel(object):
         self,
         custom_model_entity_id,
         prediction_server_id,
+        importance,
         get_model_package_url,
         create_model_package_url,
         _assert_deployment_creation,
@@ -318,7 +368,7 @@ class TestDeploymentCreateFromCustomModel(object):
             prediction_server_id,
         ]
         if from_version:
-            Deployment.create_from_custom_model_version(*args)
+            Deployment.create_from_custom_model_version(*args, importance=importance)
         else:
             Deployment.create_from_custom_model_image(*args)
 
@@ -534,6 +584,18 @@ class TestDeploymentUpdate(object):
         request_json = json.loads(responses.calls[1].request.body)
         assert request_json["description"] == "new description"
 
+    @responses.activate
+    @pytest.mark.usefixtures("deployment_get_response", "deployment_update_response")
+    def test_update_importance(self, deployment_data):
+        deployment = Deployment.get(deployment_data["id"])
+        deployment.update(importance="LOW")
+
+        assert responses.calls[1].request.method == "PATCH"
+        assert responses.calls[1].request.url.endswith("/deployments/5c6f7a9e9ca9b20017ff95a2/")
+
+        request_json = json.loads(responses.calls[1].request.body)
+        assert request_json["importance"] == "LOW"
+
 
 class TestDeploymentListFilters(object):
     @pytest.mark.parametrize(
