@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from copy import deepcopy
 import json
 
@@ -221,7 +232,7 @@ def feature_impact_previously_ran_response__no_job_id(project_url, model_id):
 def _feature_impact_previously_ran_response(project_url, model_id, job_id, message=None):
     """
     Loads a response that the given model has already ran its feature impact
-     """
+    """
     body = {
         "message": message or "Feature Impact is in progress for this model.",
         "errorName": "JobAlreadyAdded",
@@ -440,76 +451,6 @@ def mocked_custom_model_version_with_required_metadata(mocked_versions):
     return next(version for version in mocked_versions["data"] if version.get("requiredMetadata"))
 
 
-@pytest.fixture
-def shap_impact_url(project_id, model_id):
-    return "https://host_name.com/projects/{}/models/{}/shapImpact/".format(project_id, model_id)
-
-
-@pytest.fixture
-def shap_impact_job_creation_response(shap_impact_url, job_url):
-    responses.add(
-        responses.POST, shap_impact_url, body="", status=202, adding_headers={"Location": job_url}
-    )
-
-
-@pytest.fixture
-def shap_impact_response(shap_impact_server_data, shap_impact_url):
-    body = json.dumps(shap_impact_server_data)
-    responses.add(
-        responses.GET, shap_impact_url, status=200, content_type="application/json", body=body
-    )
-
-
-@pytest.fixture
-def shap_impact_job_running_server_data(base_job_running_server_data):
-    return dict(base_job_running_server_data, jobType="shapImpact")
-
-
-@pytest.fixture
-def shap_impact_job_finished_server_data(base_job_completed_server_data):
-    return dict(base_job_completed_server_data, jobType="shapImpact")
-
-
-@pytest.fixture
-def shap_impact_running_response(shap_impact_job_running_server_data, job_url):
-    responses.add(
-        responses.GET,
-        job_url,
-        body=json.dumps(shap_impact_job_running_server_data),
-        status=200,
-        content_type="application/json",
-    )
-
-
-@pytest.fixture
-def shap_impact_completed_response(shap_impact_job_finished_server_data, job_url, shap_impact_url):
-    responses.add(
-        responses.GET,
-        job_url,
-        body=json.dumps(shap_impact_job_finished_server_data),
-        status=303,
-        adding_headers={"Location": shap_impact_url},
-        content_type="application/json",
-    )
-
-
-@pytest.fixture
-def shap_impact_previously_ran_response(project_url, model_id, job_id, job_url):
-    body = {
-        "message": "SHAP impact already exists.",
-        "errorName": "JobAlreadyAdded",
-        "jobId": job_id,
-    }
-    responses.add(
-        responses.POST,
-        "{}models/{}/shapImpact/".format(project_url, model_id),
-        body=json.dumps(body),
-        status=202,
-        content_type="application/json",
-        adding_headers={"Location": job_url},
-    )
-
-
 # CustomTask and CustomTaskVersion
 
 
@@ -581,9 +522,89 @@ def training_history():
     ]
 
 
+@pytest.fixture
+def custom_task_version_arguments():
+    return [
+        {
+            "key": "user_param___param_float",
+            "argument": {
+                "name": "param_float",
+                "type": "float",
+                "default": 0.5,
+                "values": [0.0, 1.0],
+            },
+        },
+        {
+            "key": "user_param___param_floatgrid",
+            "argument": {
+                "name": "param_floatgrid",
+                "type": "floatgrid",
+                "default": 0.5,
+                "values": [0.0, 1.0],
+            },
+        },
+        {
+            "key": "user_param___param_int",
+            "argument": {"name": "param_int", "type": "int", "default": 1, "values": [0, 1]},
+        },
+        {
+            "key": "user_param___param_intgrid",
+            "argument": {
+                "name": "param_intgrid",
+                "type": "intgrid",
+                "default": 1,
+                "values": [0, 1],
+            },
+        },
+        {
+            "key": "user_param___param_multi",
+            "argument": {
+                "name": "param_multi",
+                "type": "multi",
+                "default": 1,
+                "values": {
+                    "int": [0, 1],
+                    "float": [0.0, 1.0],
+                    "select": {"values": ["a", "b", "c"]},
+                },
+            },
+        },
+        {
+            "key": "user_param___param_sel",
+            "argument": {
+                "name": "param_sel",
+                "type": "select",
+                "default": "b",
+                "values": ["a", "b", "c"],
+            },
+        },
+        {
+            "key": "user_param___param_selgrid",
+            "argument": {
+                "name": "param_selgrid",
+                "type": "selectgrid",
+                "default": "b",
+                "values": ["a", "b", "c"],
+            },
+        },
+        {
+            "key": "user_param___param_string",
+            "argument": {
+                "name": "param_string",
+                "type": "unicode",
+                "default": "default string",
+                "values": [],
+            },
+        },
+    ]
+
+
 @pytest.fixture
 def custom_task_version_with_optional_values(
-    custom_task_version, workspace_items, training_history
+    custom_task_version,
+    workspace_items,
+    training_history,
+    custom_task_version_arguments,
 ):
     new_task_version = deepcopy(custom_task_version)
     new_task_version.update(
@@ -602,6 +623,7 @@ def custom_task_version_with_optional_values(
             "trainingHistory": training_history,
             "requiredMetadata": {"hello": "world"},
             "requiredMetadataValues": [{"fieldName": "hello", "value": "world"}],
+            "arguments": custom_task_version_arguments,
         }
     )
     return new_task_version
@@ -667,3 +689,15 @@ def custom_task_list_response(custom_task_response_json):
         "next": None,
         "data": [custom_task_response_json, second],
     }
+
+
+@pytest.fixture
+def custom_task_version_dependency_build_server_data(custom_task_id, custom_task_version_id):
+    return {
+        "customTaskId": custom_task_id,
+        "customTaskVersionId": custom_task_version_id,
+        "buildStart": "2018-11-19T14:18:01.468272Z",
+        "buildEnd": "2018-11-19T15:18:01.468272Z",
+        "buildStatus": "success",
+        "buildLogLocation": "https://127.0.0.1/logs/",
+    }
