@@ -1,9 +1,21 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from copy import copy, deepcopy
 import json
 from tempfile import NamedTemporaryFile
 
 import pytest
 import responses
+import six
 
 from datarobot import CustomInferenceModel, TARGET_TYPE
 from datarobot.enums import CUSTOM_MODEL_TARGET_TYPE
@@ -102,7 +114,11 @@ def assert_inference_model(model, model_json):
 
 def mock_get_response(url, response):
     responses.add(
-        responses.GET, url, status=200, content_type="application/json", body=json.dumps(response),
+        responses.GET,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(response),
     )
 
 
@@ -226,7 +242,10 @@ class TestCustomInferenceModel(object):
 
         mock_get_response(url, mocked_inference_model)
         responses.add(
-            responses.DELETE, url, status=204, content_type="application/json",
+            responses.DELETE,
+            url,
+            status=204,
+            content_type="application/json",
         )
 
         model = CustomInferenceModel.get(mocked_inference_model["id"])
@@ -258,7 +277,7 @@ class TestCustomInferenceModel(object):
         model.download_latest_version(downloaded_file_path)
 
         # assert
-        downloaded_file.read() == b"content"
+        assert six.ensure_binary(downloaded_file.read()) == b"content"
 
         assert responses.calls[0].request.method == "GET"
         assert responses.calls[0].request.url == url
