@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from collections import defaultdict
 from copy import deepcopy
 import json
@@ -8,6 +19,7 @@ import mock
 import pytest
 from requests_toolbelt import MultipartEncoder
 import responses
+import six
 
 from datarobot import CustomModelVersion
 from datarobot.models.custom_model_version import RequiredMetadataValue
@@ -38,7 +50,11 @@ def make_versions_url(unittest_endpoint):
 
 def mock_get_response(url, response):
     responses.add(
-        responses.GET, url, status=200, content_type="application/json", body=json.dumps(response),
+        responses.GET,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(response),
     )
 
 
@@ -146,7 +162,7 @@ def test_download(mocked_version, make_versions_url, tmpdir):
     version.download(downloaded_file_path)
 
     # assert
-    downloaded_file.read() == b"content"
+    assert six.ensure_binary(downloaded_file.read()) == b"content"
 
     assert responses.calls[0].request.method == "GET"
     assert responses.calls[0].request.url == url
@@ -157,7 +173,9 @@ def test_download(mocked_version, make_versions_url, tmpdir):
 @responses.activate
 @pytest.mark.parametrize("use_deprecated_metadata", [True, False])
 def test_update(
-    mocked_custom_model_version_with_required_metadata, make_versions_url, use_deprecated_metadata,
+    mocked_custom_model_version_with_required_metadata,
+    make_versions_url,
+    use_deprecated_metadata,
 ):
     mocked_version = mocked_custom_model_version_with_required_metadata
     # arrange
@@ -578,7 +596,10 @@ def test_calculate_feature_impact(unittest_endpoint, mocked_version, make_versio
     )
 
     responses.add(
-        responses.GET, status_url, headers={"Location": url}, status=303,
+        responses.GET,
+        status_url,
+        headers={"Location": url},
+        status=303,
     )
 
     # act
