@@ -1,18 +1,34 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
+import copy
 from copy import deepcopy
 import json
 import os
 from shutil import rmtree
 
+import mock
 import pytest
 from requests_toolbelt import MultipartEncoder
 import responses
 from trafaret import DataError
 
+from datarobot import errors
+from datarobot.enums import DEFAULT_MAX_WAIT
 from datarobot.models.custom_model_version import RequiredMetadataValue
 from datarobot.models.custom_task_version import CustomTaskFileItem, CustomTaskVersion
 from datarobot.utils import camelize, underscorize
 from tests.model.utils import (
     assert_custom_task_version,
+    assert_custom_task_version_dependency_build,
     assert_items,
     assert_single_api_call,
     change_response_value,
@@ -54,6 +70,24 @@ def version_get_response(version_url, custom_task_version_response_json):
     add_mock_get_response(version_url, custom_task_version_response_json)
 
 
+@pytest.fixture
+def dependency_img_build_route(unittest_endpoint, custom_task_id, custom_task_version_id):
+    return "{}/customTasks/{}/versions/{}/dependencyBuild/".format(
+        unittest_endpoint,
+        custom_task_id,
+        custom_task_version_id,
+    )
+
+
+@pytest.fixture
+def dependency_img_build_log_route(unittest_endpoint, custom_task_id, custom_task_version_id):
+    return "{}/customTasks/{}/versions/{}/dependencyBuildLog/".format(
+        unittest_endpoint,
+        custom_task_id,
+        custom_task_version_id,
+    )
+
+
 FILE_ITEM_RESPONSE_KEYS = [camelize(el.name) for el in CustomTaskFileItem.schema.keys]
 
 
@@ -349,11 +383,13 @@ class TestCreateMethods:
             http_method, versions_base_url, json.dumps(custom_task_version_response_json)
         )
 
+        maxmem = 1337
         base_env_id = "abc123"
         required_metadata = {"HI_THERE": "stuff"}
         attrs = dict(
             custom_task_id=custom_task_id,
             base_environment_id=base_env_id,
+            maximum_memory=maxmem,
             is_major_update=is_major_update,
             required_metadata=required_metadata,
         )
@@ -361,6 +397,7 @@ class TestCreateMethods:
             "baseEnvironmentId": [base_env_id],
             "isMajorUpdate": [str(is_major_update)],
             "requiredMetadata": [json.dumps(required_metadata)],
+            "maximumMemory": [str(maxmem)],
         }
 
         create_method(**attrs)
@@ -528,7 +565,10 @@ class TestCreateMethods:
 
     @responses.activate
     def test_create_from_previous_files_to_delete(
-        self, versions_base_url, custom_task_id, custom_task_version_response_json,
+        self,
+        versions_base_url,
+        custom_task_id,
+        custom_task_version_response_json,
     ):
         add_mock_response(
             responses.PATCH, versions_base_url, json.dumps(custom_task_version_response_json)
@@ -540,3 +580,159 @@ class TestCreateMethods:
         fields = fields_to_dict(responses.calls[0].request.body)
         assert set(fields["filesToDelete"]) == {"abc", "def"}
         assert len(fields["filesToDelete"]) == 2
+
+
+class TestDependencyImageBuild:
+    @responses.activate
+    def test_start_dependency_build__no_waiting(
+        self,
+        dependency_img_build_route,
+        custom_task_version,
+        custom_task_version_dependency_build_server_data,
+    ):
+        version = CustomTaskVersion.from_server_data(custom_task_version)
+        responses.add(
+            responses.POST,
+            dependency_img_build_route,
+            status=202,
+            content_type="application/json",
+            json=custom_task_version_dependency_build_server_data,
+        )
+
+        dependency_build = version.start_dependency_build()
+        assert len(responses.calls) == 1
+        assert_custom_task_version_dependency_build(
+            dependency_build, custom_task_version_dependency_build_server_data
+        )
+
+    @responses.activate
+    def test_start_dependency_build__with_waiting(
+        self,
+        dependency_img_build_route,
+        custom_task_version,
+        custom_task_version_dependency_build_server_data,
+    ):
+        version = CustomTaskVersion.from_server_data(custom_task_version)
+        # simulate the response of starting a dependency image build
+        response_data = copy.copy(custom_task_version_dependency_build_server_data)
+        responses.add(
+            responses.POST,
+            dependency_img_build_route,
+            status=202,
+            content_type="application/json",
+            json=response_data,
+        )
+        # simulate the 1st pull of status
+        response_data = copy.copy(custom_task_version_dependency_build_server_data)
+        response_data["buildStatus"] = "processing"
+        responses.add(
+            responses.GET,
+            dependency_img_build_route,
+            status=200,
+            content_type="application/json",
+            json=response_data,
+        )
+        # simulate the 2nd pull of status
+        response_data = copy.copy(custom_task_version_dependency_build_server_data)
+        response_data["buildStatus"] = "success"
+        responses.add(
+            responses.GET,
+            dependency_img_build_route,
+            status=200,
+            content_type="application/json",
+            json=response_data,
+        )
+
+        with mock.patch("time.sleep"):
+            dependency_build = version.start_dependency_build_and_wait(max_wait=DEFAULT_MAX_WAIT)
+        assert len(responses.calls) == 3
+        # check the final response
+        assert_custom_task_version_dependency_build(dependency_build, response_data)
+
+    @responses.activate
+    def test_start_dependency_build__raise_timeout_error(
+        self,
+        dependency_img_build_route,
+        custom_task_version,
+        custom_task_version_dependency_build_server_data,
+    ):
+        version = CustomTaskVersion.from_server_data(custom_task_version)
+        # simulate the response of starting a dependency image build
+        response_data = custom_task_version_dependency_build_server_data
+        responses.add(
+            responses.POST,
+            dependency_img_build_route,
+            status=202,
+            content_type="application/json",
+            json=response_data,
+        )
+        # simulate the pull of status
+        response_data["buildStatus"] = "processing"
+        responses.add(
+            responses.GET,
+            dependency_img_build_route,
+            status=200,
+            content_type="application/json",
+            json=response_data,
+        )
+
+        with mock.patch("time.sleep"):
+            with pytest.raises(errors.AsyncTimeoutError):
+                version.start_dependency_build_and_wait(max_wait=0)
+
+    @responses.activate
+    def test_get_dependency_build(
+        self,
+        dependency_img_build_route,
+        custom_task_version,
+        custom_task_version_dependency_build_server_data,
+    ):
+        version = CustomTaskVersion.from_server_data(custom_task_version)
+        response_data = custom_task_version_dependency_build_server_data
+        responses.add(
+            responses.GET,
+            dependency_img_build_route,
+            status=200,
+            content_type="application/json",
+            json=response_data,
+        )
+        build_info = version.get_dependency_build()
+        assert len(responses.calls) == 1
+        assert_custom_task_version_dependency_build(build_info, response_data)
+
+    @responses.activate
+    @pytest.mark.parametrize("file_directory", [False, "file_directory"])
+    def test_download_dependency_build_log(
+        self,
+        file_directory,
+        dependency_img_build_log_route,
+        custom_task_version,
+        tmpdir,
+    ):
+        version = CustomTaskVersion.from_server_data(custom_task_version)
+        responses.add(
+            responses.GET,
+            dependency_img_build_log_route,
+            status=200,
+            body="body",
+            headers={"Content-Disposition": "attachment; filename=default_filename"},
+        )
+
+        downloaded_file = tmpdir.mkdir(file_directory) if file_directory else tmpdir
+        version.download_dependency_build_log(file_directory=str(downloaded_file))
+        assert len(responses.calls) == 1
+        downloaded_file = (
+            tmpdir.join(file_directory, "default_filename")
+            if file_directory
+            else tmpdir.join("default_filename")
+        )
+        assert downloaded_file.read() == "body"
+
+    @responses.activate
+    def test_cancel_dependency_build(self, dependency_img_build_route, custom_task_version):
+        version = CustomTaskVersion.from_server_data(custom_task_version)
+        responses.add(responses.DELETE, dependency_img_build_route, status=204)
+
+        version.cancel_dependency_build()
+
+        assert len(responses.calls) == 1
