@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from copy import deepcopy
 import json
 import os
@@ -85,7 +96,7 @@ def empty_dataset_details(dataset_id):
         "dataEngineQueryId": None,
         "dataSourceId": None,
         "dataSourceType": "",
-        "description": None,
+        "description": "",
         "eda1ModificationDate": None,
         "eda1ModifierFullName": None,
         "error": "",
@@ -203,7 +214,10 @@ def dataset_get_response(dataset_url, mock_dataset_full_response):
 @pytest.fixture()
 def dataset_delete_response(dataset_url, mock_dataset):
     responses.add(
-        responses.DELETE, dataset_url, status=204, content_type="application/json",
+        responses.DELETE,
+        dataset_url,
+        status=204,
+        content_type="application/json",
     )
 
 
@@ -253,7 +267,10 @@ def test_delete_dataset(mock_dataset):
 def test_un_delete_dataset(dataset_url, dataset_id):
     url = "{}deleted/".format(dataset_url)
     responses.add(
-        responses.PATCH, url, status=204, content_type="application/json",
+        responses.PATCH,
+        url,
+        status=204,
+        content_type="application/json",
     )
 
     Dataset.un_delete(dataset_id)
@@ -815,7 +832,10 @@ class TestDatasetCreation(object):
 
         # return 400 since all we care is that read_timeout is passed down to the HTTP request
         responses.add(
-            responses.POST, "https://host_name.com/datasets/fromFile/", body="", status=400,
+            responses.POST,
+            "https://host_name.com/datasets/fromFile/",
+            body="",
+            status=400,
         )
 
         with mock.patch.object(
@@ -1290,6 +1310,30 @@ class TestDatasetCreation(object):
             "useKerberos": use_kerberos,
         }
 
+    @pytest.fixture
+    def set_up_query_generator(self, unittest_endpoint, status_location, set_status_response):
+        responses.add(
+            responses.POST,
+            "{}/dataEngineWorkspaceStates/fromDataEngineQueryGenerator/".format(unittest_endpoint),
+            body=json.dumps({"workspaceStateId": "someWorkspaceStateId"}),
+            status=201,
+            content_type="application_json",
+        )
+        self.add_mock_upload_response(
+            "{}/datasets/fromDataEngineWorkspaceState/".format(unittest_endpoint), status_location
+        )
+
+    @responses.activate
+    @pytest.mark.usefixtures("set_up_query_generator")
+    def test_create_from_query_generator(self, mock_dataset):
+
+        data_source_id = "5acc8437ec8d670001ba16bf"
+        result = Dataset.create_from_query_generator(generator_id=data_source_id)
+
+        assert_dataset(result, mock_dataset)
+        post_params = request_body_to_json(responses.calls[0].request)
+        assert post_params == {"queryGeneratorId": data_source_id}
+
 
 class TestDatasetDetails(object):
     @staticmethod
