@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from copy import deepcopy
 import json
 
@@ -33,7 +44,11 @@ def make_environments_url(unittest_endpoint):
 
 def mock_get_response(url, response):
     responses.add(
-        responses.GET, url, status=200, content_type="application/json", body=json.dumps(response),
+        responses.GET,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(response),
     )
 
 
@@ -188,7 +203,10 @@ def test_delete(mocked_environment, make_environments_url):
 
     mock_get_response(url, mocked_environment)
     responses.add(
-        responses.DELETE, url, status=204, content_type="application/json",
+        responses.DELETE,
+        url,
+        status=204,
+        content_type="application/json",
     )
 
     execution_environment = ExecutionEnvironment.get(mocked_environment["id"])
