@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import pytest
@@ -8,6 +19,7 @@ from datarobot.models.feature_effect import (
     FeatureEffectMetadata,
     FeatureEffectMetadataDatetime,
     FeatureEffects,
+    FeatureEffectsMulticlass,
 )
 
 
@@ -76,6 +88,21 @@ def feature_effect_server_data():
                 "featureName": "record_min_temp_year",
                 "weightLabel": None,
                 "featureImpactScore": 1,
+                "isBinnable": False,
+                "isScalable": True,
+                "individualConditionalExpectation": {
+                    "isCapped": True,
+                    "data": [
+                        [
+                            {"dependence": 3.574459450887747, "label": "3"},
+                            {"dependence": 8.398920976345721, "label": "4"},
+                        ],
+                        [
+                            {"dependence": 2.843083411286525, "label": "3"},
+                            {"dependence": 1.4162371027540206, "label": "4"},
+                        ],
+                    ],
+                },
             },
             {
                 "featureType": "categorical",
@@ -97,6 +124,21 @@ def feature_effect_server_data():
                 "featureName": "date (Day of Week)",
                 "weightLabel": None,
                 "featureImpactScore": 0.2,
+                "isBinnable": False,
+                "isScalable": None,
+                "individualConditionalExpectation": {
+                    "isCapped": True,
+                    "data": [
+                        [
+                            {"dependence": 3.574459450887747, "label": "3"},
+                            {"dependence": 8.398920976345721, "label": "4"},
+                        ],
+                        [
+                            {"dependence": 2.843083411286525, "label": "3"},
+                            {"dependence": 1.4162371027540206, "label": "4"},
+                        ],
+                    ],
+                },
             },
             {
                 "featureType": "categorical",
@@ -111,11 +153,50 @@ def feature_effect_server_data():
                 "featureName": "date (Day of Week) no pvsa",
                 "weightLabel": None,
                 "featureImpactScore": 0.1,
+                "isBinnable": True,
+                "isScalable": None,
+                "individualConditionalExpectation": {
+                    "isCapped": True,
+                    "data": [
+                        [
+                            {"dependence": 3.574459450887747, "label": "3"},
+                            {"dependence": 8.398920976345721, "label": "4"},
+                        ],
+                        [
+                            {"dependence": 2.843083411286525, "label": "3"},
+                            {"dependence": 1.4162371027540206, "label": "4"},
+                        ],
+                    ],
+                },
             },
         ],
     }
 
 
+@pytest.fixture
+def multiclass_feature_effects_server_data(feature_effect_server_data):
+    server_data = dict(feature_effect_server_data)
+    feature_effects = server_data.pop("featureEffects")
+    multiclass_feature_effects = list()
+    for class_ in ["a", "b", "c"]:
+        for item in feature_effects:
+            # 'individualConditionalExpectation' is not calculated for multiclass projects
+            item.pop("individualConditionalExpectation", None)
+            multiclass_item = dict(item)
+            multiclass_item["class"] = class_
+            multiclass_feature_effects.append(multiclass_item)
+    server_data.update(
+        {
+            "next": None,
+            "previous": None,
+            "count": len(multiclass_feature_effects),
+            "totalCount": len(multiclass_feature_effects),
+            "data": multiclass_feature_effects,
+        }
+    )
+    return server_data
+
+
 @pytest.fixture
 def feature_effect_server_data_holdout(feature_effect_server_data):
     feature_effect_server_data_holdout = dict(feature_effect_server_data)
@@ -141,16 +222,43 @@ def feature_effect_server_data_datetime_holdout(feature_effect_server_data_datet
 @pytest.fixture
 def feature_effect_response(feature_effect_server_data, feature_effect_url):
     source = "training"
+    include_ice_plots = True
     body = json.dumps(feature_effect_server_data)
     responses.add(
         responses.GET,
-        "{}?source={}".format(feature_effect_url, source),
+        "{}?source={},includeIcePlots={}".format(feature_effect_url, source, include_ice_plots),
         status=200,
         content_type="application/json",
         body=body,
     )
 
 
+@pytest.fixture
+def multiclass_feature_effect_response(
+    multiclass_feature_effects_server_data, multiclass_feature_effects_url
+):
+    responses.add(
+        responses.GET,
+        multiclass_feature_effects_url + "?source=training",
+        status=200,
+        content_type="application/json",
+        body=json.dumps(multiclass_feature_effects_server_data),
+    )
+
+
+@pytest.fixture
+def multiclass_feature_effect_response_datetime(
+    multiclass_feature_effects_server_data, multiclass_feature_effects_url_datetime
+):
+    responses.add(
+        responses.GET,
+        multiclass_feature_effects_url_datetime + "?source=training&backtestIndex=0",
+        status=200,
+        content_type="application/json",
+        body=json.dumps(multiclass_feature_effects_server_data),
+    )
+
+
 @pytest.fixture
 def feature_effect_response_holdout(feature_effect_server_data_holdout, feature_effect_url):
     source = "holdout"
@@ -184,9 +292,12 @@ def feature_effect_response_datetime(
 ):
     source = "training"
     backtest_index = "0"
+    include_ice_plots = True
     responses.add(
         responses.GET,
-        "{}?source={}&backtestIndex=".format(feature_effect_url_datetime, source, backtest_index),
+        "{}?source={}&backtestIndex={},includeIcePlots={}".format(
+            feature_effect_url_datetime, source, backtest_index, include_ice_plots
+        ),
         status=200,
         content_type="application/json",
         body=json.dumps(feature_effect_server_data_datetime),
@@ -251,6 +362,20 @@ def feature_effect_url_datetime(project_id, model_id):
     )
 
 
+@pytest.fixture
+def multiclass_feature_effects_url(project_id, model_id):
+    return "https://host_name.com/projects/{}/models/{}/multiclassFeatureEffects/".format(
+        project_id, model_id
+    )
+
+
+@pytest.fixture
+def multiclass_feature_effects_url_datetime(project_id, model_id):
+    return "https://host_name.com/projects/{}/datetimeModels/{}/multiclassFeatureEffects/".format(
+        project_id, model_id
+    )
+
+
 @pytest.fixture
 def feature_effect_job_running_server_data(base_job_running_server_data):
     return dict(base_job_running_server_data, jobType=enums.JOB_TYPE.FEATURE_EFFECTS)
@@ -272,6 +397,30 @@ def feature_effect_job_creation_response(feature_effect_url, job_url):
     )
 
 
+@pytest.fixture
+def multiclass_feature_effect_job_creation_response(multiclass_feature_effect_url, job_url):
+    responses.add(
+        responses.POST,
+        multiclass_feature_effect_url,
+        body="",
+        status=202,
+        adding_headers={"Location": job_url},
+    )
+
+
+@pytest.fixture
+def multiclass_feature_effect_job_creation_response_datetime(
+    multiclass_feature_effects_url_datetime, job_url
+):
+    responses.add(
+        responses.POST,
+        multiclass_feature_effects_url_datetime,
+        body=json.dumps({"backtestIndex": "0"}),
+        status=202,
+        adding_headers={"Location": job_url},
+    )
+
+
 @pytest.fixture
 def feature_effect_job_creation_bad_request(feature_effect_url):
     body = {"message": "Invalid field data", "errors": {"rowCount": "value is less than 10"}}
@@ -351,7 +500,7 @@ def feature_effect_running_response(feature_effect_job_running_server_data, job_
 def feature_effect_previously_ran_response(feature_effect_url, job_id):
     """
     Loads a response that the given model has already ran its feature effect
-     """
+    """
     body = {
         "message": "Feature Effect is in progress for this model.",
         "errorName": "JobAlreadyAdded",
@@ -370,7 +519,7 @@ def feature_effect_previously_ran_response(feature_effect_url, job_id):
 def feature_effect_previously_ran_response_datetime(feature_effect_url_datetime, job_id):
     """
     Loads a response that the given model has already ran its feature effect
-     """
+    """
     body = {
         "message": "Feature Effect is in progress for this model.",
         "errorName": "JobAlreadyAdded",
@@ -422,7 +571,10 @@ def test_get_feature_effect_metadata(
 
 @responses.activate
 def test_get_feature_effect_metadata_datetime(
-    feature_effect_metadata_datetime, feature_effect_metadata_url_datetime, project_id, model_id,
+    feature_effect_metadata_datetime,
+    feature_effect_metadata_url_datetime,
+    project_id,
+    model_id,
 ):
     responses.add(
         responses.GET,
@@ -591,7 +743,7 @@ def test_wait_for_feature_effect_finished(one_model, feature_effect_server_data)
 @responses.activate
 @pytest.mark.usefixtures("feature_effect_response")
 def test_get_feature_effect_assumed_complete(one_model, feature_effect_server_data):
-    feature_effect = one_model.get_feature_effect(source="training")
+    feature_effect = one_model.get_feature_effect(source="training", include_ice_plots=True)
 
     assert feature_effect.project_id == feature_effect_server_data["projectId"]
     assert feature_effect.model_id == feature_effect_server_data["modelId"]
@@ -791,7 +943,7 @@ def test_get_feature_effect_assumed_complete_datetime(
     backtest_index = "0"
     source = "invalid"
     feature_effect = one_datetime_model.get_feature_effect(
-        source=source, backtest_index=backtest_index
+        source=source, backtest_index=backtest_index, include_ice_plots=True
     )
     assert feature_effect.project_id == feature_effect_server_data_datetime["projectId"]
     assert feature_effect.model_id == feature_effect_server_data_datetime["modelId"]
@@ -812,3 +964,90 @@ def test_get_feature_effect_invalid_source_datetime(one_datetime_model):
     source = "invalid"
     with pytest.raises(errors.ClientError):
         one_datetime_model.get_feature_effect(source=source, backtest_index=backtest_index)
+
+
+@pytest.mark.parametrize(
+    "top_n_features,features",
+    [(None, None), (1, ["bar"])],
+)
+def test_create_multiclass_feature_effects_raises_value_error_for_invalid_params(
+    top_n_features, features
+):
+    with pytest.raises(
+        ValueError, match="Either 'features' or 'top_n_features' must be provided, but not both."
+    ):
+        FeatureEffectsMulticlass.create(
+            project_id="project_id",
+            model_id="model_id",
+            top_n_features=top_n_features,
+            features=features,
+        )
+
+
+def _assert_multiclass_feature_effects(result):
+    assert result
+    assert len(result) == 9
+    assert all(isinstance(i, FeatureEffectsMulticlass) for i in result)
+    assert all(i.class_ == "a" for i in result[:3])
+    assert all(i.class_ == "b" for i in result[3:6])
+    assert all(i.class_ == "c" for i in result[6:])
+    expected_feature_names = {
+        "record_min_temp_year",
+        "date (Day of Week)",
+        "date (Day of Week) no pvsa",
+    }
+    assert all(i.feature_name in expected_feature_names for i in result)
+    assert all(i.feature_type for i in result)
+    assert all(i.feature_impact_score for i in result)
+    assert all(i.weight_label is None for i in result)
+    assert all(i.partial_dependence for i in result)
+    assert all(i.predicted_vs_actual for i in result if "no pvsa" not in i.feature_name)
+    assert all(i.predicted_vs_actual is None for i in result if "no pvsa" in i.feature_name)
+
+
+@responses.activate
+@pytest.mark.usefixtures("multiclass_feature_effect_response")
+def test_get_multiclass_feature_effects(project_id, model_id):
+    result = FeatureEffectsMulticlass.get(project_id, model_id)
+    _assert_multiclass_feature_effects(result)
+
+
+@responses.activate
+def test_get_multiclass_feature_effects_not_found(
+    project_id, model_id, multiclass_feature_effects_url
+):
+    body = {"message": "No data found for the model."}
+    responses.add(
+        responses.GET,
+        multiclass_feature_effects_url,
+        status=404,
+        content_type="application/json",
+        body=json.dumps(body),
+    )
+
+    with pytest.raises(errors.ClientError):
+        FeatureEffectsMulticlass.get(project_id, model_id)
+
+
+@responses.activate
+def test_get_multiclass_feature_effects_bad_request(
+    project_id, model_id, multiclass_feature_effects_url
+):
+    body = {"message": "Invalid field data", "errors": {"rowCount": "value is less than 10"}}
+    responses.add(
+        responses.GET,
+        multiclass_feature_effects_url,
+        status=400,
+        content_type="application/json",
+        body=json.dumps(body),
+    )
+
+    with pytest.raises(errors.ClientError):
+        FeatureEffectsMulticlass.get(project_id, model_id)
+
+
+@responses.activate
+@pytest.mark.usefixtures("multiclass_feature_effect_response_datetime")
+def test_get_multiclass_feature_effects_datetime(project_id, model_id):
+    result = FeatureEffectsMulticlass.get(project_id, model_id, backtest_index=0)
+    _assert_multiclass_feature_effects(result)
