@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import pytest
@@ -72,6 +83,21 @@ def feature_fit_server_data():
                 "featureName": "record_min_temp_year",
                 "weightLabel": None,
                 "featureImportanceScore": 1,
+                "isBinnable": False,
+                "isScalable": None,
+                "individualConditionalExpectation": {
+                    "isCapped": True,
+                    "data": [
+                        [
+                            {"dependence": 3.574459450887747, "label": "3"},
+                            {"dependence": 8.398920976345721, "label": "4"},
+                        ],
+                        [
+                            {"dependence": 2.843083411286525, "label": "3"},
+                            {"dependence": 1.4162371027540206, "label": "4"},
+                        ],
+                    ],
+                },
             },
             {
                 "featureType": "categorical",
@@ -93,6 +119,21 @@ def feature_fit_server_data():
                 "featureName": "date (Day of Week)",
                 "weightLabel": None,
                 "featureImportanceScore": 0.2,
+                "isBinnable": True,
+                "isScalable": False,
+                "individualConditionalExpectation": {
+                    "isCapped": True,
+                    "data": [
+                        [
+                            {"dependence": 3.574459450887747, "label": "3"},
+                            {"dependence": 8.398920976345721, "label": "4"},
+                        ],
+                        [
+                            {"dependence": 2.843083411286525, "label": "3"},
+                            {"dependence": 1.4162371027540206, "label": "4"},
+                        ],
+                    ],
+                },
             },
         ],
     }
@@ -123,10 +164,11 @@ def feature_fit_server_data_datetime_holdout(feature_fit_server_data_datetime):
 @pytest.fixture
 def feature_fit_response(feature_fit_server_data, feature_fit_url):
     source = "training"
+    include_ice_plots = True
     body = json.dumps(feature_fit_server_data)
     responses.add(
         responses.GET,
-        "{}?source={}".format(feature_fit_url, source),
+        "{}?source={},includeIcePlots={}".format(feature_fit_url, source, include_ice_plots),
         status=200,
         content_type="application/json",
         body=body,
@@ -164,9 +206,12 @@ def feature_fit_invalid_request_response(feature_fit_url):
 def feature_fit_response_datetime(feature_fit_server_data_datetime, feature_fit_url_datetime):
     source = "training"
     backtest_index = "0"
+    include_ice_plots = True
     responses.add(
         responses.GET,
-        "{}?source={}&backtestIndex=".format(feature_fit_url_datetime, source, backtest_index),
+        "{}?source={}&backtestIndex={},includeIcePlots={}".format(
+            feature_fit_url_datetime, source, backtest_index, include_ice_plots
+        ),
         status=200,
         content_type="application/json",
         body=json.dumps(feature_fit_server_data_datetime),
@@ -242,7 +287,11 @@ def feature_fit_job_finished_server_data(base_job_completed_server_data):
 @pytest.fixture
 def feature_fit_job_creation_response(feature_fit_url, job_url):
     responses.add(
-        responses.POST, feature_fit_url, body="", status=202, adding_headers={"Location": job_url},
+        responses.POST,
+        feature_fit_url,
+        body="",
+        status=202,
+        adding_headers={"Location": job_url},
     )
 
 
@@ -311,7 +360,7 @@ def feature_fit_running_response(feature_fit_job_running_server_data, job_url):
 def feature_fit_previously_ran_response(feature_fit_url, job_id):
     """
     Loads a response that the given model has already ran its feature fit
-     """
+    """
     body = {
         "message": "Feature Fit is in progress for this model.",
         "errorName": "JobAlreadyAdded",
@@ -330,7 +379,7 @@ def feature_fit_previously_ran_response(feature_fit_url, job_id):
 def feature_fit_previously_ran_response_datetime(feature_fit_url_datetime, job_id):
     """
     Loads a response that the given model has already ran its feature fit
-     """
+    """
     body = {
         "message": "Feature Fit is in progress for this model.",
         "errorName": "JobAlreadyAdded",
@@ -382,7 +431,10 @@ def test_get_feature_fit_metadata(
 
 @responses.activate
 def test_get_feature_fit_metadata_datetime(
-    feature_fit_metadata_datetime, feature_fit_metadata_url_datetime, project_id, model_id,
+    feature_fit_metadata_datetime,
+    feature_fit_metadata_url_datetime,
+    project_id,
+    model_id,
 ):
     responses.add(
         responses.GET,
@@ -415,7 +467,9 @@ def test_get_feature_fit_job_result_not_finished(one_model):
 
 @responses.activate
 @pytest.mark.usefixtures(
-    "feature_fit_job_creation_response", "feature_fit_completed_response", "feature_fit_response",
+    "feature_fit_job_creation_response",
+    "feature_fit_completed_response",
+    "feature_fit_response",
 )
 def test_get_feature_fit_job_result_finished(feature_fit_server_data, one_model):
     feature_fit_job = one_model.request_feature_fit()
@@ -461,7 +515,9 @@ def test_wait_for_feature_fit_never_finished(one_model, mock_async_time):
 
 @responses.activate
 @pytest.mark.usefixtures(
-    "feature_fit_previously_ran_response", "feature_fit_completed_response", "feature_fit_response",
+    "feature_fit_previously_ran_response",
+    "feature_fit_completed_response",
+    "feature_fit_response",
 )
 def test_get_or_request_feature_fit_previously_requested(one_model, feature_fit_server_data):
     feature_fit = one_model.get_or_request_feature_fit(source="training")
@@ -485,7 +541,9 @@ def test_get_or_request_feature_fit_currently_running_waits(one_model, mock_asyn
 
 @responses.activate
 @pytest.mark.usefixtures(
-    "feature_fit_job_creation_response", "feature_fit_completed_response", "feature_fit_response",
+    "feature_fit_job_creation_response",
+    "feature_fit_completed_response",
+    "feature_fit_response",
 )
 def test_get_or_request_feature_fit(one_model, feature_fit_server_data):
 
@@ -525,7 +583,7 @@ def test_wait_for_feature_fit_finished(one_model, feature_fit_server_data):
 @responses.activate
 @pytest.mark.usefixtures("feature_fit_response")
 def test_get_feature_fit_assumed_complete(one_model, feature_fit_server_data):
-    feature_fit = one_model.get_feature_fit(source="training")
+    feature_fit = one_model.get_feature_fit(source="training", include_ice_plots=True)
 
     assert feature_fit.project_id == feature_fit_server_data["projectId"]
     assert feature_fit.model_id == feature_fit_server_data["modelId"]
@@ -711,7 +769,9 @@ def test_get_feature_fit_assumed_complete_datetime(
 ):
     backtest_index = "0"
     source = "invalid"
-    feature_fit = one_datetime_model.get_feature_fit(source=source, backtest_index=backtest_index)
+    feature_fit = one_datetime_model.get_feature_fit(
+        source=source, backtest_index=backtest_index, include_ice_plots=True
+    )
     assert feature_fit.project_id == feature_fit_server_data_datetime["projectId"]
     assert feature_fit.model_id == feature_fit_server_data_datetime["modelId"]
     assert feature_fit.source == feature_fit_server_data_datetime["source"]
