@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import pytest
 import responses
 
@@ -66,7 +77,8 @@ def test_get_or_request_feature_impact_previously_requested(one_model, feature_i
 
 @responses.activate
 @pytest.mark.usefixtures(
-    "feature_impact_previously_ran_response__no_job_id", "feature_impact_response",
+    "feature_impact_previously_ran_response__no_job_id",
+    "feature_impact_response",
 )
 def test_get_or_request_feature_impact_previously_requested_but_no_job_id(
     one_model, feature_impact_server_data
@@ -77,7 +89,8 @@ def test_get_or_request_feature_impact_previously_requested_but_no_job_id(
 
 @responses.activate
 @pytest.mark.usefixtures(
-    "feature_impact_previously_ran_response", "feature_impact_running_response",
+    "feature_impact_previously_ran_response",
+    "feature_impact_running_response",
 )
 def test_get_or_request_feature_impact_currently_running_waits(one_model, mock_async_time):
     mock_async_time.time.side_effect = (0, 5)
