@@ -1,4 +1,15 @@
 # -*- encoding: utf-8 -*-
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from datetime import datetime
 import json
 
@@ -173,8 +184,9 @@ def predictions_multilabel_json():
                     {"threshold": 0.5, "value": 0.6, "label": "cat"},
                     {"threshold": 0.5, "value": 0.5, "label": u"🐕"},
                     {"threshold": 0.5, "value": 0.4, "label": "Maine Coon"},
+                    {"threshold": 0.5, "value": 0.7, "label": "British_Shorthair"},
                 ],
-                "prediction": ["cat"],
+                "prediction": ["cat", "British_Shorthair"],
                 "rowId": 0,
             },
             {
@@ -182,6 +194,7 @@ def predictions_multilabel_json():
                     {"threshold": 0.5, "value": 0.1, "label": "cat"},
                     {"threshold": 0.5, "value": 0.4, "label": u"🐕"},
                     {"threshold": 0.5, "value": 0.4, "label": "Maine Coon"},
+                    {"threshold": 0.5, "value": 0.1, "label": "British_Shorthair"},
                 ],
                 "prediction": [],
                 "rowId": 1,
@@ -280,7 +293,8 @@ def predictions_metadata_by_id_url(predictions_metadata_url, prediction_id):
 @responses.activate
 def test_get__fetches_metadata(project_id, prediction_id, sample_prediction_metadata):
     metadata_url = "https://host_name.com/projects/{}/predictionsMetadata/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     responses.add(
         responses.GET,
@@ -313,7 +327,10 @@ def test_get__fetches_metadata(project_id, prediction_id, sample_prediction_meta
 
 @responses.activate
 def test_get_predictions_with_shap_explanations(
-    project_id, prediction_id, predictions_metadata_with_shap_exp, predictions_metadata_by_id_url,
+    project_id,
+    prediction_id,
+    predictions_metadata_with_shap_exp,
+    predictions_metadata_by_id_url,
 ):
     mocked_response = predictions_metadata_with_shap_exp
     add_response(url=predictions_metadata_by_id_url, body=mocked_response)
@@ -540,6 +557,9 @@ def test_get_all_as_dataframe_multilabel_json_serializer(
                 u"threshold_Maine Coon": 0.5,
                 u"prediction_Maine Coon": 0,
                 u"class_Maine Coon": 0.4,
+                u"threshold_British_Shorthair": 0.5,
+                u"prediction_British_Shorthair": 1,
+                u"class_British_Shorthair": 0.7,
             },
             {
                 u"row_id": 1,
@@ -552,9 +572,21 @@ def test_get_all_as_dataframe_multilabel_json_serializer(
                 u"threshold_Maine Coon": 0.5,
                 u"prediction_Maine Coon": 0,
                 u"class_Maine Coon": 0.4,
+                u"threshold_British_Shorthair": 0.5,
+                u"prediction_British_Shorthair": 0,
+                u"class_British_Shorthair": 0.1,
             },
         ]
     )
+    types_mapping = {}
+    for column in expected.columns:
+        if column.startswith("prediction_"):
+            types_mapping[column] = "int8"
+        elif column.startswith("threshold_"):
+            types_mapping[column] = "float32"
+        elif column.startswith("class_"):
+            types_mapping[column] = "float32"
+    expected = expected.astype(types_mapping)
 
     pd.testing.assert_frame_equal(actual, expected[actual.columns])
 
