@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import csv
 import io
 import json
@@ -128,11 +139,16 @@ def test_list__no_url_in_api_response__error(project_id, model_id, prediction_id
 @responses.activate
 def test_iterate_rows__empty_predictions__ok(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     response = {"data": [], "next": "{}?offset=100&limit=100".format(url)}
     responses.add(
-        responses.GET, url, body=json.dumps(response), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(response),
+        status=200,
+        content_type="application/json",
     )
 
     obj = TrainingPredictions.get(project_id, prediction_id)
@@ -143,7 +159,8 @@ def test_iterate_rows__empty_predictions__ok(project_id, prediction_id):
 @responses.activate
 def test_iterate_rows__malfromed_predictions__data_error(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     items = [
         {
@@ -155,7 +172,11 @@ def test_iterate_rows__malfromed_predictions__data_error(project_id, prediction_
     ]
     response = {"data": items, "next": "{}?offset=100&limit=100".format(url)}
     responses.add(
-        responses.GET, url, body=json.dumps(response), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(response),
+        status=200,
+        content_type="application/json",
     )
 
     with pytest.raises(trafaret.DataError):
@@ -167,7 +188,8 @@ def test_iterate_rows__malfromed_predictions__data_error(project_id, prediction_
 @responses.activate
 def test_iterate_rows__extra_fields__ignored(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     items = [
         {
@@ -185,7 +207,11 @@ def test_iterate_rows__extra_fields__ignored(project_id, prediction_id):
     ]
     response = {"data": items, "next": "{}?offset=100&limit=100".format(url), "prev": None}
     responses.add(
-        responses.GET, url, body=json.dumps(response), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(response),
+        status=200,
+        content_type="application/json",
     )
 
     obj = TrainingPredictions.get(project_id, prediction_id)
@@ -208,7 +234,8 @@ def test_iterate_rows__extra_fields__ignored(project_id, prediction_id):
 @responses.activate
 def test_iterate_rows__all_rows_at_once__ok(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     items = [
         {"row_id": 1, "partition_id": 2, "prediction": 0.42, "prediction_values": []},
@@ -217,7 +244,11 @@ def test_iterate_rows__all_rows_at_once__ok(project_id, prediction_id):
     ]
     response = {"data": items, "next": None, "prev": None}
     responses.add(
-        responses.GET, url, body=json.dumps(response), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(response),
+        status=200,
+        content_type="application/json",
     )
 
     obj = TrainingPredictions.get(project_id, prediction_id)
@@ -227,14 +258,19 @@ def test_iterate_rows__all_rows_at_once__ok(project_id, prediction_id):
 @responses.activate
 def test_iterate_rows__one_prediction__ok(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     items = [
         {"row_id": 1, "partition_id": 2, "prediction": 0.42, "prediction_values": []},
     ]
     response = {"data": items, "next": "{}?offset=100&limit=100".format(url)}
     responses.add(
-        responses.GET, url, body=json.dumps(response), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(response),
+        status=200,
+        content_type="application/json",
     )
 
     obj = TrainingPredictions.get(project_id, prediction_id)
@@ -259,7 +295,8 @@ def test_iterate_rows__one_prediction__ok(project_id, prediction_id):
 @responses.activate
 def test_iterate_rows__one_prediction_with_shap_exp(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     items = [
         {
@@ -316,18 +353,24 @@ def test_iterate_rows__one_prediction_with_shap_exp(project_id, prediction_id):
 
 @responses.activate
 def test_iterate_rows__two_predictions_with_limit_equals_one__three_requests_were_made(
-    project_id, prediction_id,
+    project_id,
+    prediction_id,
 ):
     items = [
         {"row_id": 1, "partition_id": 2, "prediction": 0.42, "prediction_values": []},
         {"row_id": 2, "partition_id": 2, "prediction": 0.22, "prediction_values": []},
     ]
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     body = {"data": items[:1], "next": "{}?offset=1&limit=1".format(url)}
     responses.add(
-        responses.GET, url, body=json.dumps(body), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(body),
+        status=200,
+        content_type="application/json",
     )
 
     obj = TrainingPredictions.get(project_id, prediction_id)
@@ -376,7 +419,11 @@ def test_iterate_rows__two_predictions_with_limit_equals_one__three_requests_wer
     body = {"data": [], "next": "{}?offset=3&limit=1".format(url)}
     responses.reset()
     responses.add(
-        responses.GET, url, body=json.dumps(body), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(body),
+        status=200,
+        content_type="application/json",
     )
 
     assert next(it, None) is None
@@ -427,10 +474,16 @@ def test_iterate_rows__two_predictions_with_limit_equals_one__three_requests_wer
     ],
 )
 def test_get_all_as_dataframe__regression_two_predictions__ok(
-    project_id, prediction_id, project_url, project_with_target_json, serializer, response,
+    project_id,
+    prediction_id,
+    project_url,
+    project_with_target_json,
+    serializer,
+    response,
 ):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     response["body"] = response["body"](url)
     responses.add(responses.GET, url, status=200, **response)
@@ -607,10 +660,16 @@ def test_get_all_as_dataframe__regression_two_predictions__ok(
     ],
 )
 def test_get_all_as_dataframe__timeseries_predictions__ok(
-    project_id, prediction_id, project_url, project_with_target_json, serializer, response,
+    project_id,
+    prediction_id,
+    project_url,
+    project_with_target_json,
+    serializer,
+    response,
 ):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     response["body"] = response["body"](url)
     responses.add(responses.GET, url, status=200, **response)
@@ -689,10 +748,16 @@ def test_get_all_as_dataframe__timeseries_predictions__ok(
     ],
 )
 def test_download_to_csv__two_regression_predictions__ok(
-    project_id, prediction_id, project_url, project_with_target_json, serializer, response,
+    project_id,
+    prediction_id,
+    project_url,
+    project_with_target_json,
+    serializer,
+    response,
 ):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     response["body"] = response["body"](url)
     responses.add(responses.GET, url, status=200, **response)
@@ -716,7 +781,8 @@ def test_download_to_csv__two_regression_predictions__ok(
 @responses.activate
 def test_iterate_rows__one_classification_prediction__ok(project_id, prediction_id):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     items = [
         {
@@ -728,7 +794,11 @@ def test_iterate_rows__one_classification_prediction__ok(project_id, prediction_
     ]
     response = {"data": items, "next": "{}?offset=100&limit=100".format(url)}
     responses.add(
-        responses.GET, url, body=json.dumps(response), status=200, content_type="application/json",
+        responses.GET,
+        url,
+        body=json.dumps(response),
+        status=200,
+        content_type="application/json",
     )
 
     obj = TrainingPredictions.get(project_id, prediction_id)
@@ -794,10 +864,16 @@ def test_iterate_rows__one_classification_prediction__ok(project_id, prediction_
     ],
 )
 def test_get_all_as_dataframe__one_classification_prediction__ok(
-    project_id, prediction_id, project_url, project_with_target_json, serializer, response,
+    project_id,
+    prediction_id,
+    project_url,
+    project_with_target_json,
+    serializer,
+    response,
 ):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     response["body"] = response["body"](url)
     responses.add(responses.GET, url, status=200, **response)
@@ -878,10 +954,16 @@ def test_get_all_as_dataframe__one_classification_prediction__ok(
     ],
 )
 def test_download_to_csv__multiclass_project__prediction__ok(
-    project_id, prediction_id, project_url, project_with_target_json, serializer, response,
+    project_id,
+    prediction_id,
+    project_url,
+    project_with_target_json,
+    serializer,
+    response,
 ):
     url = "https://host_name.com/projects/{}/trainingPredictions/{}/".format(
-        project_id, prediction_id,
+        project_id,
+        prediction_id,
     )
     response["body"] = response["body"](url)
     responses.add(responses.GET, url, status=200, **response)
