@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import pytest
@@ -5,7 +16,7 @@ import responses
 import six
 import six.moves.urllib.parse as urllibparse
 
-from datarobot import UserBlueprint
+from datarobot import errors, UserBlueprint
 from datarobot.models.user_blueprints.models import (
     DEFAULT_BATCH_SIZE,
     GrantAccessControlWithUsernameValidator,
@@ -16,6 +27,7 @@ from datarobot.models.user_blueprints.models import (
     UserBlueprintSharingListController,
     UserBlueprintValidate,
     UserBlueprintValidateTaskParameters,
+    VertexContextItemMessages,
 )
 from datarobot.utils import from_api, to_api
 
@@ -132,7 +144,11 @@ def mocked_input_types():
 
 @pytest.fixture
 def mocked_add_to_menu_response(blueprint_id, user_blueprint_id):
-    return {"addedToMenu": [{"userBlueprintId": user_blueprint_id, "blueprintId": blueprint_id}]}
+    return {
+        "addedToMenu": [{"userBlueprintId": user_blueprint_id, "blueprintId": blueprint_id}],
+        "notAddedToMenu": [],
+        "message": "All blueprints successfully added to project repository.",
+    }
 
 
 @pytest.fixture
@@ -245,7 +261,10 @@ def blueprint():
 
 @pytest.fixture
 def mocked_vertex_context(mock_user_blueprint_without_blueprint):
-    return {"vertexContext": mock_user_blueprint_without_blueprint["vertexContext"]}
+    return {
+        "vertexContext": mock_user_blueprint_without_blueprint["vertexContext"],
+        "blueprintContext": mock_user_blueprint_without_blueprint["blueprintContext"],
+    }
 
 
 @pytest.fixture
@@ -285,6 +304,7 @@ def mock_user_blueprint_without_blueprint(blueprint_id, user_blueprint_id, user_
         "supportsNewSeries": False,
         "userBlueprintId": user_blueprint_id,
         "userId": str(user_id),
+        "blueprintContext": {"warnings": [], "errors": []},
         "vertexContext": [
             {
                 "information": {
@@ -319,6 +339,33 @@ def mock_user_blueprint_with_project_id(mock_user_blueprint, project_id):
     return dict(mock_user_blueprint, projectId=project_id)
 
 
+@pytest.fixture
+def mock_user_blueprint_with_custom_task_version(mock_user_blueprint_without_blueprint):
+    custom_task_version_id = "1" * 24
+    custom_task_id = "2" * 24
+    bp_with_custom_task = [
+        {
+            "task_id": "1",
+            "task_data": {
+                "inputs": ["CAT", "DATE", "DATE_DURATION", "NUM", "TXT"],
+                "task_code": "CUSTOMR",
+                "task_parameters": [{"param": "version_id", "value": custom_task_version_id}],
+                "output_method": "P",
+                "output_method_parameters": [],
+                "x_transformations": [],
+                "y_transformations": [],
+            },
+        },
+    ]
+    return dict(
+        mock_user_blueprint_without_blueprint,
+        blueprint=bp_with_custom_task,
+        customTaskVersionMetadata=[[custom_task_version_id, custom_task_id]],
+        modelType="training Model (v1.0)",
+        taskType="custom",
+    )
+
+
 @pytest.fixture
 def make_url(unittest_endpoint):
     def _make_url(url):
@@ -377,6 +424,10 @@ def test_get_blueprint(
         body=json.dumps(mock_user_blueprint),
     )
     response = UserBlueprint.get(user_blueprint_id, project_id=project_id)
+    assert response.blueprint_context == VertexContextItemMessages(
+        errors=[],
+        warnings=[],
+    )
     assert response == UserBlueprint.from_server_data(mock_user_blueprint)
     assert response == UserBlueprint(**as_shallow_dict(response))
     assert responses.calls[0].request.method == "GET"
@@ -424,7 +475,7 @@ def test_create_blueprint_with_data(
     assert responses.calls[0].request.url == url
 
     # Inspect and verify the request
-    body = json.loads(responses.calls[0].request.body.decode("utf-8").replace("'", '"'))
+    body = from_api(json.loads(responses.calls[0].request.body), keep_null_keys=True)
     expected = {
         "blueprint": blueprint,
         "decompressed_blueprint": True,
@@ -437,7 +488,7 @@ def test_create_blueprint_with_data(
     if expected_save_to_catalog is not None:
         expected.update(dict(save_to_catalog=expected_save_to_catalog))
 
-    assert body == to_api(expected)
+    assert body == expected
 
 
 @responses.activate
@@ -477,7 +528,7 @@ def test_create_blueprint_with_blueprint_id_and_project_id(
     assert responses.calls[0].request.url == url
 
     # Inspect and verify the request
-    body = json.loads(responses.calls[0].request.body.decode("utf-8").replace("'", '"'))
+    body = from_api(json.loads(responses.calls[0].request.body), keep_null_keys=True)
     expected = {
         "blueprint_id": blueprint_id,
         "decompressed_blueprint": True,
@@ -489,7 +540,7 @@ def test_create_blueprint_with_blueprint_id_and_project_id(
     if expected_save_to_catalog is not None:
         expected.update(dict(save_to_catalog=expected_save_to_catalog))
 
-    assert body == to_api(expected)
+    assert body == expected
 
 
 @responses.activate
@@ -533,7 +584,7 @@ def test_create_blueprint_with_user_blueprint_id(
     assert responses.calls[0].request.url == url
 
     # Inspect and verify the request
-    body = json.loads(responses.calls[0].request.body.decode("utf-8").replace("'", '"'))
+    body = from_api(json.loads(responses.calls[0].request.body), keep_null_keys=True)
     expected = {
         "user_blueprint_id": user_blueprint_id,
         "decompressed_blueprint": True,
@@ -546,11 +597,22 @@ def test_create_blueprint_with_user_blueprint_id(
     if expected_save_to_catalog is not None:
         expected.update(dict(save_to_catalog=expected_save_to_catalog))
 
-    assert body == to_api(expected)
+    assert body == expected
 
 
+@pytest.mark.parametrize("set_blueprint_to_none", [False, True])
+@pytest.mark.parametrize("project_id", ["foo", None])
+@pytest.mark.parametrize("include_project_id_if_none", [False, True])
 @responses.activate
-def test_update_blueprint_with_data(make_url, user_blueprint_id, mock_user_blueprint, blueprint):
+def test_update_blueprint_with_data(
+    make_url,
+    user_blueprint_id,
+    mock_user_blueprint,
+    blueprint,
+    set_blueprint_to_none,
+    project_id,
+    include_project_id_if_none,
+):
     url = make_url("userBlueprints/{}/".format(user_blueprint_id))
     responses.add(
         responses.PATCH,
@@ -559,18 +621,38 @@ def test_update_blueprint_with_data(make_url, user_blueprint_id, mock_user_bluep
         content_type="application/json",
         body=json.dumps(mock_user_blueprint),
     )
-    response = UserBlueprint.update(blueprint, user_blueprint_id)
+    model_type = "Foo Bar"
+    if set_blueprint_to_none:
+        blueprint = None
+    response = UserBlueprint.update(
+        blueprint,
+        user_blueprint_id,
+        model_type=model_type,
+        project_id=project_id,
+        include_project_id_if_none=include_project_id_if_none,
+    )
     assert response == UserBlueprint.from_server_data(mock_user_blueprint)
     assert response == UserBlueprint(**as_shallow_dict(response))
     assert responses.calls[0].request.method == "PATCH"
     assert responses.calls[0].request.url == url
+    expected_body = {"decompressed_blueprint": True, "model_type": "Foo Bar"}
+    if project_id is not None or include_project_id_if_none:
+        expected_body["project_id"] = project_id
+    if not set_blueprint_to_none:
+        expected_body["blueprint"] = blueprint
+    assert (
+        from_api(json.loads(responses.calls[0].request.body), keep_null_keys=True) == expected_body
+    )
 
 
 @responses.activate
 def test_delete_blueprint_with_data(make_url, user_blueprint_id):
     url = make_url("userBlueprints/{}/".format(user_blueprint_id))
     responses.add(
-        responses.DELETE, url, status=204, content_type="application/json",
+        responses.DELETE,
+        url,
+        status=204,
+        content_type="application/json",
     )
     UserBlueprint.delete(user_blueprint_id)
     assert responses.calls[0].request.method == "DELETE"
@@ -579,7 +661,11 @@ def test_delete_blueprint_with_data(make_url, user_blueprint_id):
 
 @responses.activate
 def test_add_to_project(
-    make_url, project_id, user_blueprint_id, blueprint_id, mocked_add_to_menu_response,
+    make_url,
+    project_id,
+    user_blueprint_id,
+    blueprint_id,
+    mocked_add_to_menu_response,
 ):
     url = make_url("userBlueprintsProjectBlueprints/")
     responses.add(
@@ -597,13 +683,19 @@ def test_add_to_project(
     assert len(response.added_to_menu) == 1
     assert response.added_to_menu[0].blueprint_id == blueprint_id
     assert response.added_to_menu[0].user_blueprint_id == user_blueprint_id
+    assert response.not_added_to_menu == []
+    assert response.message == "All blueprints successfully added to project repository."
     assert responses.calls[0].request.method == "POST"
     assert responses.calls[0].request.url == url
 
 
 @responses.activate
 def test_get_input_types(
-    make_url, project_id, user_blueprint_id, blueprint_id, mocked_input_types,
+    make_url,
+    project_id,
+    user_blueprint_id,
+    blueprint_id,
+    mocked_input_types,
 ):
     url = make_url("userBlueprintsInputTypes/")
     responses.add(
@@ -623,7 +715,11 @@ def test_get_input_types(
 
 @responses.activate
 def test_get_available_tasks(
-    make_url, project_id, user_blueprint_id, blueprint_id, mocked_available_tasks,
+    make_url,
+    project_id,
+    user_blueprint_id,
+    blueprint_id,
+    mocked_available_tasks,
 ):
     url = make_url("userBlueprintsTasks/")
     responses.add(
@@ -694,7 +790,11 @@ def test_validate_task_parameters(
 @pytest.mark.parametrize("project_id, expected_project_id", [(None, None), ("foo", "foo")])
 @responses.activate
 def test_validate_blueprint(
-    project_id, expected_project_id, make_url, blueprint, mocked_vertex_context,
+    project_id,
+    expected_project_id,
+    make_url,
+    blueprint,
+    mocked_vertex_context,
 ):
     url = make_url("userBlueprintsValidations/")
     responses.add(
@@ -710,6 +810,10 @@ def test_validate_blueprint(
     if project_id is not None:
         kwargs.update(dict(project_id=project_id))
     response = UserBlueprint.validate_blueprint(**kwargs)
+    assert response.blueprint_context == VertexContextItemMessages(
+        errors=[],
+        warnings=[],
+    )
 
     # Inspect and verify the request
     request_body = json.loads(responses.calls[0].request.body.decode("utf-8").replace("'", '"'))
@@ -761,7 +865,10 @@ def test_retrieve_shared_roles(make_url, user_blueprint_id, mock_roles_response,
 def test_update_shared_roles(make_url, user_blueprint_id, role, recipientType):
     url = make_url("userBlueprints/{}/sharedRoles/".format(user_blueprint_id))
     responses.add(
-        responses.PATCH, url, status=204, content_type="application/json",
+        responses.PATCH,
+        url,
+        status=204,
+        content_type="application/json",
     )
     response = UserBlueprint.update_shared_roles(
         user_blueprint_id, [GrantAccessControlWithUsernameValidator(role, recipientType, "test")]
@@ -848,3 +955,173 @@ def test_catalog_search(make_url):
         tag=["a,b,c"],
         type=["user_blueprint"],
     )
+
+
+@responses.activate
+def test_create_blueprint_with_custom_task_version_id_req_param__default_value(
+    make_url, mock_user_blueprint
+):
+    url = make_url("userBlueprints/fromCustomTaskVersionId/")
+    responses.add(
+        responses.POST,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(mock_user_blueprint),
+    )
+    # Create the user BP.
+    custom_task_version_id = "1" * 24
+    UserBlueprint.create_from_custom_task_version_id(custom_task_version_id=custom_task_version_id)
+    # Check the public API is properly called.
+    request_body = json.loads(responses.calls[0].request.body.decode("utf-8"))
+    expected_request_body = {
+        "customTaskVersionId": custom_task_version_id,
+        "decompressedBlueprint": True,
+        "saveToCatalog": True,
+    }
+    assert request_body == expected_request_body
+
+
+@responses.activate
+@pytest.mark.parametrize("custom_task_version_id", [1111, "1111"])
+def test_create_blueprint_with_custom_task_version_id_req_param__custom_task_version_id(
+    make_url,
+    mock_user_blueprint,
+    custom_task_version_id,
+):
+    url = make_url("userBlueprints/fromCustomTaskVersionId/")
+    responses.add(
+        responses.POST,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(mock_user_blueprint),
+    )
+    # Create the user BP.
+    UserBlueprint.create_from_custom_task_version_id(custom_task_version_id=custom_task_version_id)
+    # Check the public API is properly called.
+    request_body = json.loads(responses.calls[0].request.body.decode("utf-8"))
+    expected_request_body = {
+        "customTaskVersionId": "1111",
+        "decompressedBlueprint": True,
+        "saveToCatalog": True,
+    }
+    assert request_body == expected_request_body
+
+
+@responses.activate
+@pytest.mark.parametrize("save_to_catalog", [True, False, None])
+def test_create_blueprint_with_custom_task_version_id_req_param__save_to_catalog(
+    make_url,
+    mock_user_blueprint,
+    save_to_catalog,
+):
+    url = make_url("userBlueprints/fromCustomTaskVersionId/")
+    responses.add(
+        responses.POST,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(mock_user_blueprint),
+    )
+    # Create the user BP.
+    custom_task_version_id = "1" * 24
+    kwargs = {}
+    if save_to_catalog is not None:
+        kwargs["save_to_catalog"] = save_to_catalog
+    UserBlueprint.create_from_custom_task_version_id(
+        custom_task_version_id=custom_task_version_id, **kwargs
+    )
+    # Check the public API is properly called.
+    request_body = json.loads(responses.calls[0].request.body.decode("utf-8"))
+    expected_request_body = {
+        "customTaskVersionId": custom_task_version_id,
+        "decompressedBlueprint": True,
+        "saveToCatalog": save_to_catalog if save_to_catalog is not None else True,
+    }
+    assert request_body == expected_request_body
+
+
+@responses.activate
+@pytest.mark.parametrize("description", ["", "non blank", None])
+def test_create_blueprint_with_custom_task_version_id_req_param__description(
+    make_url,
+    mock_user_blueprint,
+    description,
+):
+    url = make_url("userBlueprints/fromCustomTaskVersionId/")
+    responses.add(
+        responses.POST,
+        url,
+        status=200,
+        content_type="application/json",
+        body=json.dumps(mock_user_blueprint),
+    )
+    # Create the user BP.
+    custom_task_version_id = "1" * 24
+    kwargs = {}
+    if description is not None:
+        kwargs["description"] = description
+    # Check UserBlueprint is successfully created with public api response.
+    UserBlueprint.create_from_custom_task_version_id(
+        custom_task_version_id=custom_task_version_id, **kwargs
+    )
+    # Check the public API is properly called.
+    request_body = json.loads(responses.calls[0].request.body.decode("utf-8"))
+    expected_request_body = {
+        "customTaskVersionId": custom_task_version_id,
+        "saveToCatalog": True,
+        "decompressedBlueprint": True,
+    }
+    if description is not None:
+        expected_request_body.update({"description": description})
+    assert request_body == expected_request_body
+
+
+@responses.activate
+@pytest.mark.parametrize("http_status_code", [404, 403, 422, 500])
+def test_create_blueprint_with_custom_task_version_id__raise_proper_exception(
+    make_url, http_status_code
+):
+    url = make_url("userBlueprints/fromCustomTaskVersionId/")
+    responses.add(
+        responses.POST,
+        url,
+        status=http_status_code,
+        content_type="application/json",
+        body=json.dumps({"message": "error message"}),
+    )
+    is_client_error = 400 <= http_status_code < 500
+    expected_raised_error = errors.ClientError if is_client_error else errors.ServerError
+    with pytest.raises(expected_raised_error) as error:
+        UserBlueprint.create_from_custom_task_version_id(custom_task_version_id="1" * 24)
+    error_obj = error.value
+    assert error_obj.status_code == http_status_code
+
+
+def test_from_server_data_with_custom_task_blueprint(mock_user_blueprint_without_blueprint):
+    custom_task_version_id = "1" * 24
+    custom_task_id = "2" * 24
+    bp_with_custom_task = [
+        {
+            "task_id": "1",
+            "task_data": {
+                "inputs": ["CAT", "DATE", "DATE_DURATION", "NUM", "TXT"],
+                "task_code": "CUSTOMR",
+                "task_parameters": [{"param": "version_id", "value": custom_task_version_id}],
+                "output_method": "P",
+                "output_method_parameters": [],
+                "x_transformations": [],
+                "y_transformations": [],
+            },
+        },
+    ]
+    mock_user_blueprint_with_custom_task_version = dict(
+        mock_user_blueprint_without_blueprint,
+        blueprint=bp_with_custom_task,
+        customTaskVersionMetadata=[[custom_task_version_id, custom_task_id]],
+        modelType="training Model (v1.0)",
+        taskType="custom",
+    )
+    user_blueprint = UserBlueprint.from_server_data(mock_user_blueprint_with_custom_task_version)
+    assert user_blueprint.custom_task_version_metadata == [[custom_task_version_id, custom_task_id]]
