@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from collections import defaultdict
 import json
 
@@ -61,6 +72,10 @@ def assert_custom_task_version(version, version_json):
 
     _assert_custom_version_common_fields(version, version_json)
 
+    obj_arguments = version.arguments
+    json_arguments = version_json.get("arguments", [])
+    assert_custom_version_arguments(obj_arguments, json_arguments)
+
 
 def _assert_custom_version_common_fields(version, version_json):
     non_optional = [
@@ -126,6 +141,14 @@ def assert_dependencies(obj_dependencies, json_dependencies):
                 assert_key(constraint, constraint_json, key)
 
 
+def assert_custom_version_arguments(obj_arguments, json_arguments):
+    assert len(obj_arguments) == len(json_arguments)
+    for argument, argument_json in zip(obj_arguments, json_arguments):
+        assert argument.key == argument_json["key"]
+        for key in {"name", "type", "default", "values"}:
+            assert_key(argument.argument, argument_json["argument"], key)
+
+
 def assert_key(api_obj, json_data, obj_attribute):
     is_optional_key = False
     _assert_attribute(api_obj, json_data, obj_attribute, is_optional_key)
@@ -194,3 +217,20 @@ def fields_to_dict(encoder):
     for k, v in encoder.fields:
         fields[k].append(v)
     return fields
+
+
+def assert_custom_task_version_dependency_build(
+    custom_task_version_dependency_build, custom_task_version_dependency_build_server_data
+):
+    server_data = custom_task_version_dependency_build_server_data
+    assert custom_task_version_dependency_build.custom_task_id == server_data["customTaskId"]
+    assert (
+        custom_task_version_dependency_build.custom_task_version_id
+        == server_data["customTaskVersionId"]
+    )
+    assert custom_task_version_dependency_build.started_at == server_data["buildStart"]
+    assert custom_task_version_dependency_build.completed_at == server_data["buildEnd"]
+    assert custom_task_version_dependency_build.build_status == server_data["buildStatus"]
+    assert (
+        custom_task_version_dependency_build.build_log_location == server_data["buildLogLocation"]
+    )
