@@ -1,4 +1,15 @@
 # -*- encoding: utf-8 -*-
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import datetime
 import io
 import json
@@ -528,7 +539,9 @@ def test_list_batch_prediction_jobs_by_status(batch_prediction_jobs_json):
         pytest.param("batch_prediction_job_initializing_json", "INITIALIZING", 0),
         pytest.param("batch_prediction_job_completed_passthrough_columns_json", "COMPLETED", 100),
         pytest.param(
-            "batch_prediction_job_completed_passthrough_columns_set_json", "COMPLETED", 100,
+            "batch_prediction_job_completed_passthrough_columns_set_json",
+            "COMPLETED",
+            100,
         ),
         pytest.param("batch_prediction_job_s3_completed_json", "COMPLETED", 100),
     ],
@@ -695,7 +708,10 @@ def test_score_to_file_timeout(
 
     with pytest.raises(RuntimeError):
         BatchPredictionJob.score_to_file(
-            "5ce1138c962d7415e076d8c6", io.BytesIO(b"foo\nbar"), output_file, download_timeout=1,
+            "5ce1138c962d7415e076d8c6",
+            io.BytesIO(b"foo\nbar"),
+            output_file,
+            download_timeout=1,
         )
 
     assert open(output_file, "r").read() == ""
@@ -759,7 +775,9 @@ def test_score_to_file_race_condition(
     mock_file_object.seek.side_effect = slow_seek
 
     BatchPredictionJob.score_to_file(
-        "5ce1138c962d7415e076d8c6", mock_file_object, output_file,
+        "5ce1138c962d7415e076d8c6",
+        mock_file_object,
+        output_file,
     )
 
     put_mock.assert_called_once()
@@ -825,7 +843,9 @@ def test_score_to_file_aborted_during_download_raises_exception(
 @responses.activate
 @pytest.mark.usefixtures("client")
 def test_score_to_file_failed_before_download_raises_exception(
-    tmpdir, batch_prediction_job_initializing_json, batch_prediction_job_failed_json,
+    tmpdir,
+    batch_prediction_job_initializing_json,
+    batch_prediction_job_failed_json,
 ):
 
     responses.add(
@@ -862,6 +882,38 @@ def test_score_to_file_failed_before_download_raises_exception(
         )
 
 
+@responses.activate
+@pytest.mark.usefixtures("client")
+def test_score_to_non_file_download_raises_exception(
+    batch_prediction_job_s3_initializing_json,
+    batch_prediction_job_s3_completed_json,
+):
+    responses.add(
+        responses.POST,
+        "https://host_name.com/batchPredictions/",
+        body=batch_prediction_job_s3_initializing_json,
+        headers={"Location": "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/"},
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/",
+        body=batch_prediction_job_s3_completed_json,
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/download/",
+        body="a,b,c\n1,2,3",
+    )
+
+    job_id = "5ce1204b962d741661907ea0"
+    job = BatchPredictionJob.get(job_id)
+    buf = io.BytesIO()
+    with pytest.raises(RuntimeError, match=r"You cannot download predictions from jobs that did"):
+        job.download(buf)
+
+
 @responses.activate
 @pytest.mark.usefixtures("client")
 @pytest.mark.parametrize(
@@ -964,7 +1016,10 @@ def test_score_from_existing(batch_prediction_job_s3_completed_json):
             id="unsupported-intake-option",
         ),
         pytest.param(
-            {"deployment": "foo"}, ValueError, "Missing source data", id="missing-source-data",
+            {"deployment": "foo"},
+            ValueError,
+            "Missing source data",
+            id="missing-source-data",
         ),
         pytest.param(
             {"deployment": "foo", "intake_settings": {"type": "s3"}},
@@ -1680,7 +1735,8 @@ def test_score_job_data(mock_client, score_args, expected_job_data):
         BatchPredictionJob.score(**score_args)
 
     mock_client.post.assert_called_once_with(
-        url=BatchPredictionJob._jobs_path(), json=expected_job_data,
+        url=BatchPredictionJob._jobs_path(),
+        json=expected_job_data,
     )
 
 
@@ -1863,3 +1919,151 @@ def test_score_pandas(
         "POSITIVE_CLASS",
         "prediction_status",
     }
+
+
+@pytest.mark.parametrize(
+    ["intake_settings", "output_settings"],
+    [
+        pytest.param(
+            {"type": "s3", "url": "s3://bucket/source_key", "credential_id": "key_id"},
+            {"type": "s3", "url": "s3://bucket/target_key", "credential_id": "key_id"},
+            id="s3-keys",
+        ),
+        pytest.param(
+            {
+                "type": "dataset",
+                "dataset": Dataset(
+                    dataset_id="foo",
+                    version_id="dont_display",
+                    name="name",
+                    categories=["categories"],
+                    created_at="created_at",
+                    created_by="created_by",
+                    is_data_engine_eligible=False,
+                    is_latest_version=True,
+                    is_snapshot=True,
+                    processing_state="processing_state",
+                ),
+                "dataset_version_id": "version_id_explicit",
+            },
+            {"type": "localFile"},
+        ),
+        pytest.param(
+            {
+                "type": "jdbc",
+                "table": "test",
+                "schema": "public",
+                "catalog": "cat",
+                "data_store_id": "abcd1234",
+                "credential_id": "key_id",
+            },
+            {
+                "type": "jdbc",
+                "table": "test2",
+                "schema": "public",
+                "catalog": "cat",
+                "statement_type": "insert",
+                "data_store_id": "abcd1234",
+                "credential_id": "key_id",
+                "create_table_if_not_exists": True,
+            },
+            id="jdbc-keys",
+        ),
+        pytest.param(
+            {
+                "type": "snowflake",
+                "table": "test",
+                "schema": "public",
+                "external_stage": "s3_stage",
+                "data_store_id": "abcd1234",
+                "credential_id": "key_id",
+                "cloud_storage_credential_id": "cloud_storage_key_id",
+                "cloud_storage_type": "s3",
+            },
+            {
+                "type": "snowflake",
+                "table": "test2",
+                "schema": "public",
+                "external_stage": "s3_stage",
+                "statement_type": "insert",
+                "data_store_id": "abcd1234",
+                "credential_id": "key_id",
+                "cloud_storage_credential_id": "cloud_storage_key_id",
+                "cloud_storage_type": "s3",
+                "create_table_if_not_exists": True,
+            },
+            id="snowflake-keys",
+        ),
+        pytest.param(
+            {
+                "type": "synapse",
+                "table": "test",
+                "schema": "public",
+                "catalog": "cat",
+                "external_data_source": "my_data_source",
+                "data_store_id": "abcd1234",
+                "credential_id": "key_id",
+                "cloud_storage_credential_id": "cloud_storage_key_id",
+            },
+            {
+                "type": "synapse",
+                "table": "test2",
+                "schema": "public",
+                "catalog": "cat",
+                "external_data_source": "my_data_source",
+                "statement_type": "insert",
+                "data_store_id": "abcd1234",
+                "credential_id": "key_id",
+                "cloud_storage_credential_id": "cloud_storage_key_id",
+                "create_table_if_not_exists": True,
+            },
+            id="synapse-keys",
+        ),
+    ],
+)
+@responses.activate
+@pytest.mark.usefixtures("client")
+def test_score_does_not_mutate_input_output_settings(
+    batch_prediction_job_initializing_json,
+    batch_prediction_job_completed_json,
+    batch_prediction_job_data_csv_with_index,
+    intake_settings,
+    output_settings,
+):
+    # PRED-6420 reported that the .score() function mutated intake_settings
+    # by removing keys such as type. Therefore this test checks that all keys
+    # which are passed in, still exist after calling .score()
+
+    responses.add(
+        responses.POST,
+        "https://host_name.com/batchPredictions/",
+        body=batch_prediction_job_initializing_json,
+        headers={"Location": "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/"},
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/download/",
+        body=batch_prediction_job_data_csv_with_index,
+        stream=True,
+    )
+
+    responses.add(
+        responses.GET,
+        "https://host_name.com/batchPredictions/5ce1204b962d741661907ea0/",
+        body=batch_prediction_job_completed_json,
+    )
+
+    # setup expected values
+    input_before_scoring = dict(intake_settings)
+    num_input_keys_before_scoring = len(intake_settings.keys())
+
+    output_before_scoring = dict(output_settings)
+    num_output_keys_before_scoring = len(output_settings.keys())
+
+    BatchPredictionJob.score("5ce1138c962d7415e076d8c6", intake_settings, output_settings)
+
+    assert len(intake_settings.keys()) == num_input_keys_before_scoring
+    assert len(output_settings.keys()) == num_output_keys_before_scoring
+    assert intake_settings == input_before_scoring
+    assert output_settings == output_before_scoring
