@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import os
 import tempfile
 import unittest
@@ -349,7 +360,8 @@ class RestErrors(SDKTestcase):
         with self.assertRaises(AppPlatformError) as app_error:
             client.get("projects/500")
             self.assertEqual(
-                str(app_error.exception), "Connection refused: https://host_name.com/projects/500",
+                str(app_error.exception),
+                "Connection refused: https://host_name.com/projects/500",
             )
 
 
@@ -365,6 +377,7 @@ class TestClientAttributes(unittest.TestCase):
             "Project",
             "Model",
             "DatetimeModel",
+            "CombinedModel",
             "PrimeModel",
             "BlenderModel",
             "FrozenModel",
@@ -387,6 +400,7 @@ class TestClientAttributes(unittest.TestCase):
             "errors",
             "models",
             "client",
+            "mixins",  # TODO - When we add new modules they end up at the top-level [DSX-2261]
             "rest",
             "SCORING_TYPE",
             "DatasetFeaturelist",
@@ -474,10 +488,17 @@ class TestClientAttributes(unittest.TestCase):
             "DatasetDefinition",
             "feature_discovery",
             "SecondaryDataset",
+            "SegmentationTask",
+            "SegmentInfo",
             "Relationship",
             "FeatureDiscoverySetting",
             "SNAPSHOT_POLICY",
             "UserBlueprint",
+            "DataEngineQueryGenerator",
+            "ClassMappingAggregationSettings",
+            "ClusteringModel",
+            "ClusterInsight",
+            "Cluster",
         }
 
         found_names = {name for name in dir(dr) if not name.startswith("_")}
