@@ -1,4 +1,15 @@
 # coding: utf-8
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import pytest
@@ -308,10 +319,20 @@ def test_upload_dataset_from_file_with_config_id(dataset_with_config_id):
     filepath = fixture_file_path("onehundredrows.csv")
     project = Project("p-id")
     config_id = dataset_with_config_id["secondaryDatasetsConfigId"]
-    new_dataset = project.upload_dataset(filepath, secondary_datasets_config_id=config_id)
+    credentials = [{"credentialId": "cred-id", "catalogVersionId": "catalog-version-id"}]
+    new_dataset = project.upload_dataset(
+        filepath,
+        secondary_datasets_config_id=config_id,
+        credentials=credentials,
+    )
 
     assert new_dataset.secondary_datasets_config_id == config_id
-    assert "secondaryDatasetsConfigId" in responses.calls[0].request.body.fields
+    fields = responses.calls[0].request.body.fields
+    assert "secondaryDatasetsConfigId" in fields
+    assert (
+        fields["credentials"]
+        == '[{"credentialId": "cred-id", "catalogVersionId": "catalog-version-id"}]'
+    )
 
 
 @responses.activate
@@ -674,6 +695,34 @@ def test_upload_dataset_from_data_source_without_forecast_point(
     assert new_dataset.detected_actual_value_columns == [{"missing_count": 25, "name": "actuals"}]
 
 
+@responses.activate
+def test_upload_dataset_from_data_source_with_credentials(
+    data_sources_endpoint,
+    data_sources_list_server_resp,
+    airlines10mb_data_source_server_resp,
+    dataset_json,
+):
+    data_source_id = airlines10mb_data_source_server_resp["id"]
+    username = "my_username"
+    password = "my_password"
+    credentials = [{"credentialId": "cred-id", "catalogVersionId": "catalog-version-id"}]
+
+    prep_successful_upload_response("dataSourceUploads", dataset_json)
+    responses.add(responses.GET, data_sources_endpoint, json=data_sources_list_server_resp)
+    project = Project("p-id")
+
+    project.upload_dataset_from_data_source(
+        data_source_id,
+        username=username,
+        password=password,
+        credentials=credentials,
+    )
+
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body["credentials"] == credentials
+
+
 @responses.activate
 def test_delete_dataset():
     responses.add(
@@ -753,3 +802,113 @@ def test_upload_dataset_from_data_source_with_relax_kia_check(
         "user": username,
         "password": password,
     }
+
+
+@responses.activate
+def test_upload_dataset_from_catalog_with_relax_kia_check(dataset_with_relax_kia_check_server_data):
+    relax_kia_check = parse_time(
+        dataset_with_relax_kia_check_server_data["relaxKnownInAdvanceFeaturesCheck"]
+    )
+    prep_successful_upload_response(
+        "datasetUploads", json.dumps(dataset_with_relax_kia_check_server_data)
+    )
+    project = Project("p-id")
+    project.upload_dataset_from_catalog(
+        "some_dataset_id", relax_known_in_advance_features_check=relax_kia_check
+    )
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body == {
+        "datasetId": "some_dataset_id",
+        "relaxKnownInAdvanceFeaturesCheck": relax_kia_check,
+    }
+
+
+@responses.activate
+def test_upload_dataset_from_catalog(dataset_json):
+    prep_successful_upload_response("datasetUploads", dataset_json)
+    project = Project("p-id")
+    project.upload_dataset_from_catalog("some_dataset_id")
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body == {"datasetId": "some_dataset_id"}
+
+
+@responses.activate
+def test_upload_dataset_from_catalog_with_forecast(dataset_with_forecast_point_server_data):
+    forecast_point = parse_time(dataset_with_forecast_point_server_data["forecastPoint"])
+    prep_successful_upload_response(
+        "datasetUploads", json.dumps(dataset_with_forecast_point_server_data)
+    )
+    project = Project("p-id")
+    project.upload_dataset_from_catalog("some_dataset_id", forecast_point=forecast_point)
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body == {
+        "datasetId": "some_dataset_id",
+        "forecastPoint": datetime_to_string(forecast_point),
+    }
+
+
+@responses.activate
+def test_upload_dataset_from_catalog_with_forecast_millis(
+    dataset_with_millis_forecast_point_server_data,
+):
+    forecast_point = parse_time(dataset_with_millis_forecast_point_server_data["forecastPoint"])
+    prep_successful_upload_response(
+        "datasetUploads", json.dumps(dataset_with_millis_forecast_point_server_data)
+    )
+    project = Project("p-id")
+    project.upload_dataset_from_catalog("some_dataset_id", forecast_point=forecast_point)
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body == {
+        "datasetId": "some_dataset_id",
+        "forecastPoint": datetime_to_string(forecast_point),
+    }
+
+
+@responses.activate
+def test_upload_dataset_from_catalog_without_forecast_point(
+    dataset_uploaded_without_forecast_point_server_data,
+):
+    forecast_point = parse_time(
+        dataset_uploaded_without_forecast_point_server_data["forecastPoint"]
+    )
+    forecast_point_range = [
+        parse_time(date)
+        for date in dataset_uploaded_without_forecast_point_server_data["forecastPointRange"]
+    ]
+    data_start_date = parse_time(
+        dataset_uploaded_without_forecast_point_server_data["dataStartDate"]
+    )
+    data_end_date = parse_time(dataset_uploaded_without_forecast_point_server_data["dataEndDate"])
+    max_forecast_date = parse_time(
+        dataset_uploaded_without_forecast_point_server_data["maxForecastDate"]
+    )
+    prep_successful_upload_response(
+        "datasetUploads", json.dumps(dataset_uploaded_without_forecast_point_server_data)
+    )
+    project = Project("p-id")
+    new_dataset = project.upload_dataset_from_catalog("some_dataset_id")
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body == {"datasetId": "some_dataset_id"}
+    assert new_dataset.forecast_point == forecast_point
+    assert new_dataset.forecast_point_range == forecast_point_range
+    assert new_dataset.data_start_date == data_start_date
+    assert new_dataset.data_end_date == data_end_date
+    assert new_dataset.max_forecast_date == max_forecast_date
+    assert new_dataset.actual_value_column is None
+    assert new_dataset.detected_actual_value_columns == [{"missing_count": 25, "name": "actuals"}]
+
+
+@responses.activate
+def test_upload_dataset_from_catalog_with_credentials(dataset_json):
+    prep_successful_upload_response("datasetUploads", dataset_json)
+    project = Project("p-id")
+    credentials = [{"credentialId": "cred-id", "catalogVersionId": "catalog-version-id"}]
+    project.upload_dataset_from_catalog("some_dataset_id", credentials=credentials)
+    assert responses.calls[0].request.method == "POST"
+    request_body = request_body_to_json(responses.calls[0].request)
+    assert request_body["credentials"] == credentials
