@@ -1,3 +1,14 @@
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from datetime import datetime
 import json
 
@@ -531,7 +542,10 @@ def _add_compute_route_to_responses(unittest_endpoint, project_id, model_id, res
 
 @responses.activate
 def test_accuracy_over_time_plots_auto_compute_before_retrieval(
-    unittest_endpoint, project_id, model_id, accuracy_over_time_plots_metadata_response,
+    unittest_endpoint,
+    project_id,
+    model_id,
+    accuracy_over_time_plots_metadata_response,
 ):
     def reset_responses():
         responses.reset()
@@ -570,7 +584,10 @@ def test_accuracy_over_time_plots_auto_compute_before_retrieval(
 
 @responses.activate
 def test_forecast_vs_actual_plots_auto_compute_before_retrieval(
-    unittest_endpoint, project_id, model_id, forecast_vs_actual_plots_metadata_response,
+    unittest_endpoint,
+    project_id,
+    model_id,
+    forecast_vs_actual_plots_metadata_response,
 ):
     def reset_responses():
         responses.reset()
@@ -675,7 +692,10 @@ def test_forecast_vs_actual_plots_auto_compute_before_retrieval(
 
 @responses.activate
 def test_anomaly_over_time_plots_auto_compute_before_retrieval(
-    unittest_endpoint, project_id, model_id, anomaly_over_time_plots_metadata_response,
+    unittest_endpoint,
+    project_id,
+    model_id,
+    anomaly_over_time_plots_metadata_response,
 ):
     def reset_responses():
         responses.reset()
