@@ -1,5 +1,15 @@
 # -*- coding: utf-8 -*-
-from itertools import product
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import pytest
@@ -52,40 +62,6 @@ def multilabel_lift_chart_validation_parent_data(parent_model_id, project_id, li
     )
 
 
-@pytest.fixture
-def multilabel_lift_chart_validation_and_cross_validation_data(
-    model_id, project_id, lift_chart_bins_data
-):
-    return {
-        "projectId": project_id,
-        "labels": ["cat", u"🐕"],
-        "modelId": model_id,
-        "charts": [
-            {"source": "validation", "label": "cat", "bins": lift_chart_bins_data},
-            {"source": "validation", "label": u"🐕", "bins": lift_chart_bins_data},
-            {"source": "crossValidation", "label": "cat", "bins": lift_chart_bins_data},
-            {"source": "crossValidation", "label": u"🐕", "bins": lift_chart_bins_data},
-        ],
-    }
-
-
-@pytest.fixture
-def multilabel_lift_chart_all_sources_data(model_id, project_id, lift_chart_bins_data):
-    return {
-        "projectId": project_id,
-        "labels": ["cat", u"🐕"],
-        "modelId": model_id,
-        "charts": [
-            {"source": "validation", "label": "cat", "bins": lift_chart_bins_data},
-            {"source": "validation", "label": u"🐕", "bins": lift_chart_bins_data},
-            {"source": "crossValidation", "label": "cat", "bins": lift_chart_bins_data},
-            {"source": "crossValidation", "label": u"🐕", "bins": lift_chart_bins_data},
-            {"source": "holdout", "label": "cat", "bins": lift_chart_bins_data},
-            {"source": "holdout", "label": u"🐕", "bins": lift_chart_bins_data},
-        ],
-    }
-
-
 @pytest.fixture
 def lift_chart_parent_model_validation_data(parent_model_id, lift_chart_bins_data):
     return {"source": "validation", "bins": lift_chart_bins_data, "sourceModelId": parent_model_id}
@@ -335,7 +311,10 @@ def test_get_validation_multilabel_lift_charts_fallback_to_parent_insight(
 
 @responses.activate
 def test_get_validation_multilabel_lift_charts_no_charts_and_fallback_flag_not_set(
-    multilabel_lift_chart_validation_data_url, project_id, model_id, parent_model_id,
+    multilabel_lift_chart_validation_data_url,
+    project_id,
+    model_id,
+    parent_model_id,
 ):
     responses.add(responses.GET, multilabel_lift_chart_validation_data_url, status=404)
     model = Model(id=model_id, project_id=project_id, is_frozen=True)
@@ -343,133 +322,6 @@ def test_get_validation_multilabel_lift_charts_no_charts_and_fallback_flag_not_s
         model.get_multilabel_lift_charts("validation")
 
 
-@responses.activate
-def test_get_all_multilabel_lift_charts(
-    multilabel_lift_chart_validation_and_cross_validation_data,
-    expected_bin_data,
-    multilabel_lift_chart_list_url,
-    project_id,
-    model_id,
-):
-    responses.add(
-        responses.GET,
-        multilabel_lift_chart_list_url,
-        status=200,
-        content_type="application/json",
-        body=json.dumps(multilabel_lift_chart_validation_and_cross_validation_data),
-    )
-    model = Model(id=model_id, project_id=project_id)
-    lift_charts = model.get_all_multilabel_lift_charts()
-
-    expected_sources = ["validation", "crossValidation"]
-    expected_labels = ["cat", u"🐕"]
-    expected_source_label_product = product(expected_sources, expected_labels)
-
-    assert len(lift_charts) == len(expected_labels) * len(expected_sources)
-    for lift_chart, (expected_source, expected_label) in zip(
-        lift_charts, expected_source_label_product
-    ):
-        assert lift_chart.source == expected_source
-        assert lift_chart.bins == expected_bin_data
-        assert lift_chart.source_model_id == model_id
-        assert lift_chart.target_class == expected_label
-
-
-@responses.activate
-@pytest.mark.usefixtures("known_warning")
-def test_get_all_multilabel_lift_charts_fallback_to_parent_insight(
-    multilabel_lift_chart_validation_and_cross_validation_data,
-    multilabel_lift_chart_all_sources_data,
-    expected_bin_data,
-    multilabel_lift_chart_list_url,
-    multilabel_lift_chart_parent_list_url,
-    parent_model_id,
-    frozen_model_url,
-    frozen_json,
-    project_id,
-    model_id,
-):
-    # GIVEN a frozen model which only holds validation and crossValidation lift charts
-    responses.add(
-        responses.GET,
-        multilabel_lift_chart_list_url,
-        status=200,
-        content_type="application/json",
-        body=json.dumps(multilabel_lift_chart_validation_and_cross_validation_data),
-    )
-    responses.add(
-        responses.GET,
-        frozen_model_url,
-        body=frozen_json,
-        status=200,
-        content_type="application/json",
-    )
-    responses.add(
-        responses.GET,
-        multilabel_lift_chart_parent_list_url,
-        status=200,
-        content_type="application/json",
-        body=json.dumps(multilabel_lift_chart_all_sources_data),
-    )
-
-    # WHEN we request all_multilabel_lift_charts with fallback_to_parent_insights
-    model = Model(id=model_id, project_id=project_id, is_frozen=True)
-    lift_charts = model.get_all_multilabel_lift_charts(fallback_to_parent_insights=True)
-
-    expected_sources = ["validation", "crossValidation", "holdout"]
-    expected_labels = ["cat", u"🐕"]
-    expected_source_label_product = product(expected_sources, expected_labels)
-
-    # THEN we expect the result to contain LiftCharts from its parent model
-    assert len(lift_charts) == len(expected_labels) * len(expected_sources)
-    for lift_chart, (expected_source, expected_label) in zip(
-        lift_charts, expected_source_label_product
-    ):
-        assert lift_chart.source == expected_source
-        assert lift_chart.bins == expected_bin_data
-        if expected_source == "holdout":
-            assert lift_chart.source_model_id == parent_model_id
-        else:
-            assert lift_chart.source_model_id == model_id
-        assert lift_chart.target_class == expected_label
-
-
-@responses.activate
-def test_get_all_multilabel_lift_charts_fallback_to_parent_insight_flag_not_set(
-    multilabel_lift_chart_validation_and_cross_validation_data,
-    expected_bin_data,
-    multilabel_lift_chart_list_url,
-    project_id,
-    model_id,
-):
-    # GIVEN a frozen model which only holds validation and crossValidation lift charts
-    responses.add(
-        responses.GET,
-        multilabel_lift_chart_list_url,
-        status=200,
-        content_type="application/json",
-        body=json.dumps(multilabel_lift_chart_validation_and_cross_validation_data),
-    )
-
-    # WHEN we request all_multilabel_lift_charts with fallback_to_parent_insights flag set to False
-    model = Model(id=model_id, project_id=project_id, is_frozen=True)
-    lift_charts = model.get_all_multilabel_lift_charts(fallback_to_parent_insights=False)
-
-    # THEN we expect the result to only contain vlaidation and corrsValidation but no holdout
-    expected_sources = ["validation", "crossValidation"]
-    expected_labels = ["cat", u"🐕"]
-    expected_source_label_product = product(expected_sources, expected_labels)
-
-    assert len(lift_charts) == len(expected_labels) * len(expected_sources)
-    for lift_chart, (expected_source, expected_label) in zip(
-        lift_charts, expected_source_label_product
-    ):
-        assert lift_chart.source == expected_source
-        assert lift_chart.bins == expected_bin_data
-        assert lift_chart.source_model_id == model_id
-        assert lift_chart.target_class == expected_label
-
-
 @responses.activate
 def test_get_frozen_validation_lift_chart_no_fallback(
     lift_chart_validation_data_url, project_id, model_id
