@@ -1,4 +1,15 @@
 # -*- encoding: utf-8 -*-
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 from datetime import datetime
 import json
 import operator
@@ -85,9 +96,9 @@ def test_from_data_with_datetime(datetime_model_data):
     assert mod.training_duration is None
 
 
-def test_get_permalink_for_model(one_model):
+def test_deprecated_get_permalink_for_model(one_model):
     """
-    Model(('project-id', 'model-id')).get_leaderboard_ui_permalink()
+    Model(('project-id', 'model-id')).get_uri()
     """
     expected_link = (
         "https://host_name.com/projects/556cdfbb100d2b0e88585195/models/556ce973100d2b6e51ca9657"
@@ -95,12 +106,28 @@ def test_get_permalink_for_model(one_model):
     assert one_model.get_leaderboard_ui_permalink(), expected_link
 
 
+def test_get_permalink_for_model(one_model):
+    """
+    Model(('project-id', 'model-id')).get_uri()
+    """
+    expected_link = (
+        "https://host_name.com/projects/556cdfbb100d2b0e88585195/models/556ce973100d2b6e51ca9657"
+    )
+    assert one_model.get_uri(), expected_link
+
+
 @mock.patch("webbrowser.open")
 def test_open_model_browser(webbrowser_open, one_model):
     one_model.open_model_browser()
     assert webbrowser_open.called
 
 
+@mock.patch("webbrowser.open")
+def test_open_in_browser(webbrowser_open, one_model):
+    one_model.open_in_browser()
+    assert webbrowser_open.called
+
+
 @responses.activate
 def test_model_item_get(
     model_json, model_id, model_url, project_id, project_url, project_with_target_json
@@ -109,7 +136,10 @@ def test_model_item_get(
     Test Model.get(project_instance, 'model-id')
     """
     responses.add(
-        responses.GET, project_url, body=project_with_target_json, status=200,
+        responses.GET,
+        project_url,
+        body=project_with_target_json,
+        status=200,
     )
     responses.add(
         responses.GET, model_url, body=model_json, status=200, content_type="application/json"
@@ -178,7 +208,10 @@ def test_model_item_get_with_project_id(
     model_json, model_id, project_id, model_url, project_url, project_with_target_json
 ):
     responses.add(
-        responses.GET, project_url, body=project_with_target_json, status=200,
+        responses.GET,
+        project_url,
+        body=project_with_target_json,
+        status=200,
     )
     responses.add(
         responses.GET, model_url, body=model_json, status=200, content_type="application/json"
@@ -759,7 +792,9 @@ def test_request_predictions_with_predictions_start_end_date(
     start_end_date = datetime.now()
 
     pred_job = one_model.request_predictions(
-        dataset_id, predictions_start_date=start_end_date, predictions_end_date=start_end_date,
+        dataset_id,
+        predictions_start_date=start_end_date,
+        predictions_end_date=start_end_date,
     )
     assert pred_job.id == int(job_data["id"])
 
@@ -1162,7 +1197,8 @@ def test_cross_validate(project_id, one_model, job_id):
     responses.add(
         responses.POST,
         "https://host_name.com/projects/{}/models/{}/crossValidation/".format(
-            project_id, one_model.id,
+            project_id,
+            one_model.id,
         ),
         status=202,
         adding_headers={
@@ -1770,7 +1806,10 @@ def test_frozen_model_parent_id(
     frozen_json, model_id, model_url, project_id, project_url, project_with_target_json
 ):
     responses.add(
-        responses.GET, project_url, body=project_with_target_json, status=200,
+        responses.GET,
+        project_url,
+        body=project_with_target_json,
+        status=200,
     )
     responses.add(
         responses.GET, model_url, body=frozen_json, status=200, content_type="application/json"
