@@ -1,4 +1,15 @@
 # -*- encoding: utf-8 -*-
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 
 import json
 import unittest
@@ -410,7 +421,10 @@ class TestPredictJob(SDKTestcase):
     @responses.activate
     def test_get_finished_predict_job(self):
         responses.add(
-            responses.GET, self.get_job_url, status=303, body="",
+            responses.GET,
+            self.get_job_url,
+            status=303,
+            body="",
         )
         with self.assertRaises(errors.PendingJobFinished):
             PredictJob.get(self.project_id, self.predict_job_id)
@@ -418,7 +432,10 @@ class TestPredictJob(SDKTestcase):
     @responses.activate
     def test_get_predict_job_async_failure(self):
         responses.add(
-            responses.GET, self.get_job_url, status=202, body="",
+            responses.GET,
+            self.get_job_url,
+            status=202,
+            body="",
         )
         with pytest.raises(errors.AsyncFailureError) as exc_info:
             PredictJob.get(self.project_id, self.predict_job_id)
@@ -440,7 +457,10 @@ class TestPredictJob(SDKTestcase):
     @responses.activate
     def test_get_predictions_async_failure(self):
         responses.add(
-            responses.GET, self.get_job_url, status=202, body="",
+            responses.GET,
+            self.get_job_url,
+            status=202,
+            body="",
         )
         with pytest.raises(errors.AsyncFailureError) as exc_info:
             PredictJob.get_predictions(self.project_id, self.predict_job_id)
@@ -477,7 +497,8 @@ class TestWaitForAsyncPredictions(SDKTestcase):
         self.pid = "p-id"
         self.predict_job_id = "5"
         self.get_job_url = "https://host_name.com/projects/{}/predictJobs/{}/".format(
-            self.pid, self.predict_job_id,
+            self.pid,
+            self.predict_job_id,
         )
 
     @responses.activate
@@ -525,7 +546,8 @@ class TestRawPredictionResponseToDataframe(unittest.TestCase):
         frame = raw_prediction_response_to_dataframe(data, "")
         self.assertEqual(frame.shape, (3, 2))
         self.assertEqual(
-            sorted(frame.columns), [u"prediction", u"row_id"],
+            sorted(frame.columns),
+            [u"prediction", u"row_id"],
         )
 
     def test_parse_classification_predictions(self):
