@@ -1,5 +1,15 @@
 # -*- coding: utf-8 -*-
-from itertools import product
+#
+# Copyright 2021 DataRobot, Inc. and its affiliates.
+#
+# All rights reserved.
+#
+# DataRobot, Inc.
+#
+# This is proprietary source code of DataRobot, Inc. and its
+# affiliates.
+#
+# Released under the terms of DataRobot Tool and Utility Agreement.
 import json
 
 import pytest
@@ -331,34 +341,21 @@ class TestLabelwiseRocCurve:
             project_id, parent_model_id
         )
 
-    @pytest.fixture
-    def labelwise_roc_curve_list_url(self, project_id, model_id):
-        return "https://host_name.com/projects/{}/models/{}/labelwiseRocCurves/".format(
-            project_id, model_id
-        )
-
-    @pytest.fixture
-    def labelwise_roc_curve_parent_list_url(self, project_id, parent_model_id):
-        return "https://host_name.com/projects/{}/models/{}/labelwiseRocCurves/".format(
-            project_id, parent_model_id
-        )
-
     @pytest.fixture
     def labelwise_roc_curve_validation_data(self, roc_curve_data):
         return self.get_labelwise_roc_curves_response(["validation"], roc_curve_data)
 
-    @pytest.fixture
-    def labelwise_roc_curve_validation_and_cross_validation_data(self, roc_curve_data):
-        return self.get_labelwise_roc_curves_response(
-            ["validation", "crossValidation"], roc_curve_data
-        )
-
     def get_labelwise_roc_curves_response(self, sources, roc_curve_data):
         LABELS = ["cat", u"🐕"]
         charts = []
         for label in LABELS:
             for source in sources:
-                chart_dict = dict(label=label, source=source, kolmogorovSmirnovMetric=0.1, auc=0.2,)
+                chart_dict = dict(
+                    label=label,
+                    source=source,
+                    kolmogorovSmirnovMetric=0.1,
+                    auc=0.2,
+                )
                 chart_dict.update(roc_curve_data)
                 charts.append(chart_dict)
         response = {
@@ -368,12 +365,6 @@ class TestLabelwiseRocCurve:
         }
         return response
 
-    @pytest.fixture
-    def labelwise_roc_curve_validation_cross_validation_and_holdout_data(self, roc_curve_data):
-        return self.get_labelwise_roc_curves_response(
-            ["validation", "crossValidation", "holdout"], roc_curve_data
-        )
-
     @responses.activate
     def test_get_labelwise_roc_curves(
         self,
@@ -434,7 +425,9 @@ class TestLabelwiseRocCurve:
         frozen_model_url,
     ):
         responses.add(
-            responses.GET, labelwise_roc_curve_validation_data_url, status=404,
+            responses.GET,
+            labelwise_roc_curve_validation_data_url,
+            status=404,
         )
 
         responses.add(
@@ -464,154 +457,13 @@ class TestLabelwiseRocCurve:
 
     @responses.activate
     def test_get_labelwise_roc_curves_no_data_available(
-        self, labelwise_roc_curve_validation_data_url, project_id, model_id, parent_model_id,
+        self,
+        labelwise_roc_curve_validation_data_url,
+        project_id,
+        model_id,
+        parent_model_id,
     ):
         responses.add(responses.GET, labelwise_roc_curve_validation_data_url, status=404)
         model = Model(id=model_id, project_id=project_id)
         with pytest.raises(ClientError):
             model.get_labelwise_roc_curves("validation")
-
-    @responses.activate
-    def test_get_all_labelwise_roc_curves(
-        self,
-        labelwise_roc_curve_validation_and_cross_validation_data,
-        labelwise_roc_curve_list_url,
-        project_id,
-        model_id,
-        roc_curve_validation_data,
-        roc_curve_data,
-    ):
-        responses.add(
-            responses.GET,
-            labelwise_roc_curve_list_url,
-            status=200,
-            content_type="application/json",
-            body=json.dumps(labelwise_roc_curve_validation_and_cross_validation_data),
-        )
-        model = Model(id=model_id, project_id=project_id)
-        roc_charts = model.get_all_labelwise_roc_curves()
-
-        expected_labels = ["cat", u"🐕"]
-        expected_sources = ["validation", "crossValidation"]
-        expected_source_label_combinations = product(expected_labels, expected_sources)
-
-        assert len(roc_charts) == len(expected_labels) * len(expected_sources)
-
-        for roc_chart, (expected_label, expected_source) in zip(
-            roc_charts, expected_source_label_combinations
-        ):
-            self._assert_single_labelwise_roc_curve(
-                roc_chart, expected_label, expected_source, model_id, roc_curve_data
-            )
-
-    @responses.activate
-    @pytest.mark.usefixtures("known_warning")
-    def test_get_all_labelwise_roc_curves_fallback_to_parent_insight(
-        self,
-        labelwise_roc_curve_validation_and_cross_validation_data,
-        labelwise_roc_curve_validation_cross_validation_and_holdout_data,
-        labelwise_roc_curve_list_url,
-        labelwise_roc_curve_parent_list_url,
-        project_id,
-        model_id,
-        parent_model_id,
-        roc_curve_validation_data,
-        frozen_model_url,
-        frozen_json,
-        roc_curve_data,
-    ):
-        responses.add(
-            responses.GET,
-            labelwise_roc_curve_list_url,
-            status=200,
-            content_type="application/json",
-            body=json.dumps(labelwise_roc_curve_validation_and_cross_validation_data),
-        )
-        responses.add(
-            responses.GET,
-            frozen_model_url,
-            body=frozen_json,
-            status=200,
-            content_type="application/json",
-        )
-        responses.add(
-            responses.GET,
-            labelwise_roc_curve_parent_list_url,
-            status=200,
-            content_type="application/json",
-            body=json.dumps(labelwise_roc_curve_validation_cross_validation_and_holdout_data),
-        )
-        model = Model(id=model_id, project_id=project_id, is_frozen=True)
-        roc_charts = model.get_all_labelwise_roc_curves(fallback_to_parent_insights=True)
-
-        expected_labels = ["cat", u"🐕"]
-        expected_sources = ["validation", "crossValidation", "holdout"]
-
-        expected_source_label_combinations = [
-            ("cat", "validation"),
-            ("cat", "crossValidation"),
-            (u"🐕", "validation"),
-            (u"🐕", "crossValidation"),
-            ("cat", "holdout"),
-            (u"🐕", "holdout"),
-        ]
-        assert len(roc_charts) == len(expected_labels) * len(expected_sources)
-
-        for roc_chart, (expected_label, expected_source) in zip(
-            roc_charts, expected_source_label_combinations
-        ):
-            expected_model_id = parent_model_id if expected_source == "holdout" else model_id
-            self._assert_single_labelwise_roc_curve(
-                roc_chart, expected_label, expected_source, expected_model_id, roc_curve_data
-            )
-
-    @responses.activate
-    def test_get_all_labelwise_roc_curves_fallback_flag_not_set(
-        self,
-        labelwise_roc_curve_validation_and_cross_validation_data,
-        labelwise_roc_curve_validation_cross_validation_and_holdout_data,
-        labelwise_roc_curve_list_url,
-        labelwise_roc_curve_parent_list_url,
-        project_id,
-        model_id,
-        parent_model_id,
-        roc_curve_validation_data,
-        frozen_model_url,
-        frozen_json,
-        roc_curve_data,
-    ):
-        responses.add(
-            responses.GET,
-            labelwise_roc_curve_list_url,
-            status=200,
-            content_type="application/json",
-            body=json.dumps(labelwise_roc_curve_validation_and_cross_validation_data),
-        )
-        responses.add(
-            responses.GET,
-            frozen_model_url,
-            body=frozen_json,
-            status=200,
-            content_type="application/json",
-        )
-        responses.add(
-            responses.GET,
-            labelwise_roc_curve_parent_list_url,
-            status=200,
-            content_type="application/json",
-            body=json.dumps(labelwise_roc_curve_validation_cross_validation_and_holdout_data),
-        )
-        model = Model(id=model_id, project_id=project_id, is_frozen=True)
-        roc_charts = model.get_all_labelwise_roc_curves(fallback_to_parent_insights=False)
-
-        expected_labels = ["cat", u"🐕"]
-        expected_sources = ["validation", "crossValidation"]
-        expected_source_label_combinations = product(expected_labels, expected_sources)
-
-        for roc_chart, (expected_label, expected_source) in zip(
-            roc_charts, expected_source_label_combinations
-        ):
-            expected_model_id = parent_model_id if expected_source == "holdout" else model_id
-            self._assert_single_labelwise_roc_curve(
-                roc_chart, expected_label, expected_source, expected_model_id, roc_curve_data
-            )
